#include "stdafx.h"
#include "VCADDTools.h"
#include <stdio.h>

// C++ to say Hello World!
//   lines starting with a // are comments
void WINAPI HelloWorld(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    // used for error returns from the API
    short iError;	
    
    // construct a point object
    Point2D pt;

    // set the point to the origin
    pt.x = 0.0;
    pt.y = 0.0;

    // set text string
    VCSetTextString(&iError, "Hello World!");

    // place the text in the drawing at the given point
    //   -1 means in the drawing, other options 
    //   can place it in a symbol definition
    VCAddTextEntity(&iError, -1, pt);

    // zoom all to see the text
    VCZoomAll();
}

// C++ to Add a Single Entity
//   lines starting with a // are comments
void WINAPI AddSingleEnt(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    // used for error returns from the API
    short iError;

    // an entity handle, an index into the drawing database
    long hEnt;
    
    // construct two point objects
    Point2D pt0;
    Point2D pt1;

    // Optional - Set properties for the new entity:
    //      While all the properties can be modified after the entity 
    //      has been added to the database, it is convenient to set 
    //      the properties prior to the operation.
    //      The properties for entities typically include layer, 
    //      color, line type, and line width.  These can be set with 
    //      the following API calls.
    //      If you do not set a specific property, Visual CADD will 
    //      use the current properties when creating the entity.
    //      Compound entities such as dimensions, text, fills, and
    //      hatches require specific settings for the respective 
    //      entity type.
    //      The following code sets the layer index to 5, 
    //      the color property to blue (index 9), 
    //      the line type property to SOLID (index 0),
    //      and the line width property index to 1 (pixel).
 
    VCSetLayerIndex(&iError, 5);
    VCSetColorIndex(&iError, 9);
    VCSetLineTypeIndex(&iError, 0);
    VCSetLineWidthIndex(&iError, 1);

    //  Add the entity to the database:
    //      To add the entity to the drawing, specify the point(s)
    //      location which can be determined either directly through 
    //      code or as a result of user input (demonstrated in 
    //      another topic).  The point(s) are then passed to the add
    //      command to place the entity.
    //      Note each entity requires a different number of input 
    //      points to define the geometry. For example, a line 
    //      entity requires two point locations for the end points 
    //      while an elliptical arc requires seven points to define
    //      the placement. Verify the number of points and their 
    //      purpose in the Alphabetical Listing of API 
    //      Calls.
    //      The following code adds a line from (0.0, 0.0) to 
    //      (10.0, 10.0) based on values established through 
    //      code. Note the points have been defined as a Point2D
    //      and contain an x and y value.
    //      The -1 means to place the entity in the drawing, other 
    //      options can place it in a symbol definition.

    pt0.x = 0.0;
    pt0.y = 0.0;
    pt1.x = 10.0;
    pt1.y = 10.0;
    VCAddLineEntity(&iError, -1, pt0, pt1);

    //  Optional - Make the new entity the current entity:
    //      A new entity is always appended to the end of the 
    //      database and given an entity handle (index) one greater 
    //      than the previous last entity.  It may be necessary to 
    //      make the new entity current for tracking its ID, changing
    //      properties, redrawing to the screen, adding data to the 
    //      entity, or other operations.  Each entity in the drawing
    //      database is referenced by an entity handle (index) 
    //      allowing applications to quickly access entities with 
    //      VCSetCurrentEntity.
    //      The following code sets the newly placed entity as the 
    //      current entity.

    VCLastEntity(&iError, &hEnt);
    VCSetCurrentEntity(&iError, hEnt);

    //  Optional - Draw the new entity to the screen:
    //      New entities are not automatically displayed on the 
    //      screen after being added to the database.  The entity 
    //      will be drawn during the next redraw or paint event,
    //      such as a VCZoomAll() or a UI command Regen/RD.  In order
    //      to draw the entity immediately, use VCDrawCurrentEntity:

    VCDrawCurrentEntity(&iError);
}

// C++ to Add a Continuous Entity
//   lines starting with a // are comments
void WINAPI AddContEnt(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  an entity handle, an index into the drawing database
    long hEnt;
    
    // construct a point object
    Point2D pt0;

    //  Optional - Set properties for the new entity:
    //      While all the properties can be modified after the entity 
    //      has been added to the database, it is convenient to set 
    //      the properties prior to the operation.
    //      The properties for entities typically include layer, 
    //      color, line type, and line width.  These can be set with 
    //      the following API calls.
    //      If you do not set a specific property, Visual CADD will 
    //      use the current properties when creating the entity.
    //      Compound entities such as dimensions, text, fills, and
    //      hatches require specific settings for the respective 
    //      entity type.
    //      The following code sets the layer index to 5, 
    //      the color property to blue (index 9), 
    //      the line type property to SOLID (index 0),
    //      and the line width property index to 1 (pixel).
 
    VCSetLayerIndex(&iError, 5);
    VCSetColorIndex(&iError, 9);
    VCSetLineTypeIndex(&iError, 0);
    VCSetLineWidthIndex(&iError, 1);

    //  Add a reference to the entity to the database:
    //      Continuous entities allow for a multiple number of points
    //      defining the geometry.  These points must be set after 
    //      the entity has been added in the database.  Like the 
    //      single entities, the defining points can be defined 
    //      through code or through user interaction within the 
    //      interface.  The following code adds a Continuous Bezier 
    //      entity initially with no points.
    //      The -1 means to place the entity in the drawing, other 
    //      options can place it in a symbol definition.

    VCAddContinuousBezierEntity(&iError, -1);

    //      In order to add placement points to the geometry, the new
    //      entity must be set current.  This ensures the point 
    //      operations are applied to the correct entity.  Each 
    //      entity in the drawing database is referenced based on a 
    //      handle or index allowing applications to quickly access 
    //      entities with VCSetCurrentEntity.  The following code 
    //      gets the handle (index) of the newly placed entity and 
    //      sets it as the current entity.

    VCLastEntity(&iError, &hEnt);
    VCSetCurrentEntity(&iError, hEnt);

    //  Set the points for the continuous entity:
    //      Since a continuous entity allows for a variable number 
    //      of points, the application can set the points one at a 
    //      time as often as needed.  This is done by using the 
    //      VCSetCurrentEntityPoint function to set the points.
    //      The following code sample adds 10 calculated points 
    //      to the Continuous Bezier entity.
    
    for (short index = 0; index < 10; index++)
    {
        pt0.x = index;
        pt0.y = 10.0 / (1.0 + index);

        VCSetCurrentEntityPoint(&iError, index, &pt0);
    }

    //  Optional - Draw the new entity to the screen:
    //      New entities are not automatically displayed on the 
    //      screen after being added to the database.  The entity 
    //      will be drawn during the next redraw or paint event,
    //      such as a VCZoomAll() or a UI command Regen/RD.  In order
    //      to draw the entity immediately, use VCDrawCurrentEntity:

    VCDrawCurrentEntity(&iError);
}

// C++ to Add a Hatch Entity
//   lines starting with a // are comments
void WINAPI AddHatchEnt(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  an entity handle, an index into the drawing database
    long hEnt;
    
    // construct two point objects
    Point2D pt0;
    Point2D pt1;

    //  Optional: Set the properties for the new entity:
    //      Hatch settings have their own specific settings separate 
    //      from the drawing properties of layer, color, line type, 
    //      and line width settings.  Specific settings calls 
    //      are required to alter the color, pattern rotation, and 
    //      scale.  If no settings are specified, Visual CADD will 
    //      use the current settings.  The following code sets the 
    //      hatch pattern to ZigZag with a scale of 5.0, rotation 
    //      angle of 0.0, and color to blue (index 9):

    VCSetHatchColor(&iError, 9);
    VCSetHatchRot(&iError, 0.0);
    VCSetHatchScale(&iError, 5.0);
    VCSetHatchName(&iError, "ZigZag");

    //  Add a reference to the entity to the database:
    //      Hatch entities allow different combinations of entities 
    //      to form the boundary.  These entities need to be added 
    //      to an existing hatch entity.  After the hatch entity is 
    //      added drawing database, entities are added to the hatch 
    //      and sorted to verify the new boundary.  The following 
    //      code adds a Hatch entity which initially has no boundary:

    VCAddHatchEntity(&iError, -1);

    //      In order to add boundary entities to the hatch, the new 
    //      entity must be set current.  Each entity in the drawing 
    //      database is referenced based on a handle or index 
    //      allowing applications to quickly access entities with 
    //      VCSetCurrentEntity.  The following code gets the handle 
    //      (index) of the newly placed entity and sets it as the 
    //      current entity.

    VCLastEntity(&iError, &hEnt);
    VCSetCurrentEntity(&iError, hEnt);

    //  Add entities to create the boundary:
    //      The added entities must create a closed boundary for the 
    //      hatch.  These boundaries can be made of either single or 
    //      continuous entities.  Please see the topic Adding a 
    //      Continuous Entity for more information about continuous 
    //      entities.  The following code creates a hatch boundary 
    //      based on a circle entity.  Note the -2 means to add the 
    //      entity to the hatch definition.

    pt0.x = 0.0;
    pt0.y = 0.0;
    pt1.x = 0.0;
    pt1.y = 10.0;
    VCAddCircleEntity(&iError, -2, pt0, pt1);

    //  Sort the Hatch/Fill Entity:
    //      After the boundary has been created, the Visual CADD 
    //      engine must parse the boundary and determine if it is 
    //      closed. Only closed boundaries can be hatched or filled.  
    //      The following code hatches the boundaries if they are 
    //      closed:

    VCSortCurrentHatchFillEntity(&iError);

    //  Optional - Draw the new entity to the screen:
    //      New entities are not automatically displayed on the 
    //      screen after being added to the database.  The entity 
    //      will be drawn during the next redraw or paint event,
    //      such as a VCZoomAll() or a UI command Regen/RD.  In order
    //      to draw the entity immediately, use VCDrawCurrentEntity:

    VCDrawCurrentEntity(&iError);
}

// C++ to Add a Text Entity
//   lines starting with a // are comments
void WINAPI AddTextEnt(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  an entity handle, an index into the drawing database
    long hEnt;
    
    // construct two point objects
    Point2D pt0;

    //  Optional: Set the properties for the new entity:
    //      Text settings have their own specific settings separate 
    //      from the drawing properties of layer, color, line type, 
    //      and line width settings.  If no settings are specified, 
    //      Visual CADD will use the current settings.  The 
    //      following code sets the text layer to 8, color to 
    //      blue (index 9), left justified, height 3 inches, and 
    //      text string to Hello World!:

    VCSetTextLayer(&iError, 8);
    VCSetTextColor(&iError, 9);
    VCSetTextJustify(&iError, 'L');
    VCSetTextHeight(&iError, 3.0);
    VCSetTextString(&iError, "Hello World!");

    //  Add the entity to the database:
    //      Text entities only require an insertion point for the string.

    pt0.x = 0.0;
    pt0.y = 0.0;

    //      The following code adds the text entity to the drawing:

    VCAddTextEntity(&iError, -1, pt0);
 
    //  Optional - Make the new entity the current entity:
    //      A new entity is always appended to the end of the 
    //      database and given an entity handle (index) one greater 
    //      than the previous last entity.  It may be necessary to 
    //      make the new entity current for tracking its ID, changing
    //      properties, redrawing to the screen, adding data to the 
    //      entity, or other operations.  Each entity in the drawing
    //      database is referenced by an entity handle (index) 
    //      allowing applications to quickly access entities with 
    //      VCSetCurrentEntity.
    //      The following code sets the newly placed entity as the 
    //      current entity.

    VCLastEntity(&iError, &hEnt);
    VCSetCurrentEntity(&iError, hEnt);

    //  Optional - Draw the new entity to the screen:
    //      New entities are not automatically displayed on the 
    //      screen after being added to the database.  The entity 
    //      will be drawn during the next redraw or paint event,
    //      such as a VCZoomAll() or a UI command Regen/RD.  In order
    //      to draw the entity immediately, use VCDrawCurrentEntity:

    VCDrawCurrentEntity(&iError);
}

// C++ to Add a Reference Frame Entity
//   lines starting with a // are comments
void WINAPI AddRFEnt(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    // construct two point objects
    Point2D pt0;

    //  Set the filename to add as the reference frame:
    //      The reference frame contains a drawing that is to be 
    //      referenced inside the active drawing. The path and 
    //      filename for the drawing are required to define the 
    //      entity.  The following code references a drawing 
    //      named SAMPLE.VCD from the active directory:

    VCSetRefFrameName(&iError, "SAMPLE.VCD");

    //  Optional: Set the desired frame properties:
    //      A reference frame has specific properties that apply 
    //      only to this entity type. These include boundary color, 
    //      line width, and display, offset, rotation, and scale. 
    //      Each of these properties can be altered after the entity 
    //      has been placed however it is convenient to set these 
    //      prior to adding the entity.  The following code sets 
    //      the boundary display off and the rotation to 45 degrees.
    //      NOTE: All angles must be entered in radians. PI/4 
    //      represents 45 degrees in radians.

    VCSetRefFrameDrawBoundary(&iError, 0);

    double dRotation = PI / 4.0;
    VCSetRefFrameRot(&iError, &dRotation);

    //  Bind or link the data as desired:
    //      The referenced drawing can either be bound or linked to 
    //      the reference frame entity. Bound data causes the 
    //      reference frame to store the vector information directly 
    //      in the active drawing while linked data stores only a 
    //      reference to the external file.  Linked drawings will 
    //      reflect changes made after the file has been added.  
    //      Bound data will cause the drawing size to enlarge since 
    //      all the reference file information is not stored in the 
    //      new drawing.  The following code specifies for the 
    //      reference frame to contain linked, not bound, data:

    VCSetRefFrameIsDataBound(&iError, 0);

    //  Optional: Set the reference frame size.
    //      A reference frame defaults to the size of the file that 
    //      is being referenced.  In situations where several 
    //      reference frames are used to reference a drawing, it may 
    //      be desirable to specify the frame size in order to have 
    //      the referenced drawing fit to a certain position.  The 
    //      following code sets the frame height and width to 12 
    //      inches each.  NOTE: The X value of the point represents 
    //      the width while the Y value represents the height.

    pt0.x = 12.0;
    pt0.y = 12.0;

    VCSetRefFrameViewWidthHeight(&iError, &pt0);

    //  Add the reference frame:
    //      The reference frame entity can now be added to the drawing 
    //      database.  The following adds the reference frame entity 
    //      to the drawing at 0, 0:

    pt0.x = 0.0;
    pt0.y = 0.0;

    VCAddRefFrameEntity(&iError, -1, &pt0);
}

// C++ to Load a Symbol
//   lines starting with a // are comments
void WINAPI LoadSym(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Retrieve the internal name for the symbol:
    //      When working with symbol entities, the index or the 
    //      internal name is required. Since the index changes as
    //      new symbols are loaded and others are deleted, 
    //      typically the internal name should be used.  As 
    //      noted, the internal name may not be known but can be 
    //      found from the one saved on disk.  The following code
    //      retrieves the internal name for a symbol from the one
    //      saved on disk.
    //      
    //  This example also illustrates how to retrieve strings
    //  from the API using C++.  The first call to 
    //  VCGetSymbolInternalName with the return parameter of NULL
    //  returns the length of the string.  Then after allocating 
    //  a buffer of that length plus one for the string's NULL 
    //  terminator, the second call retrieves the string.

    int iLen;
    char szFilename[MAX_PATH];

    strcpy_s(szFilename, MAX_PATH, 
        "C:\\Users\\Public\\Documents\\Visual CADD 9\\Symbols\\CedarTree.vcs");

    iLen = VCGetSymbolInternalName(&iError, szFilename, NULL);
    char* szInternal = new char[iLen + 1];
    VCGetSymbolInternalName(&iError, szFilename, szInternal);

    //  Load the symbol based on the internal name:
    //      When working with symbols, the symbol must be loaded 
    //      into memory within the drawing session prior to any 
    //      placement commands.  When loading new symbols into 
    //      the session, an application should check if the 
    //      definition has already been loaded by another 
    //      application or the user.  The symbol must be loaded 
    //      in order to be placed or manipulated.  The symbol can 
    //      be loaded multiple times but will keep a single 
    //      definition in memory.  The following code tests if 
    //      the symbol has been loaded and loads the definition.

    if (VCIsSymbolLoaded(szInternal) == 0)
    {
        VCOpenVCS(szFilename);
    }

    //  delete the buffer when done.
    delete [] szInternal;

    //  Optional: Follow with a symbol place operation.
}

// C++ to Place a Symbol
//   lines starting with a // are comments
void WINAPI PlaceSym(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    // construct point object
    Point2D pt0;

    //  See the Loading A Symbol topic for details of the 
    //  following to load a symbol in code.
    int iLen;
    char szFilename[MAX_PATH];
    strcpy_s(szFilename, MAX_PATH, 
        "C:\\Users\\Public\\Documents\\Visual CADD 9\\Symbols\\CedarTree.vcs");
    iLen = VCGetSymbolInternalName(&iError, szFilename, NULL);
    char* szInternal = new char[iLen + 1];
    VCGetSymbolInternalName(&iError, szFilename, szInternal);
    if (VCIsSymbolLoaded(szInternal) == 0)
    {
        VCOpenVCS(szFilename);
    }

    //  Place the symbol directly through code:
    //      The symbol can be added to the drawing database or 
    //      another symbol definition directly through code.  
    //      This method requires the same steps presented in the 
    //      Adding A Single Entity topic.  Once a symbol 
    //      definition has been loaded, the symbol must be 
    //      selected from the internal definition list.  Loaded 
    //      symbols are available to all drawings within 
    //      the drawing session and are referenced by an internal
    //      name or index.  In order to place the symbol, it must 
    //      be set as the currently active symbol definition.
    //
    //  The following code sets the active symbol definition 
    //  based on the internal name of an already loaded symbol 
    //  and places it at the point (12, 24) in inches.

    pt0.x = 12.0;
    pt0.y = 24.0;

    VCSetSymName(&iError, szInternal);
    VCAddSymbolEntity(&iError, -1, pt0);

    //  Optional:  Draw the symbol.  See the Adding A Single 
    //  Entity topic for details of the following to draw the 
    //  last entity.
    long hEnt;    
    VCLastEntity(&iError, &hEnt);
    VCSetCurrentEntity(&iError, hEnt);
    VCDrawCurrentEntity(&iError);

    //  Optional: Place the symbol using a tool command:
    //      The API provides several options when placing a 
    //      symbol through code.  If the application requires 
    //      user input for the placement point then VCSymbolPlace 
    //      can be used.  This routine initiates a tool in the 
    //      drawing interface and immediately allows the user to 
    //      begin dragging the symbol to the desired location.  
    //      Visual CADD handles all rubber-banding and preview 
    //      events in this case.
    //      
    //  The following code initiates the symbol placement tool 
    //  and allows the user to select the placement point:

    VCSymbolPlace(szInternal);

    //  delete the buffer when done.
    delete [] szInternal;
}

// C++ to Create a Symbol
//   lines starting with a // are comments
void WINAPI CreateSym(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    // construct two point objects
    Point2D pt0;
    Point2D pt1;

    //  Create a symbol name:
    //      Create a reference to the symbol definition. The 
    //      definition allows the code to add a symbol to 
    //      currently active drawing session based on an internal 
    //      name.  The following code creates a new definition 
    //      with the name "MySymbolDefintion":

    short iSymbolIndex;
    iSymbolIndex = VCCreateSymbolDef(&iError, "MySymbolDefintion");

    //  Add the entities directly to the symbol definition:
    //      The following code adds entities directly to the new 
    //      symbol definition.

    pt0.x = 0;
    pt0.y = 0;
    pt1.x = 0;
    pt1.y = 10;

    VCAddCircleEntity(&iError, iSymbolIndex, pt0, pt1);
    VCAddLineEntity(&iError, iSymbolIndex, pt0, pt1);

    //  Optional: Save the symbol definition to disk:
    //      When a symbol definition is created it is simply 
    //      loaded into the current drawing session.  In order to 
    //      utilize the definition in future drawing sessions, it 
    //      must be saved to disk.  The following code saves the 
    //      symbol to a VCS file.

    VCSaveVCS("MySymbolDefinition", "C:\\MyPath\\Symbols\\MySymbol.vcs");
}

// C++ to Modify a Symbol
//   lines starting with a // are comments
void WINAPI ModifySym(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    // construct three point objects
    Point2D pt0;
    Point2D pt1;
    Point2D pt2;

    //  Retrieve the symbol index:
    //      In order to add entities directly to a symbol 
    //      definition, the symbol index must be used.  Since the 
    //      symbol index can change as new symbols are loaded and 
    //      others deleted, it should be determined from the 
    //      internal name.  The following code retrieves the 
    //      symbol index from the internal name:

    short iSymbolIndex;
    iSymbolIndex = VCGetSymbolIndex(&iError, "MySymbolDefintion");

    //  Add the entities directly to the symbol definition:
    //      The returned symbol index can then be used to add 
    //      entities directly to the definition.  The following 
    //      code adds an arc to an existing definition using the 
    //      points 0,0; 10,10; 20,0:

    pt0.x = 0;
    pt0.y = 0;
    pt1.x = 10;
    pt1.y = 10;
    pt2.x = 20;
    pt2.y = 0;

    VCAddArcEntity(&iError, iSymbolIndex, pt0, pt1, pt2);

    //  Optional: Save the symbol definition to disk:
    //      When a symbol definition is modified it is simply 
    //      changed in the current drawing session.  In order to 
    //      utilize the definition in future drawing sessions, it 
    //      must be saved to disk.  The following code saves the 
    //      symbol to a VCS file.

    VCSaveVCS("MySymbolDefinition", "C:\\MyPath\\Symbols\\MySymbol.vcs");
}

// C++ to Parse a Symbol
//   lines starting with a // are comments
void WINAPI ParseSym(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  Set the symbol section for parsing:
    //      When querying information about entities, it is 
    //      necessary to parse the database for the desired item 
    //      and set it as the current handle.  Symbols behave as 
    //      other "primitive" entities that are present within 
    //      the drawing database.  In order to access information 
    //      about these sub-entities in a symbol, an application 
    //      needs to set the parsing selection to the symbol 
    //      definition prior to using the database routines.  
    //      This allows an application to retrieve and set values
    //      pertaining to entities within a symbol definition.
    //      The following code sets the parsing section for a 
    //      symbol name "InternalSymbolName":

    VCSetSymbolSection(&iError, "MySymbolDefintion");

    //  Error checking:
    //      If the requested symbol was not found, there can be 
    //      unpredictable results by proceeding as if it was 
    //      found.  So check the error and take appropriate 
    //      action:

    if (&iError != 0)    
    {
        //  Error condition
        //  show the user a warning message
        strcpy_s(sz, sizeof(sz), "MySymbolDefinition symbol not found");
        MessageBox(NULL, sz, "API Help Sample", NULL);
    }
    else
    {
        //  Success condition
        //  Use the database parsing routines:
        //      When querying information from a symbol definition, 
        //      it is necessary to parse within the definition to 
        //      retrieve the properties.  Any of the parsing methods 
        //      provided through the API may be used.  The following 
        //      code uses a loop to parse the symbol entity and 
        //      returns a count for the number of entities in that 
        //      symbol:

        short iKind;
        int iCount = 0; //  initialize to 0

        //  start at the first entity in the symbol definition
        VCFirstEntity(&iError, &iKind);

        //  loop through and count the entities  
        while (iError == 0)
        {
            iCount++;
            VCNextEntity(&iError, &iKind);
        }

        sprintf_s(sz, sizeof(sz), "MySymbolDefintion entity count: %d", iCount);
        MessageBox(NULL, sz, "API Help Sample", NULL);
    }


    //  Reset the parsing routines to the entity section:
    //      After completion of the symbol parsing routine, reset 
    //      the entity section to the drawing.  Otherwise other 
    //      routines parsing the database might accidentally 
    //      parse the symbol rather than the database.  The 
    //      following code resets the parsing section to the 
    //      drawing:

    VCSetEntitySection(&iError);
}

// C++ to Retrieve a Symbol Count
//   lines starting with a // are comments
void WINAPI RetrieveSym(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for messages
    char sz[128];
    char szSymName[MAX_VC_SYM_NAME + 1];

    //  Retrieve the symbol definition count:
    //      Symbol definitions are loaded into the drawing 
    //      session as new drawings are loaded or by specific 
    //      commands to load them.  The following code retrieves 
    //      a count for the number of currently loaded symbol 
    //      definitions:

    short iLoadedCount;
    iLoadedCount = VCGetSymbolDefCount();

    //  Parse the symbol definitions and retrieve the placement 
    //  count:
    //      After retrieving the number of definitions loaded in 
    //      the session, an application can then simply move 
    //      through the list and get the necessary information.  
    //      The following code parses the symbol definitions and 
    //      retrieves the name and number of placements for each 
    //      definition.

    short iIndex;
    for (iIndex = 0; iIndex < iLoadedCount; iIndex++)
    {
        VCGetSymbolName(szSymName, iIndex);

        short iPlacedCount;
        iPlacedCount = VCGetSymbolPlacementCount(iIndex);

        sprintf_s(sz, sizeof(sz), 
            "Symbol Index: %d\nName: %s\nPlaced: %d time(s)", 
            iIndex, szSymName, iPlacedCount);
        MessageBox(NULL, sz, "API Help Sample", NULL);
    }
}

// C++ to Retrieve Attributes
//   lines starting with a // are comments
void WINAPI RetrieveAtb(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[1024];
    char* szLabel;
    char* szValue;

    //  parse through the entire database:
    //  start at the first entity
    short iKind;
    VCFirstEntity(&iError, &iKind);

    //  loop through entities
    while (iError == 0)
    {
        //  process only symbols
        if (iKind == SYMBOL2D)
        {
            //  Retrieve the number of attribute definitions 
            //  attached:
            //      A symbol can have an unlimited number of 
            //      attributes attached.  These attribute 
            //      definitions contain labels and values 
            //      defining the definition.  This step should be
            //      used to determine the number so a proper loop 
            //      can be set up to parse through all the 
            //      attributes.  The following code retrieves the 
            //      number of attributes and sets up a loop 
            //      structure to begin parsing the attributes:

            short iAtbCount;
            iAtbCount = VCGetCurEntAtbCount(&iError);

            for (short iAtbIndex = 0; iAtbIndex < iAtbCount; iAtbIndex++)
            {
                //  Retrieve the number of labels in the current 
                //  attribute definition:
                //      Similar to the step above but this sets 
                //      up a loop structure for parsing the 
                //      current attribute.  The following example 
                //      sets up a loop structure to parse the 
                //      current attribute definition:

                short iRecCount;
                iRecCount = VCGetCurEntAtbRecCount(&iError, iAtbIndex);
                {
                    //  Retrieve the label from the definition:
                    //      Once inside the attribute definition, 
                    //      the program can then retrieve the 
                    //      label and value.  The label 
                    //      represents the name or tag for the 
                    //      attribute.  For example, if the 
                    //      attribute read MANUFACTURER: TRITOOLS 
                    //      then MANUFACTURER represents the 
                    //      label and TRITOOLS represents the 
                    //      value.  The following code retrieves 
                    //      the label and value at the current 
                    //      loop index:

                    for (short iRecIndex = 0; iRecIndex < iRecCount; iRecIndex++)
                    {
                        short iLen;
                        iLen = VCGetCurEntAtbRecLabel(&iError, iAtbIndex, iRecIndex, NULL);
                        szLabel = new char[iLen + 1];
                        VCGetCurEntAtbRecLabel(&iError, iAtbIndex, iRecIndex, szLabel);

                        iLen = VCGetCurEntAtbRecValue(&iError, iAtbIndex, iRecIndex, NULL);
                        szValue = new char[iLen + 1];
                        VCGetCurEntAtbRecValue(&iError, iAtbIndex, iRecIndex, szValue);

                        sprintf_s(sz, sizeof(sz), 
                            "Label: %s  Value: %s", 
                            szLabel, szValue);
                        MessageBox(NULL, sz, "API Help Sample", NULL);

                        delete [] szLabel;
                        delete [] szValue;
                    }
                }
            }
        }

        VCNextEntity(&iError, &iKind);
    }
}

// C++ to Create Attributes
//   lines starting with a // are comments
void WINAPI CreateAtb(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Create the initial attribute values:
    //      In order to create an attribute at least one set of 
    //      label and value must be set.  This data is referenced 
    //      by an index of zero in the attribute definition.  The 
    //      following code adds an attribute definition named 
    //      "MYATB" to the current drawing session and sets the 
    //      initial label to "Type" and value to "Default":

    VCAddAtbDef(&iError, "MYATB", "Type", "Default");

    //  Set any subsequent label and values in the attribute:
    //      An attribute can contain up to 256 label and value 
    //      sets.  Each of these can represent any set of 
    //      non-graphical data required. Each attribute label and 
    //      value must be set in order. For example, an 
    //      application can set the values for the second record 
    //      set (iRec = 1) and then for the third record set 
    //      (iRec = 2).  It can not skip a set, it must add the 
    //      items in sequential order starting with 0 for the 
    //      initial set.  The following code adds four more label 
    //      and value record sets:

    VCSetAtbDefLabelValue(&iError, "MYATB", "Label1", "Value1", 1);
    VCSetAtbDefLabelValue(&iError, "MYATB", "Label2", "Value2", 2);
    VCSetAtbDefLabelValue(&iError, "MYATB", "Label3", "Value3", 3);
    VCSetAtbDefLabelValue(&iError, "MYATB", "Label4", "Value4", 4);
}

// C++ to Attach User Data
//   lines starting with a // are comments
void WINAPI AttachUD(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Set the required unique user data name in the application
    //  initialization routine:
    //      In order to setup user data for each entity and the 
    //      drawing header, a unique user data name must be 
    //      specified to reference the information.  The user 
    //      data name is case insensitive and can be up to 15 
    //      characters long.  The following code sets a user 
    //      data name of "MyData":

    VCSetUserDataName(&iError, "MyData");

    //  Attach the information to the current entity:
    //      To access user data in the current entity, call 
    //      VCSetEntityUserData.

    VCSetEntityUserData(&iError);

    //    The current entity can be set in a number of ways 
    //    using any of the Visual CADD API parsing routines or 
    //    VCSetCurrentEntity.  For information see the topic 
    //    Parsing the Database.  For illustration, we will use 
    //    the first entity in the database with entity handle or 
    //    index 0.  The user data will be attached to this 
    //    current entity.

    VCSetCurrentEntity(&iError, 0);

    //  verify we have a current entity before proceeding
    if (&iError == 0)
    {
        //  Add or set the desired user data values to the 
        //  current entity:
        //      The Visual CADD API allows two methods for 
        //      attaching the user data information.  The easiest
        //      method is to simply use the add routines which 
        //      adds the data to the next available slot in the 
        //      user data segment. The API also allows user data 
        //      to be set and placed at a specific index within 
        //      the user data.  The benefits of the second method 
        //      become apparent when working with multiple data 
        //      values being attached to the entity.  As more 
        //      data is attached, a hierarchical system can be 
        //      set up to access the information desired.  The 
        //      following code adds a user data short (0), 
        //      double (25.5), string ("My Application Data"), 
        //      and chunk to the current entity:

        VCAddCurrentEntityUserDataShort(&iError, 0);
        VCAddCurrentEntityUserDataDouble(&iError, 25.5);
        VCAddCurrentEntityUserDataString(&iError, "My Application Data");

        BYTE bFlags[8] = { 0x23, 0xa3, 0x6f, 0x8e, 0x66, 0xff, 0xff, 0xb2 };
        VCAddCurrentEntityUserDataChunk(&iError, bFlags, 8);

        //  Optional - if the current entity already has user 
        //  data and your application knows the order and kind of
        //  the data, then you can set or replace the existing 
        //  data.  The following code sets the previously added 
        //  user data short (31) and double (-52.2) at index 0 
        //  and 1, respectively:

        VCSetCurrentEntityUserDataShort(&iError, 0, 31);
        VCSetCurrentEntityUserDataDouble(&iError, 1, -52.2);
    }
}

// C++ to Retrieve User Data
//   lines starting with a // are comments
void WINAPI RetrieveUD(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Set the required unique user data name in the application
    //  initialization routine:
    //      In order to access user data for each entity and the 
    //      drawing header, a unique user data name must be 
    //      specified to reference the information.  The user 
    //      data name is case insensitive and can be up to 15 
    //      characters long.  The following code sets a user 
    //      data name of "MyData":

    VCSetUserDataName(&iError, "MyData");

    //  Retrieve the information to the current entity:
    //      To access user data in the current entity, call 
    //      VCSetEntityUserData.

    VCSetEntityUserData(&iError);

    //    The current entity can be set in a number of ways 
    //    using any of the Visual CADD API parsing routines or 
    //    VCSetCurrentEntity.  For information see the topic 
    //    Parsing the Database.  For illustration, we will use 
    //    the first entity in the database with entity handle or 
    //    index 0.  The user data will be retrieved from this 
    //    current entity.

    VCSetCurrentEntity(&iError, 0);

    //  verify we have a current entity before proceeding
    if (&iError == 0)
    {
        //  Retrieve the user data count for the unique user 
        //  data ID:
        //      This count returns the number of valid user data 
        //      segments attached to the entity.  This 
        //      information can then used to loop through the 
        //      retrieval process.  The following code retrieves 
        //      the amount of data attached at the current 
        //      location:

        short iUDCount;
        iUDCount = VCGetCurrentEntityUserDataCount(&iError);

        //  For each index, retrieve the type of user data 
        //  information attached.  This step can be avoided if 
        //  the application remembers and accesses the 
        //  information all in the same order each time.  The 
        //  following code retrieves the user data kind at the 
        //  specified index.  Typically this would be done in a 
        //  loop statement to check all the data on the entity:

        for (short iIndex = 0; iIndex < iUDCount; iIndex++)
        {
            //  If the data type is not known then typically this 
            //  would involve a statement to retrieve the user 
            //  data kind then retrieve the value of the 
            //  appropriate type.  If the application remembers 
            //  and accesses the user data the same way each 
            //  time, you would just make direct calls to the 
            //  corresponding functions for the respective index.

            short iUDKind;
            iUDKind = VCGetCurrentEntityUserDataKind(&iError, iIndex);

            switch(iUDKind)
            {
            case USER_UNKNOWN:
            default:
                {
                    break;
                }
            case USER_BYTE:
                {
                    BYTE bByte;
                    bByte = VCGetCurrentEntityUserDataByte(&iError, iIndex);
                    break;
                }
            case USER_SHORT:
                {
                    short nShort;
                    nShort = VCGetCurrentEntityUserDataShort(&iError, iIndex);
                    break;
                }
            case USER_LONG:
                {
                    long iLong;
                    iLong = VCGetCurrentEntityUserDataLong(&iError, iIndex);
                    break;
                }
            case USER_DOUBLE:
                {
                    double dDouble;
                    dDouble = VCGetCurrentEntityUserDataDouble(&iError, iIndex);
                    break;
                }
            case USER_FLOAT:
                {
                    float fFloat;
                    fFloat = VCGetCurrentEntityUserDataFloat(&iError, iIndex);
                    break;
                }
            case USER_CHUNK:
                {
                    short iSize;
                    iSize = VCGetCurEntUserDataChunkSize(&iError, iIndex);
                    char* pBytes = new char[iSize];
                    VCGetCurrentEntityUserDataChunk(&iError, iIndex, pBytes);
                    delete [] pBytes;
                    break;
                }
            case USER_STRING:
                {
                    char sz[USER_MAX_STRING_SIZE];
                    VCGetCurrentEntityUserDataString(&iError, iIndex, sz);
                    break;
                }
            }
        }
    }
}

// C++ to Access Header User Data
//   lines starting with a // are comments
void WINAPI HeaderUD(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Set the required unique user data name in the application
    //  initialization routine:
    //      In order to access user data for each entity and the 
    //      drawing header, a unique user data name must be 
    //      specified to reference the information.  The user 
    //      data name is case insensitive and can be up to 15 
    //      characters long.  The following code sets a user 
    //      data name of "MyData":

    VCSetUserDataName(&iError, "MyData");

    //  Access the user data in the drawing header:
    //      Access to user data in the drawing header is 
    //      identical to the user data in the current entity 
    //      except that you call VCSetHeaderUserData instead of 
    //      VCSetEntityUserData and there is no current entity.

    VCSetHeaderUserData(&iError);

    //  Add or set the desired user data values to the 
    //  drawing header:
    //      The Visual CADD API allows two methods for 
    //      attaching the user data information.  The easiest
    //      method is to simply use the add routines which 
    //      adds the data to the next available slot in the 
    //      user data segment. The API also allows user data 
    //      to be set and placed at a specific index within 
    //      the user data.  The benefits of the second method 
    //      become apparent when working with multiple data 
    //      values being attached to the header.  As more 
    //      data is attached, a hierarchical system can be 
    //      set up to access the information desired.  The 
    //      following code adds a user data short (0), 
    //      double (25.5), string ("My Application Data"), and 
    //      chunk to the drawing header:

    VCAddCurrentEntityUserDataShort(&iError, 0);
    VCAddCurrentEntityUserDataDouble(&iError, 25.5);
    VCAddCurrentEntityUserDataString(&iError, "My Application Data");

    BYTE bFlags[8] = { 0x23, 0xa3, 0x6f, 0x8e, 0x66, 0xff, 0xff, 0xb2 };
    VCAddCurrentEntityUserDataChunk(&iError, bFlags, 8);

    //  Optional - if the drawing header already has user 
    //  data and your application knows the order and kind of
    //  the data, then you can set or replace the existing 
    //  data.  The following code sets the previously added 
    //  user data short (31) and double (-52.2) at index 0 
    //  and 1, respectively:

    VCSetCurrentEntityUserDataShort(&iError, 0, 31);
    VCSetCurrentEntityUserDataDouble(&iError, 1, -52.2);

    //  Retrieve the user data count for the unique user 
    //  data ID:
    //      This count returns the number of valid user data 
    //      segments attached to the header.  This 
    //      information can then used to loop through the 
    //      retrieval process.  The following code retrieves 
    //      the amount of data attached at the current 
    //      location:

    short iUDCount;
    iUDCount = VCGetCurrentEntityUserDataCount(&iError);

    //  For each index, retrieve the type of user data 
    //  information attached.  This step can be avoided if 
    //  the application remembers and accesses the 
    //  information all in the same order each time.  The 
    //  following code retrieves the user data kind at the 
    //  specified index.  Typically this would be done in a 
    //  loop statement to check all the data on the entity:

    for (short iIndex = 0; iIndex < iUDCount; iIndex++)
    {
        //  If the data type is not known then typically this 
        //  would involve a statement to retrieve the user 
        //  data kind then retrieve the value of the 
        //  appropriate type.  If the application remembers 
        //  and accesses the user data the same way each 
        //  time, you would just make direct calls to the 
        //  corresponding functions for the respective index.

        short iUDKind;
        iUDKind = VCGetCurrentEntityUserDataKind(&iError, iIndex);

        switch(iUDKind)
        {
        case USER_UNKNOWN:
        default:
            {
                break;
            }
        case USER_BYTE:
            {
                BYTE bByte;
                bByte = VCGetCurrentEntityUserDataByte(&iError, iIndex);
                break;
            }
        case USER_SHORT:
            {
                short nShort;
                nShort = VCGetCurrentEntityUserDataShort(&iError, iIndex);
                break;
            }
        case USER_LONG:
            {
                long iLong;
                iLong = VCGetCurrentEntityUserDataLong(&iError, iIndex);
                break;
            }
        case USER_DOUBLE:
            {
                double dDouble;
                dDouble = VCGetCurrentEntityUserDataDouble(&iError, iIndex);
                break;
            }
        case USER_FLOAT:
            {
                float fFloat;
                fFloat = VCGetCurrentEntityUserDataFloat(&iError, iIndex);
                break;
            }
        case USER_CHUNK:
            {
                short iSize;
                iSize = VCGetCurEntUserDataChunkSize(&iError, iIndex);
                char* pBytes = new char[iSize];
                VCGetCurrentEntityUserDataChunk(&iError, iIndex, pBytes);
                delete [] pBytes;
                break;
            }
        case USER_STRING:
            {
                char sz[USER_MAX_STRING_SIZE];
                VCGetCurrentEntityUserDataString(&iError, iIndex, sz);
                break;
            }
        }
    }
}

// C++ to Retrieve User Data using tags
//   lines starting with a // are comments
void WINAPI RetrieveUDbyTag(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Set the required unique user data name in the application
    //  initialization routine:
    //      In order to access user data for each entity and the 
    //      drawing header, a unique user data name must be 
    //      specified to reference the information.  The user 
    //      data name is case insensitive and can be up to 15 
    //      characters long.  The following code sets a user 
    //      data name of "MyData":

    VCSetUserDataName(&iError, "MyData");

    //  Retrieve the information to the current entity:
    //      To access user data in the current entity, call 
    //      VCSetEntityUserData.

    VCSetEntityUserData(&iError);

    //    The current entity can be set in a number of ways 
    //    using any of the Visual CADD API parsing routines or 
    //    VCSetCurrentEntity.  For information see the topic 
    //    Parsing the Database.  For illustration, we will use 
    //    the first entity in the database with entity handle or 
    //    index 0.  The user data will be retrieved from this 
    //    current entity.

    VCSetCurrentEntity(&iError, 0);

    //  verify we have a current entity before proceeding
    if (&iError == 0)
    {
        //  Add or set the desired user data values to the 
        //  current entity:
        //      As each user data item is added, a user data tag
        //      is attached to it to identify it for future access.

        VCAddCurrentEntityUserDataShort(&iError, 0);
        VCSetCurrentEntityUserDataTag(&iError, 0, 123);
        VCAddCurrentEntityUserDataDouble(&iError, 25.5);
        VCSetCurrentEntityUserDataTag(&iError, 1, 345);
        VCAddCurrentEntityUserDataString(&iError, "My Application Data");
        VCSetCurrentEntityUserDataTag(&iError, 2, 678);

        //  Retrieve the user data index for a tag:
        //      This returns the index of the user data which
        //      has a tag value of 345. The search is started at index 0.
        //      For our example, the returned index will be 1.
        //      If more than one user data item had a tag value of 345,
        //      the subsequent indexes could be found by setting the start index
        //      to the current index value: 

        short iIndex = VCGetCurrentEntityUserDataTagIndex(&iError, 345, 0);

        //  We can now access the user data. 
        //  If the application remembers the user data type
        //  for the item, you would just make direct calls to the 
        //  corresponding function for the index.

        double dDouble;
        dDouble = VCGetCurrentEntityUserDataDouble(&iError, iIndex);

        //  To illustrate the usefulness of tags, delete a user data item:
        //      Deleting user data item 0 (short) will cause the index
        //      of the following two items (the double and the string) to change.
        //      This time, finding a tag of 345 will return an index of 0.

        VCDeleteCurrentEntityUserData(&iError, 0);
        iIndex = VCGetCurrentEntityUserDataTagIndex(&iError, 345, 0);

        //  We can still access the double user data.

        dDouble = VCGetCurrentEntityUserDataDouble(&iError, iIndex);
   }
}

// C++ to Check Version
//   lines starting with a // are comments
void WINAPI Version(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for messages
    char sz[64];

    //  Check the version numbers:
    //      If your application requires a certain Visual CADD 
    //      version, use the following code to retrieve the 
    //      version numbers for error checking:

    short iMajor;
    short iMinor;
    short iDot;
    short iInternal;
    long iFull;
    long iTarget;

    //  get the version numbers
    iMajor = VCGetMajorVersion();
    iMinor = VCGetMinorVersion();
    iDot = VCGetMinorDotVersion();
    iInternal = VCGetMinorInternalVersion();

    //  get the full version packed as major/minor/dot/internal
    iFull = VCGetFullVersion();
    iTarget =  0x07000000;  //  packed 7.0.0.0

    if (iFull >= iTarget)
    {
        sprintf_s(sz, sizeof(sz), "Visual CADD Version: %d.%d.%d.%d\n%s", 
            iMajor, iMinor, iDot, iInternal, "Version is v7.0.0 or higher");
        MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
    }
    else
    {
        sprintf_s(sz, sizeof(sz), "Visual CADD Version: %d.%d.%d.%d\n%s", 
            iMajor, iMinor, iDot, iInternal, "Version is less than v7.0.0");
        MessageBox(NULL, sz, "API Help Sample", MB_ICONEXCLAMATION);

        //  Optional - stop tool from running
    }
}

// C++ to Check Valid World
//   lines starting with a // are comments
void WINAPI WorldCheck(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  Check the current world:
    //      The following code checks the current drawing world 
    //      in order to make sure it is valid:

    vbool tfValid;

    tfValid = VCIsCurrentWorldValid();

    if (tfValid == 0)
    {
        MessageBox(NULL, "Not a valid world", "API Help Sample", MB_ICONEXCLAMATION);

        //  Optional - stop tool from running
    }
    else
    {
        MessageBox(NULL, "Valid world", "API Help Sample", MB_ICONINFORMATION);
    }
}

// C++ to Parse the Database
//   lines starting with a // are comments
void WINAPI ParseDBase(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  Move to the first entity in the drawing data base and 
    //  loop through the database:
    //      The following code demonstrates the proper method for 
    //      implementing these routines to search the drawing 
    //      database:

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  setup some counters
    int iErasedCount = 0;
    int iUnerasedCount = 0;

    //  parse through the entire database:
    //  start at the first entity
    short iKind;
    VCFirstEntity(&iError, &iKind);

    //  loop through entities
    while (iError == 0)
    {
        //  VCFirstEntity() and VCNextEntity() move through the 
        //  database and make each successive entity the current 
        //  entity.  For example, we will process each current 
        //  entity to count the erased and un-erased entities.

        if (VCIsCurrentErased(&iError) == 0)
        {
            iUnerasedCount++;
        }
        else
        {
            iErasedCount++;
        }

        VCNextEntity(&iError, &iKind);
    }

    sprintf_s(sz, sizeof(sz), "Erased count: %d\nUn-Erased count: %d", iErasedCount, iUnerasedCount);
    MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
}

// C++ to Parse a Selection
//   lines starting with a // are comments
void WINAPI ParseSelect(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  Parse through the selection in the database:
    //      A selection is often what the user has selected 
    //      before he starts your tool and the selection is the 
    //      target of the tool for making some modification or 
    //      creating new entities.  In this example, since we 
    //      want it to run self-contained, we will also 
    //      illustrate how to create filtered selections in code.  
    //      The filtering method works with a specialized 
    //      selection filter.

    //  Optional - because we are going to construct our own 
    //  selection using code, we can start by de-selecting any 
    //  existing selection.

    VCDeSelectAll();

    //  Optional - Turn selection highlight off:
    //      Because our tool will be selecting entities, we can 
    //      turn off the selection highlight to avoid the time 
    //      required to redraw the selected entities.  Or we may 
    //      choose to not display the selections to the user.  
    //      The following code turns the selection highlight off:

    VCSetHighlight(&iError, 0);

    //  Optional - Reset the filter:
    //      The application should reset the filter to clear out 
    //      any existing filter information.  By resetting the 
    //      filter an application is assured no other information 
    //      in either the user settings or an application 
    //      settings are used.  The following code resets the 
    //      selection filter:

    VCFilterReset(&iError);

    //  Set the new filter criteria:
    //      The filter can be applied on a variety of entity 
    //      types, names, colors, layers, and widths.  You can 
    //      use any combination of these filter settings.  The 
    //      entity type IDs are presented in the topic Entity 
    //      Types.  The following example demonstrates a filter 
    //      for continuous lines using the SOLID line type 
    //      (index 0):

    VCSetFilterKind(&iError, CONTINUOUSLINE2D);
    VCSetFilterLineType(&iError, 0);

    //  Set the filter active:

    VCSetFilterActive(&iError, 1);

    //  Select the entities:
    //      Since the filter has been set to select specific 
    //      types of entities and/or properties, when you select 
    //      any entities in the database, only those that meet 
    //      the filter criteria will be selected.  The following 
    //      code selects all entities through code:

    VCSelectAll();

    //  Parse the filtered selection:
    //      After setting the filtered selection list in code, or 
    //      optionally processing a selection from the user, 
    //      specialized parsing procedures are available to move 
    //      through the selected entities in the database.  
    //      These parsing routines are analogous to the standard 
    //      parsing routines.  The following code parses through 
    //      the selection list:

    //  setup a counter
    int iCount = 0;

    //  start at the first selected entity
    short iKind;
    VCFirstSelected(&iError, &iKind);

    while (iError == 0)
    {
        //  your tool would do whatever processing is required
        //      for example, count the un-erased lines
        if (VCIsCurrentErased(&iError) == 0)
        {
            iCount++;
        }

        VCNextSelected(&iError, &iKind);
    }

    //  De-select the entities:
    //      The selection list should be cleared after the 
    //      processing has finished.  The following code 
    //      de-selects all the entities in the drawing:

    VCDeSelectAll();

    //  Turn the filter off:

    VCSetFilterActive(&iError, 0);

    //  Optional: Reset the filter:
    //      The filter should be reset after the operation to 
    //      clean up any filter criteria which might appear in 
    //      the user interface.  The following code resets the selection filter:

    VCFilterReset(&iError);

    //  Optional: Turn the highlight display on:
    //      The following code turns the selection highlight on:

    VCSetHighlight(&iError, 1);

    sprintf_s(sz, sizeof(sz), "SOLID continuous line count: %d", iCount);
    MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
}

// C++ to Parse On Screen
//   lines starting with a // are comments
void WINAPI ParseOnScrn(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  Reset the on screen list with the new zoom:
    //      When working with display and zoom related parsing 
    //      methods, the items selection list needs to be reset 
    //      prior to each parsing.  This ensures the current 
    //      zoom, whether changed directly through code or from 
    //      the user interface, is reflected in the on screen 
    //      search.  The following code resets the screen list 
    //      for the current zoom:

    VCResetOnScreenList(&iError);

    //  Parse the list:
    //      The routines to parse the list coincide with standard 
    //      methods of moving from the first item in the list to 
    //      the next until the end of the list is reached.  The 
    //      following code parses the new screen list:

    //  setup a counter
    int iCount = 0;

    //  start at the first selected entity
    short iKind;
    VCFirstOnScreen(&iError, &iKind);

    while (iError == 0)
    {
        //  your tool would do whatever processing is required
        //      for example, count the lines on screen
        if (iKind == CONTINUOUSLINE2D)
        {
            iCount++;
        }

        VCNextOnScreen(&iError, &iKind);
    }

    sprintf_s(sz, sizeof(sz), "SOLID continuous line count: %d", iCount);
    MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
}

// C++ to Parse Expanded Entities
//   lines starting with a // are comments
void WINAPI ParseExpand(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  Parse the expanded list:
    //      The routines to parse the list coincide with standard 
    //      parsing methods of moving from the first item in the 
    //      list to the next until the end of the list is 
    //      reached:

    //  setup a counter
    int iCount = 0;

    //  start at the first expanded entity
    short iKind;
    VCFirstEntityExpand(&iError, &iKind);

    while (iError == 0)
    {
        //  your tool would do whatever processing is required
        //      for example, count the lines in the expanded 
        //      drawing
        if (iKind == CONTINUOUSLINE2D)
        {
            iCount++;
        }

        VCNextEntityExpand(&iError, &iKind);
    }

    sprintf_s(sz, sizeof(sz), "SOLID continuous line count: %d", iCount);
    MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
}

// C++ to Get Entity Properties
//   lines starting with a // are comments
void WINAPI GetEntProp(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  Optional - Save the current drawing settings:
    //      When working with entity properties, it is generally 
    //      desirable to maintain the current settings in a 
    //      temporary buffer and restore the information on 
    //      completion.  This allows the user to continue using 
    //      his original settings without unexpected changes.  
    //      The following code stores the settings into a 
    //      temporary buffer:

    VCSaveSettings();

    //  Parse the list for the desired entity:
    //      The standard parsing structures presented in the 
    //      previous sections are generally used to move through 
    //      the entities or a selection and retrieve the 
    //      properties.  However, in order to retrieve property 
    //      information, an entity need only to be set as current 
    //      within the database.  This can done by the parsing 
    //      methods or directly if the entity handle is known.  
    //      The following code demonstrates setting the current 
    //      entity based on a known ID.  Typically, this ID is 
    //      found through another parsing method.  This example 
    //      sets the current entity as number 0, the first entity 
    //      in the database:

    VCSetCurrentEntity(&iError, 0);

    //  Optional first method - Match the entity properties in 
    //  the settings and use a settings retrieval routine:
    //      This method requires the application to match all the 
    //      entity properties and set them as the drawing 
    //      settings in the user interface.  Typically, when 
    //      using this method, it is good practice to save the 
    //      current user settings prior to processing and then 
    //      return them on exit.  The following code matches the 
    //      current entity properties and retrieves the color 
    //      index corresponding to the entity property:

    VCMatchCurrentEntity(&iError);

    //  for example, retrieve the color index of the current 
    //  entity
    short iColor;
    iColor = VCGetColorIndex(&iColor);

    //  Optional second method - Use a current entity routine to 
    //  get the desired property:
    //      The second method does not require the application to 
    //      retrieve the all entity properties into the drawing 
    //      settings.  The information can be retrieved directly 
    //      from the entity property settings.  The following 
    //      code retrieves the color setting directly from the 
    //      entity property:

    iColor = VCGetCurrentEntityColor(&iError);

    //  Optional - Restore the settings:
    //      When working with entity properties it is generally 
    //      desirable to maintain the current set settings in a 
    //      temporary buffer and restore the information on 
    //      completion.  The following code restores the settings 
    //      from the temporary buffer:

    VCRestoreSettings();

    sprintf_s(sz, sizeof(sz), "First entity color index: %d", iColor);
    MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
}

// C++ to Parse Hatch/Fill Boundary
//   lines starting with a // are comments
void WINAPI ParseBound(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  used for messages
    char sz[64];

    //  Retrieve the ENTITYHANDLE for the hatch or fill entity:
    //      In order to access the boundaries of a hatch or fill 
    //      entity, an application needs to retrieve the handle 
    //      for the entity.  This handle is usually retrieved 
    //      with VCGetCurrEntityHandle after utilizing another 
    //      database parsing routine.  Please see the rest of the 
    //      database parsing section for details on the methods 
    //      available for accessing entity information.  For
    //      example, we will use the first hatch entity in the 
    //      database: 

    //  start at the first entity and look for first hatch
    short iKind;
    VCFirstEntity(&iError, &iKind);
    while ((iError == 0) && (iKind != HATCH2D))
    {
        VCNextEntity(&iError, &iKind);
    }

    //  setup a counter
    short iCount = 0;

    if (iError == 0)
    {
        //  found hatch, save the entity handle
        long hEnt;
        hEnt = VCGetCurrentEntityHandle(&iError);

        //  Set a parsing loop and determine the number of contours 
        //  defining the boundary:
        //      The hatch or fill boundary can be defined by 
        //      multiple paths or contours.  The number of 
        //      contours can be retrieved with the API routine 
        //      VCGetEntityContourCount.  The following example 
        //      returns a count for the number of contours 
        //      defining the entity.  It assumes a known 
        //      entity handle obtained through other database 
        //      parsing methods:

        short iContCount;
        iContCount = VCGetEntityContourCount(&iError, hEnt);

        //  do a parsing loop through all the contours
        for (short iContIndex = 0; iContIndex < iContCount; iContIndex++)
        {
            //  determine the number of sub-entities defining 
            //  each contour
            short iSubCount;
            iSubCount = VCGetEntitySubEntityCount(&iError, hEnt, iContIndex);

            //  do a parsing loop through all the sub-entities of 
            //  each contour
            for (short iEntIndex = 0; iEntIndex < iSubCount; iEntIndex++)
            {
                //  Your tool would do whatever processing is 
                //  required.  For example, if you needed to 
                //  process the sub-entities, you may make the 
                //  sub-entity the current entity by calling 
                //  VCSetCurrentEntitySubEntity.  For example, 
                //  count the total sub-entities:
                iCount++;
            }
        }
    }

    sprintf_s(sz, sizeof(sz), "First hatch total sub-entity count: %d", iCount);
    MessageBox(NULL, sz, "API Help Sample", MB_ICONINFORMATION);
}

// C++ to Apply Settings to an Entity
//   lines starting with a // are comments
void WINAPI ApplySett(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    //  Move to the desired entity(ies) in the database:
    //      This can be done with all the general parsing 
    //      routines or directly with VCSetCurrentEntity.  
    //      See Parsing the Database.  The following code parses
    //      through a selection made by the user before he starts 
    //      the tool:

    //  Save the current settings:
    //      It is generally desirable to save the user settings 
    //      prior to changing the values. These settings can then 
    //      be restored at the end of the tool.  The following 
    //      code saves the current user drawing settings to a 
    //      temporary buffer:

    VCSaveSettings();

    //  start at the first selected entity
    short iKind;
    VCFirstSelected(&iError, &iKind);

    while (iError == 0)
    {
        //  your tool would do whatever processing is required
        //      for example, change entity properties

        //  match all the entity properties
        VCMatchCurrentEntity(&iError);

        //  change only the desired properties:
        //      Note, when using VCApplySettingsToCurrentEntity
        //      you may also change any entity-specific setting, 
        //      such VCSetTextHeight, VCSetLeaderArrowType, etc.  
        //      If so, you should always check the entity type, 
        //      the iKind variable, to verify you have the 
        //      desired entity type.  For example, change color
        //      and line width:
        VCSetColorIndex(&iError, 10);
        VCSetLineWidthIndex(&iError, 1);

        //  Apply the settings to the current entity:
        //      After the new settings have been made, they need 
        //      to be applied to the current entity.  The 
        //      following code applies the new settings to the 
        //      current entity.  This method does not directly 
        //      support undo/redo.  However, when used in 
        //      conjunction with other techniques, the changes 
        //      you make can be undone.  Please refer to the 
        //      Managing Undo and Redo topic.

        VCApplySettingsToCurrentEntity(&iError);

        //  move to the next entity
        VCNextSelected(&iError, &iKind);
    }

    //  Restore the user default settings:
    //      The user settings should be returned to their 
    //      position prior to the operation.  VCRestoreSettings 
    //      resets the settings based on the temporary buffer. 

    VCRestoreSettings();

    //  de-select
    VCDeSelectAll();
}

// C++ to Change Selected with EAttr
//   lines starting with a // are comments
void WINAPI ChangeSel(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  Define the property values for the EAttr structure:
    //      The EAttr structure contains definitions for the 
    //      basic entity properties.  Instead of using individual 
    //      routines to set the layer, color, line type, line 
    //      width, real world line width, and by-layer values, a 
    //      single EAttr structure holds these values.  This 
    //      structure is then passed to the VCChangeSelected 
    //      command to change the property values for the 
    //      entities.  See User Defined Types for definitions of 
    //      EAttr in several programming languages.  The 
    //      following code sets the members of the EAttr 
    //      structure:

    EAttr ea;

    ea.iColor = 9;
    ea.iLayer = 1;
    ea.iLinetype = 0;
    ea.iLinewidth = 1;
    ea.fWidth = 0.0;
    ea.bByLayerFlag = 0;

    //  Change the properties of the selected items:
    //      The routine will automatically change all entities 
    //      in the current selection list.  There is no need to 
    //      parse the database and explicitly recreate the 
    //      entities with the new properties.  Note, 
    //      VCChangeSelected also supports undo/redo.  The 
    //      following code changes the selected entities to the 
    //      defined properties:

    VCChangeSelected(&ea);
}

// C++ to Duplicate Entities with Transformation
//   lines starting with a // are comments
void WINAPI DupEntTrans(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError;

    // construct a point object
    Point2D pt0;
    
    // an entity handle, an index into the drawing database
    long hEnt;
    long hCurrEnt;

    //  Optional - Save the current drawing settings:
    //      When modifying entities, it is generally desirable 
    //      to maintain the current settings in a temporary 
    //      buffer and restore the information on completion.  
    //      This allows the user to continue using his original 
    //      settings without unexpected changes.  The following 
    //      code stores the settings into a temporary buffer:

    VCSaveSettings();

    //  Retrieve the ENTITYHANDLE for the entity to be 
    //  duplicated:
    //      In order to duplicate an entity, an application needs
    //      to retrieve the handle for the entity.  This handle 
    //      is usually retrieved with VCGetCurrEntityHandle after 
    //      utilizing another database parsing routine.  Please 
    //      see the the database parsing section for details on 
    //      the methods available for accessing entity 
    //      information.  For example, we will parse through an 
    //      existing selection.

    //  start at the first selected entity
    short iKind;
    VCFirstSelected(&iError, &iKind);

    while (iError == 0)
    {
        //  your tool would do whatever processing is required
        //      for example, make several duplicates

        //  match all the entity properties
        VCMatchCurrentEntity(&iError);

        //  change only the desired properties:
        //      Note, when using VCDuplicate you may also change 
        //      any entity-specific setting, such 
        //      VCSetTextHeight, VCSetLeaderArrowType, etc.  
        //      If so, you should always check the entity type, 
        //      the iKind variable, to verify you have the 
        //      desired entity type.  For example, change color:

        VCSetColorIndex(&iError, 8);

        //  Get the current entity handle for reference:
        //      Since the duplicated entity is appended to the 
        //      end of the database, it is necessary to keep 
        //      track of the current entity handle so that you 
        //      can quickly move back to the original entity.  
        //      The following code stores the current entity 
        //      handle in a variable:

        hCurrEnt = VCGetCurrentEntityHandle(&iError);
        
        //  Duplicate the entity:
        //      By duplicating the entity, the application is 
        //      recreating the entity with all the new settings.  
        //      The new entity is then appended to the end of the 
        //      database.  The following code duplicates the 
        //      current entity and applies the current settings 
        //      to the new entity:

        VCDuplicate(&iError, hCurrEnt);

        //  Optional - Erase the old entity:
        //      Depending upon the purpose of your tool, it may 
        //      be necessary to erase the old entity from the 
        //      drawing after the new one has been added.   The 
        //      following code moves to the old entity and sets 
        //      it as erased in the database:

        VCSetCurrentEntity(&iError, hCurrEnt);
        VCSetCurrentErased(&iError);
        VCDrawCurrentEntity(&iError);

        //  Draw the new entity:
        VCLastEntity(&iError, &hEnt);
        VCSetCurrentEntity(&iError, hEnt);
        VCDrawCurrentEntity(&iError);

        //  Optional - Instead of a duplicate, we can also apply 
        //  certain transformations to the original entity.  For 
        //  example, VCDuplicateWithTransform, 
        //  VCDuplicateWithRotate, VCDuplicateWithSkew, 
        //  VCDuplicateWithScale, and VCDuplicateWithMove and 
        //  duplicating in the same draw order 
        //  VCDuplicateInDrawOrder and 
        //  VCDuplicateWithTransformInDrawOrder.  For example, to 
        //  duplicate with a move (also called translation):

        pt0.x = 1.0; //  move 1 inch right
        pt0.y = 1.0; //  move 1 inch up
        VCDuplicateWithMove(&iError, hCurrEnt, &pt0, hCurrEnt);

        //  Draw the new entity:
        VCLastEntity(&iError, &hEnt);
        VCSetCurrentEntity(&iError, hEnt);
        VCDrawCurrentEntity(&iError);

        //  The parsing routines move to the next entity after 
        //  the current entity.  Therefore, if code has changed 
        //  the current entity, as it has above to draw the last 
        //  entity, then you must set the current entity back to 
        //  the original before moving to the next entity.
        VCSetCurrentEntity(&iError, hCurrEnt);

        //  move to the next entity
        VCNextSelected(&iError, &iKind);
    }

    //  Restore the user default settings:
    //      The user settings should be returned to their 
    //      position prior to the operation.  VCRestoreSettings 
    //      resets the settings based on the temporary buffer. 

    VCRestoreSettings();
}

#define SBUP_MASK_TEXT  0x01
#define SBUP_MASK_COLOR 0x02
#define SBUP_MASK_BACK  0x04


// C++ to Set a Direct Statusbar User Pane
//   lines starting with a // are comments
void WINAPI DirectUserPane(char* szDllCommandLine)
{
    //  required parameter but unused by this function
    //  circumvent the unreferenced formal parameter warning
    UNUSED_PARAMETER(szDllCommandLine);

    //  used for error returns from the API
    short iError = 0;

    // remember the handle between calls
    static UINT uHandle = 0;

    // if we don't already have a handle, get a handle to the Test user pane, without specifying an addon
    if (uHandle == 0)
    {
        uHandle = VCGetUserPaneHandle(&iError, "Test", "");
    }

    //make sure that we got a valid handle
    if (iError == 0)
    {
        // say Hello, world in red text on a blue background
        VCSetUserPaneWeb(&iError, uHandle, "Hello, world", "red", "blue", SBUP_MASK_TEXT | SBUP_MASK_COLOR | SBUP_MASK_BACK);

        // check that the handle is still valid - reloading the statusbar will invalidate it
        if (iError == 3)
        {
            // get a new handle
            uHandle = VCGetUserPaneHandle(&iError, "Test", "");

            if (iError == 0)
            {
                // try again to set the user pane
                VCSetUserPaneWeb(&iError, uHandle, "Hello, world", "red", "blue", SBUP_MASK_TEXT | SBUP_MASK_COLOR | SBUP_MASK_BACK);
            }
        }
    }
}

