// FontEdit.cpp
//
//Copyright(c) 2018 Gold Run Partners, Inc.

//  standard system includes
#include "stdafx.h"

// project includes
#include "FontEdit.h"
#include "FontEditApp.h"
#include "..\..\Source\VCADDHelper.h"
#include "Utils.h"
#include "FillFontDlg.h"
#include <float.h>

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

extern CFontEditApp theApp;

//	locals
static short  iError;				//  VCADD error code
static short* pErr = &iError;		//	ptr to VCADD error code

short bHoldFillable;

void WINAPI TCFontOpen(char*)
{
    CFileDialog theDlg(TRUE, "VCF", NULL, OFN_HIDEREADONLY, "Font files (*.vcf)|*.vcf|All files (*.*)|*.*||");
    char szMenuPath[MAX_PATH];
    VCGetVCFPath(&iError, szMenuPath);

    theDlg.m_ofn.lpstrInitialDir = szMenuPath;
    if(theDlg.DoModal() == IDOK)
    {
        VCCreateMDIWindow(pErr, 0);
        FontOpen(theDlg.GetPathName().GetBuffer());
    }
}

void WINAPI TCFontSave(char*)
{
    CFileDialog theDlg(FALSE, "VCF", NULL, OFN_OVERWRITEPROMPT, "Font files (*.vcf)|*.vcf|All files (*.*)|*.*||");
    char szMenuPath[MAX_PATH];
    VCGetVCFPath(&iError, szMenuPath);

    theDlg.m_ofn.lpstrInitialDir = szMenuPath;
    if(theDlg.DoModal() == IDOK)
    {
        FontSave(theDlg.GetPathName().GetBuffer(0), theDlg.GetFileTitle().Left(32).GetBuffer(0));
    }
}

/////////////////////////////////////////////////////////////////////////////
//	FontOpen
//
HRESULT WINAPI FontOpen(char* szFileName)
{
    Point2D ptOrigin = { 0.0, 0.0 };  //origin point for character glyph cell
    Point2D pt1, pt2;
    Point2D ptArray[3];
    VCFCharData FontList[256];
    long hEnt;
    char szLabel[256];

    LoadVCF(szFileName, FontList);

    //	general settings
    VCSetUseByLayerProperties(pErr, FALSE, FALSE, FALSE);
    VCSetBackwardsRedraw(pErr, FALSE);

    //	set wait cursor
    VCSetCursor(pErr, "IDC_WAIT");

    //	setup layers
    VCSetLayerIndex(pErr, 0);
    VCSetLayerDisplay(pErr, 0, TRUE);
    VCAddNamedLayer(pErr, "Vector Font");

    VCSetLayerIndex(pErr, 1);
    VCSetLayerDisplay(pErr, 1, TRUE);
    VCAddNamedLayer(pErr, "Guides");

    //	set All layer edit off for Font only
    //	set All snaps on for guides
    VCSetAllLayersEd(pErr, FALSE);
    VCSetAllLayersSnap(pErr, TRUE);

    //	set text characteristics
    VCSetTextAspect(pErr, 1.0);
    VCSetTextBold(pErr, FALSE);
    VCSetTextColor(pErr, 0);
    VCSetTextFontNameAndType(pErr, "Arial", 0);
    VCSetTextCharset(pErr, 0);
    VCSetTextHeight(pErr, 0.125);
    VCSetTextItalic(pErr, FALSE);
    VCSetTextJustify(pErr, 'C');
    VCSetTextLayer(pErr, 1);
    VCSetTextLineSpace(pErr, 1.50);
    VCSetTextRot(pErr, 0.0);
    VCSetTextUnderline(pErr, 0);
    VCSetTextUseByLayerProperties(pErr, FALSE, FALSE, FALSE);

    //	set leader characteristics
    VCSetLeaderArrowAngle(pErr, 15.0);
    VCSetLeaderArrowLength(pErr, 0.125);
    VCSetLeaderArrowMode(pErr, 0);
    VCSetLeaderArrowType(pErr, DIMARROWREGOPEN);
    VCSetLeaderFontNameAndType(pErr, "Architek", 1);
    VCSetLeaderShoulderLength(pErr, 0.125);
    VCSetLeaderTextAspect(pErr, 1.0);
    VCSetLeaderTextBold(pErr, 0);
    VCSetLeaderTextHeight(pErr, 0.125);
    VCSetLeaderTextItalic(pErr, FALSE);
    VCSetLeaderTextLineSpace(pErr, 1.50);
    VCSetLeaderTextOffset(pErr, 0.125);
    VCSetLeaderTextUnderline(pErr, FALSE);
    VCSetLeaderLayer(pErr, 1);

    for (short i = 0; i < 4; i++)
    {
        VCSetLeaderItemColor(pErr, i, 0);
        VCSetLeaderItemLineType(pErr, i, 0);
        VCSetLeaderItemLineWidth(pErr, i, 1);
    }
    VCSetLeaderItemShow(&iError, LEADERTEXT, 1);
    VCSetLeaderItemShow(&iError, LEADERLINE, 1);
    VCSetLeaderItemShow(&iError, LEADERARROW, 1);
    VCSetLeaderItemShow(&iError, LEADERBORDER, 0);

    pt1 = MakePoint(-29.0, -3.5);
    pt2 = MakePoint(57.0, 36.0);
    VCSetWorldZoomWindow(pErr, &pt1, &pt2);

    VCSetTextString(pErr, szFileName);
    VCSetTextHeight(pErr, GRIDHEIGHT / 4.0);
    VCAddTextEntity(pErr, NONDEFENTITY, MakePoint(8 * GRIDWIDTH, -GRIDHEIGHT));
    VCSetTextHeight(pErr, 0.125);
    DrawLastEntity();

    //	draw template with characters
    for (int row = 2; row < 16; row++)
    {
        ptOrigin.y = 15 * GRIDHEIGHT - row * GRIDHEIGHT;  //vertical offset of this row
                                                          //all cell entity vertical positions are relative to this

        //	draw horizontal guides
        pt1.x = -HORZENDLAP;
        pt2.x = 15 * GRIDWIDTH + (BOUNDRIGHT + BOUNDLEFT) + HORZENDLAP;
        VCSetLayerIndex(pErr, 1);
        VCSetLineTypeIndex(pErr, 9);
        VCSetLineWidthIndex(pErr, 1);
        VCSetColorIndex(pErr, 0);
        pt1.y = ptOrigin.y + HORZGUIDE1;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        VCSetLineTypeIndex(pErr, 0);
        VCSetColorIndex(pErr, 10);
        pt1.y = ptOrigin.y + HORZGUIDE2;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        VCSetLineTypeIndex(pErr, 0);
        VCSetColorIndex(pErr, 10);
        pt1.y = ptOrigin.y + HORZGUIDE3;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        VCSetLineTypeIndex(pErr, 12);
        VCSetColorIndex(pErr, 10);
        pt1.y = ptOrigin.y + HORZGUIDE4;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        VCSetLineTypeIndex(pErr, 0);
        VCSetColorIndex(pErr, 10);
        pt1.y = ptOrigin.y + HORZGUIDE5;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        VCSetLineTypeIndex(pErr, 0);
        VCSetColorIndex(pErr, 10);
        pt1.y = ptOrigin.y + HORZGUIDE6;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        VCSetLineTypeIndex(pErr, 9);
        VCSetColorIndex(pErr, 0);
        pt1.y = ptOrigin.y + HORZGUIDE7;
        pt2.y = pt1.y;
        VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
        DrawLastEntity();

        for (int col = 0; col < 16; col++)
        {
            ptOrigin.x = GRIDWIDTH * col; //horizontal offset of this column

            //	draw vertical guides
            if (row == 2)
            {
                pt1.y = -VERTENDLAP;
                pt2.y = 13 * GRIDHEIGHT + BOUNDTOP + (VERTENDLAP + BOUNDBOTTOM);

                VCSetLayerIndex(pErr, 1);
                VCSetLineTypeIndex(pErr, 9);
                VCSetLineWidthIndex(pErr, 1);
                VCSetColorIndex(pErr, 0);
                pt1.x = ptOrigin.x + VERTGUIDE1;
                pt2.x = pt1.x;
                VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
                DrawLastEntity();
            
                VCSetLineTypeIndex(pErr, 12);
                VCSetColorIndex(pErr, 10);
                pt1.x = ptOrigin.x + VERTGUIDE2;
                pt2.x = pt1.x;
                VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
                DrawLastEntity();
            
                VCSetLineTypeIndex(pErr, 9);
                VCSetColorIndex(pErr, 0);
                pt1.x = ptOrigin.x + VERTGUIDE3;
                pt2.x = pt1.x;
                VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
                DrawLastEntity();
            }

            int charIndex = 16 * row + col; //ANSI character index

            //	draw the character glyph
            VCSetLayerIndex(pErr, 0);
            VCSetLineTypeIndex(pErr, 0);
            VCSetLineWidthIndex(pErr, 0);
            VCSetLineWidthValue(pErr, 0.06F);
            VCSetRealWorldLineWidthMode(pErr, TRUE);

            VCSetColorIndex(pErr, 0);
            DrawVCFChar(&FontList[charIndex], &ptOrigin);

            //	draw handle point
            VCSetLineWidthIndex(pErr, 1);
            VCSetLineWidthValue(pErr, 0.0);
            VCSetRealWorldLineWidthMode(pErr, FALSE);
            VCSetLayerIndex(pErr, 1);
            pt1.x = ptOrigin.x + HANDLERADIUS;
            pt1.y = ptOrigin.y;
            VCAddCircleEntity(pErr, NONDEFENTITY, ptOrigin, pt1);
            DrawLastEntity();

            pt1.y = ptOrigin.y + HANDLERADIUS; 
            pt2.x = ptOrigin.x - HANDLERADIUS;
            pt2.y = ptOrigin.y - HANDLERADIUS;
            VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
            DrawLastEntity();

            pt1.y = ptOrigin.y - HANDLERADIUS;
            pt2.y = ptOrigin.y + HANDLERADIUS;
            VCAddLineEntity(pErr, NONDEFENTITY, pt1, pt2);
            DrawLastEntity();

            //	draw bounding rectangle
            VCSetLineTypeIndex(pErr, 0);
            VCSetColorIndex(pErr, 13);
            VCAddContinuousLineEntity(pErr, NONDEFENTITY);
            VCLastEntity(pErr, &hEnt);
            VCSetCurrentEntity(pErr, hEnt);
            VCSetCurrentEntityCloseContour(pErr, TRUE);
            pt2.x = ptOrigin.x + BOUNDLEFT;
            pt2.y = ptOrigin.y + BOUNDBOTTOM;
            VCSetCurrentEntityPoint(pErr, 0, &pt2);
            pt2.x = ptOrigin.x + BOUNDRIGHT;
            VCSetCurrentEntityPoint(pErr, 1, &pt2);
            pt2.y = ptOrigin.y + BOUNDTOP;
            VCSetCurrentEntityPoint(pErr, 2, &pt2);
            pt2.x = ptOrigin.x + BOUNDLEFT;
            VCSetCurrentEntityPoint(pErr, 3, &pt2);
            DrawLastEntity();

            //	label the character
            if (charIndex == 32)
            {
                strcpy(szLabel,"(space)");
            }
            else if (charIndex < 127)
            {
                sprintf(szLabel, "Key: %c", (char)charIndex);
            }
            else
            {
                sprintf(szLabel, "Alt+0%u", charIndex);
            }

            VCSetTextString(pErr, szLabel);
            pt1.x = ptOrigin.x + KEYHORZ;
            pt1.y = ptOrigin.y + KEYVERT;
            VCAddTextEntity(pErr, NONDEFENTITY,	pt1);	
            DrawLastEntity();

            //	draw 'filled' checkbox
            VCSetLineTypeIndex(pErr, 0);
            VCSetColorIndex(pErr, 0);
            VCAddContinuousLineEntity(pErr, NONDEFENTITY);
            VCLastEntity(pErr, &hEnt);
            VCSetCurrentEntity(pErr, hEnt);
            VCSetCurrentEntityCloseContour(pErr, TRUE);
            pt2.x = ptOrigin.x + VERTGUIDE1;
            pt2.y = ptOrigin.y + KEYVERT;
            VCSetCurrentEntityPoint(pErr, 0, &pt2);
            pt2.x += FILLBOX;
            VCSetCurrentEntityPoint(pErr, 1, &pt2);
            pt2.y += FILLBOX;
            VCSetCurrentEntityPoint(pErr, 2, &pt2);
            pt2.x -= FILLBOX;
            VCSetCurrentEntityPoint(pErr, 3, &pt2);
            DrawLastEntity();

            //	label the fill checkbox
            VCSetTextString(pErr, "Fill");
            pt1.x = ptOrigin.x + FILLHORZ;
            pt1.y = ptOrigin.y + KEYVERT;
            VCAddTextEntity(pErr, NONDEFENTITY, pt1);
            DrawLastEntity();

            //	'check' the checkbox
            if (FontList[charIndex].bFillable)
            {
                VCSetLayerIndex(pErr, 0);
                VCSetLineWidthIndex(pErr, 2);
                VCAddContinuousLineEntity(pErr, NONDEFENTITY);
                VCLastEntity(pErr, &hEnt);
                VCSetCurrentEntity(pErr, hEnt);
                VCSetCurrentEntityCloseContour(pErr, FALSE);
                pt2.x = ptOrigin.x + CHECK_X1;
                pt2.y = ptOrigin.y + CHECK_Y1;
                VCSetCurrentEntityPoint(pErr, 0, &pt2);
                pt2.x = ptOrigin.x + CHECK_X2;
                pt2.y = ptOrigin.y + CHECK_Y2;
                VCSetCurrentEntityPoint(pErr, 1, &pt2);
                pt2.x = ptOrigin.x + CHECK_X3;
                pt2.y = ptOrigin.y + CHECK_Y3;
                VCSetCurrentEntityPoint(pErr, 2, &pt2);
                DrawLastEntity();
            }
        }
    }

    VCSetColorIndex(pErr, 0);
    VCSetLineWidthIndex(pErr, 1);

    VCSetLeaderString(pErr, "character bounding box");
    ptArray[0] = MakePoint(BOUNDLEFT, 12 * GRIDHEIGHT + (HORZGUIDE3 + HORZGUIDE4) / 2);
    ptArray[1] = MakePoint(LEADARROW, 12 * GRIDHEIGHT + (HORZGUIDE3 + HORZGUIDE4) / 2 + LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 12 * GRIDHEIGHT + (HORZGUIDE3 + HORZGUIDE4) / 2 + LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLeaderString(pErr, "character handle point");
    ptArray[0] = MakePoint(0.0, 11 * GRIDHEIGHT);
    ptArray[1] = MakePoint(LEADARROW, 11 * GRIDHEIGHT + LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 11 * GRIDHEIGHT + LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLeaderString(pErr, "typical uppercase");
    ptArray[0] = MakePoint(-HORZENDLAP, 10 * GRIDHEIGHT + HORZGUIDE7);
    ptArray[1] = MakePoint(LEADARROW, 10 * GRIDHEIGHT + HORZGUIDE7 - LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 10 * GRIDHEIGHT + HORZGUIDE7 - LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLeaderString(pErr, "");
    ptArray[0] = MakePoint(-HORZENDLAP, 10 * GRIDHEIGHT + HORZGUIDE2);
    ptArray[1] = MakePoint(LEADARROW, 10 * GRIDHEIGHT + HORZGUIDE7 - LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 10 * GRIDHEIGHT + HORZGUIDE7 - LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLeaderString(pErr, "typical lowercase");
    ptArray[0] = MakePoint(-HORZENDLAP, 9 * GRIDHEIGHT + HORZGUIDE6);
    ptArray[1] = MakePoint(LEADARROW, 9 * GRIDHEIGHT + HORZGUIDE6 - LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 9 * GRIDHEIGHT + HORZGUIDE6 - LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLeaderString(pErr, "");
    ptArray[0] = MakePoint(-HORZENDLAP, 9 * GRIDHEIGHT + HORZGUIDE2);
    ptArray[1] = MakePoint(LEADARROW, 9 * GRIDHEIGHT + HORZGUIDE6 - LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 9 * GRIDHEIGHT + HORZGUIDE6 - LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLeaderString(pErr, "typical descender");
    ptArray[0] = MakePoint(-HORZENDLAP, 8 * GRIDHEIGHT + HORZGUIDE1);
    ptArray[1] = MakePoint(LEADARROW, 8 * GRIDHEIGHT + HORZGUIDE1 + LEADRISE);
    ptArray[2] = MakePoint(LEADSHOULDER, 8 * GRIDHEIGHT + HORZGUIDE1 + LEADRISE);
    VCAddLeaderEntity(pErr, NONDEFENTITY, ptArray, 3);
    DrawLastEntity();

    VCSetLayerIndex(pErr, 0);
    VCSetLineTypeIndex(pErr, 0);

    //	remove wait cursor
    VCSetCursor(pErr, NULL);

    VCSetDrawingDirty(pErr, FALSE);
    VCZoomAll();

    return NOERROR;
}

/////////////////////////////////////////////////////////////////////////////
//	FontSave
//
HRESULT WINAPI FontSave(char* szFileName, char* szFontName)
{
    Point2D ptOrigin = { 0.0, 0.0 }; //origin point for character glyph cell
    Point2D pt1, pt2;
    VCFCharData FontList[256];
    long hEnt;

    //	run the FillFont dialog
    CFillFontDlg dlg(theApp.m_pMainWnd);
    if (dlg.DoModal() == IDCANCEL)
    {
        return NOERROR;
    }
        
    //	set wait cursor
    VCSetCursor(pErr, "IDC_WAIT");

    //	set the font layer
    VCSetLayerIndex(pErr, 0);
    VCSetAllLayersEd(pErr, 0);
    
    //	stow template with characters
    for (int row = 2; row < 16; row++)
    {
        ptOrigin.y = 15 * GRIDHEIGHT - GRIDHEIGHT * row;

        for (int col = 0; col < 16; col++)
        {
            //	get handle
            ptOrigin.x = GRIDWIDTH * col;

            //	get the fill checkbox
            if (dlg.m_iChecked == IDC_FILL_ALL)
            {
                bHoldFillable = TRUE;
            }
            else if (dlg.m_iChecked == IDC_FILL_NONE)
            {
                bHoldFillable = FALSE;
            }
            else
            {
                //	select window
                VCClearSelection();
                pt1.x = ptOrigin.x + VERTGUIDE1;
                pt1.y = ptOrigin.y + KEYVERT;
                pt2.x = pt1.x + FILLBOX;
                pt2.y = pt1.y + FILLBOX;
                VCWindowSelect(&pt1, &pt2);

                //	check for a selection inside checkbox
                if (VCGetSelectionCount(pErr))
                {
                    bHoldFillable = TRUE;
                }
                else
                {
                    bHoldFillable = FALSE;
                }
            }

            //	select window
            VCClearSelection();

            //	draw a selection highlight window
            VCAddContinuousLineEntity(pErr, NONDEFENTITY);
            
            VCLastEntity(pErr, &hEnt);
            VCSetCurrentEntity(pErr, hEnt);
            
            pt1.x = ptOrigin.x + BOUNDLEFT;
            pt1.y = ptOrigin.y + BOUNDBOTTOM;
            pt2 = AddPoint2D(&ptOrigin, &pt1);
            VCSetCurrentEntityPoint(pErr, 0, &pt1);
            pt1.x = ptOrigin.x + BOUNDRIGHT;
            VCSetCurrentEntityPoint(pErr, 1, &pt1);
            pt1.y = ptOrigin.y + BOUNDTOP;
            VCSetCurrentEntityPoint(pErr, 2, &pt1);
            pt1.x = ptOrigin.x + BOUNDLEFT;
            VCSetCurrentEntityPoint(pErr, 3, &pt1);

            VCSetCurrentEntityCloseContour(pErr, TRUE);
            
            VCSetCurrentSelected(pErr);
            VCSetFillColor(pErr, VCGetSelectionColor(pErr));
            VCFillSelected();
            VCSetCurrentErased(pErr);
            VCLastEntity(pErr, &hEnt);

            //pt1 is already BOUNDLEFT, BOUNDTOP
            pt2.x = ptOrigin.x + BOUNDRIGHT;
            pt2.y = ptOrigin.y + BOUNDBOTTOM;
            VCWindowSelect(&pt1, &pt2);

            //	save the character
            StowVCFChar((short)(16 * row + col), &FontList[16 * row + col], &ptOrigin, FALSE);

            //	delete the fill highlight
            VCSetCurrentEntity(pErr, hEnt);
            VCSetCurrentErased(pErr);
        }
    }

    short iKind;
    Point2D ptText = { 8 * GRIDWIDTH, -GRIDHEIGHT };
    VCSaveSettings();
    VCClearSelection();
    VCSetAllLayersEd(pErr, TRUE);
    VCObjectSelect(&ptText);
    VCSetTextAspect(pErr, 1.0);
    VCSetTextBold(pErr, FALSE);
    VCSetTextColor(pErr, 0);
    VCSetTextFontNameAndType(pErr, "Arial", 0);
    VCSetTextCharset(pErr, 0);
    VCSetTextItalic(pErr, FALSE);
    VCSetTextJustify(pErr, 'C');
    VCSetTextLayer(pErr, 1);
    VCSetTextLineSpace(pErr, 1.50);
    VCSetTextRot(pErr, 0.0);
    VCSetTextUnderline(pErr, FALSE);
    VCSetTextUseByLayerProperties(pErr, FALSE, FALSE, FALSE);
    VCSetTextHeight(pErr, GRIDHEIGHT / 4.0);
    VCSetTextString(pErr, szFileName);
    if (VCFirstSelected(pErr, &iKind) && (iKind == TEXT2D))
    {
        //	erase existing filename
        VCSetCurrentErased(pErr);
    }
    //	add the filename
    VCAddTextEntity(pErr, NONDEFENTITY, ptText);
    VCRestoreSettings();
    
    SaveVCF(szFileName, szFontName, FontList);
    
    //	remove wait cursor and refresh
    VCZoomRegen();
    VCSetCursor(pErr, NULL);

    VCSetDrawingDirty(pErr, (VCGetDrawingName(NULL) != 0));

    return NOERROR;
}

/////////////////////////////////////////////////////////////////////////////

void GetCharacterBounds(VCFCharData* rec, fPoint2D fpHandle, BOOL tfHandle)
{
    fPoint2D fp;
    short iCount;

    short i;
    short iMax;
    short iStep = 32;
    double dStep = 1.0 / iStep;
    Point2D* pPt;
    
    switch (VCGetCurrentEntityKind(pErr))
    {
    case ARC2D:
    case CIRCLE2D:
    case ELLIPSE2D:
    case ELLIPTICALARC2D:
    case BEZIER2D:
        iMax = iStep + 2;		//	iStep + 1 is exact;
                                //	one more for possible round-off of dStep
        pPt = new Point2D[iMax];
        VCGeneratePointsFromCurrentEntity(pErr, pPt, &iCount, iMax, dStep);
        break;

    case MINTERPCURV2D:
    case CONTINUOUSBEZIER2D: // supported by conversion to spline
        iMax = VCGetCurrentEntityPointCount(pErr);
        iMax = ((iMax - 1) / 3) * (iStep + 2);
        pPt = new Point2D[iMax];
        VCGeneratePointsFromCurrentEntity(pErr, pPt, &iCount, iMax, dStep);
        break;
    
    case LINE2D:
    case CONTINUOUSLINE2D:
//	case POINT2D:	//	not supported
        iCount = VCGetCurrentEntityPointCount(pErr);
        pPt = new Point2D[iCount];
        for (i = 0; i < iCount; i++)
        {
             pPt[i] = VCGetCurrentEntityPoint(pErr, i);
        }
        break;
        
    default:
        pPt = NULL;
        iCount = 0;
    }

    for (short j = 0; j < iCount; j++)
    {
        fp = fPtFromPt(pPt[j]);
        fp.x -= fpHandle.x;
        fp.y -= fpHandle.y;
    
        if (fp.x < rec->fpMin.x)   // new minimum X point
            rec->fpMin.x = fp.x;

        if (fp.x > rec->fpMax.x)   // new maximum X point
            rec->fpMax.x = fp.x;

        if (fp.y < rec->fpMin.y)   // new minimum Y point
            rec->fpMin.y = fp.y;

        if (fp.y > rec->fpMax.y)   // new maximum Y point
            rec->fpMax.y = fp.y;

    }

    //	patch for zero-width characters
    if (rec->fpMin.x == rec->fpMax.x)   // new maximum X point inc. by 0.01
        rec->fpMax.x += 0.01F;

    if (tfHandle)
    {
        //	set left-extent to handle
        if (rec->fpMin.x > 0.0)
            rec->fpMin.x = 0.0;
    }

    delete [] pPt;
}

/////////////////////////////////////////////////////////////////////////////

BOOL LoadVCF(char *szFullPath, VCFCharData FontList[])
{
    FILE* fpin;
    WORD w;
    VCFHeader hdr;
    VCFCharRecord rec;
    VCFEntityData* ep;
    short iEntityCnt;

    // open file here
    fpin = fopen(szFullPath, "rb");

    if (!fpin)
    {
        char szTmp[2 * MAX_PATH];
        sprintf(szTmp, "Unable to open font file '%s'!", szFullPath);
        ErrMsg(szTmp, "Load Error");
        return FALSE;
    }

    // Read font header
    if (!fread(&hdr, sizeof(VCFHeader), 1, fpin))
    {
        ErrMsg("Unable to read font header!", "Read Error");
        fclose(fpin);
        return FALSE;
    }

    // Check version number
    if (hdr.bVersion != 1)
    {
        ErrMsg("Cannot read this type of font file!", "Read Error");
        fclose(fpin);
        return FALSE;
    }

    VCSetCursor(pErr, "IDC_WAIT");

    // read character definitions
    while (ferror(fpin) == 0)
    {
        fread(&rec, sizeof(VCFCharRecord), 1, fpin);

        // 	check for terminator character and quit loop when found
        if (rec.ch == 0)
        {
            break;
        }

        FontList[rec.ch].ch = rec.ch;
        FontList[rec.ch].bFillable = rec.bFillable;
        FontList[rec.ch].fpMin = rec.fpMin;
        FontList[rec.ch].fpMax = rec.fpMax;
        FontList[rec.ch].nEntities = 0;
        FontList[rec.ch].pLast = NULL;
        FontList[rec.ch].pNext = NULL;
        FontList[rec.ch].tfDefined = TRUE;

        // read the entities for the character glyph
        iEntityCnt = 0;
        while (ferror(fpin) == 0)
        {
            fread(&w, sizeof(WORD), 1, fpin);
            BYTE kind = LOBYTE(w);  //entity kind
            BYTE bCnt = HIBYTE(w);  //number of points for the entity

            // check for end of character flag
            if (kind == ENDOFCHAR)
            {
                break;
            }

            if (kind != 0)
            {
                if (bCnt > 0)
                {
                    iEntityCnt++;
                    ep = new VCFEntityData;
                    ep->bKind = kind;
                    ep->nPoints = bCnt;
                    ep->Points = new fPoint2D[bCnt];
                    fread(ep->Points, sizeof(fPoint2D), ep->nPoints, fpin);

                    ep->pNext = NULL;

                    if (FontList[rec.ch].pLast != NULL)
                        FontList[rec.ch].pLast->pNext = ep;  // already has nodes
                    else
                        FontList[rec.ch].pNext = ep;		 // starting of node list

                    FontList[rec.ch].pLast = ep;
                }
            }
        }

        FontList[rec.ch].nEntities = iEntityCnt;
    }

    fclose(fpin);

    VCSetCursor(pErr, NULL);

    return TRUE;
}

/////////////////////////////////////////////////////////////////////////////

BOOL SaveVCF(char *szFullPath, char *szFontName, VCFCharData FontList[])
{
    FILE* fpout;
    WORD w;
    VCFHeader hdr;
    VCFCharRecord rec;
    
    // open file here
    fpout = fopen(szFullPath, "wb");
    if (!fpout)
    {
        char szTmp[2 * MAX_PATH];
        sprintf(szTmp, "Unable to write font file '%s'!", szFullPath);
        ErrMsg(szTmp, "Save Error");
        return FALSE;
    }

    hdr.bVersion = 1;
    hdr.nChars = 256;
    memset(hdr.szFont, 0, sizeof(hdr.szFont));
    strcpy(hdr.szFont, szFontName);
  
    // Write font header
    if (!fwrite(&hdr, sizeof(VCFHeader), 1, fpout))
    {
        ErrMsg("Unable to write font header!", "Write Error");
        fclose(fpout);
        return FALSE;
    }

    VCSetCursor(pErr, "IDC_WAIT");

    VCFEntityData* ep;
    for (short j = 0; j < 256; j++)
    {
        if (FontList[j].pNext != NULL)
        {
            rec.ch = FontList[j].ch;
            rec.bFillable = FontList[j].bFillable;
            rec.fpMin = FontList[j].fpMin;
            rec.fpMax = FontList[j].fpMax;

            if (!fwrite(&rec, sizeof(VCFCharRecord), 1, fpout))
            {
                ErrMsg("Unable to write font record!", "Write Error");
                fclose(fpout);
                SetCursor(LoadCursor(NULL, IDC_ARROW));
                return FALSE;
            }

            ep = FontList[j].pNext;
            while (ep != NULL)
            {
                w = MAKEWORD(ep->bKind, ep->nPoints);
                fwrite(&w, sizeof(WORD), 1, fpout);
                if (ep->nPoints != NULL)
                    fwrite(ep->Points, sizeof(fPoint2D), ep->nPoints, fpout);
                ep = ep->pNext;
            }

            w = MAKEWORD(ENDOFCHAR, 0);	   // EOC = 99
            fwrite(&w, sizeof(WORD), 1, fpout);
        }
    }

    //only rec.ch = 0 is required for terminating character, but clear the entire character record anyway
    memset(&rec, 0, sizeof(rec));
    fwrite(&rec, sizeof(VCFCharRecord), 1, fpout);

    fclose(fpout);
    VCSetCursor(pErr, NULL);
    return TRUE;
}

/////////////////////////////////////////////////////////////////////////////

void DrawVCFChar(VCFCharData* lpCharRec, Point2D* lpPtHandle)
{
    Point2D pt0;
    Point2D pt1;
    Point2D pt2;
    Point2D pt3;
    Point2D pt4;
    Point2D pt5;
    Point2D pt6;
    short i;
    VCFEntityData* ep;
    ENTITYHANDLE hEnt;

    ep = lpCharRec->pNext;

    while (ep != NULL)  // step through entities as long as not NULL
    {
        switch (ep->bKind)
        {
            case LINE2D:
                pt0 = PtFromfPt(ep->Points[0]);
                pt1 = PtFromfPt(ep->Points[1]);
                VCAddLineEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0),
                    AddPoint2D(lpPtHandle, &pt1));
                break;
            case ARC2D:
                pt0 = PtFromfPt(ep->Points[0]);
                pt1 = PtFromfPt(ep->Points[1]);
                pt2 = PtFromfPt(ep->Points[2]);
                VCAddArcEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0),
                    AddPoint2D(lpPtHandle, &pt1),
                    AddPoint2D(lpPtHandle, &pt2));
                break;
            case CIRCLE2D:
                pt0 = PtFromfPt(ep->Points[0]);
                pt1 = PtFromfPt(ep->Points[1]);
                VCAddCircleEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0),
                    AddPoint2D(lpPtHandle, &pt1));
                break;
            case ELLIPSE2D:
                pt0 = PtFromfPt(ep->Points[0]);
                pt1 = PtFromfPt(ep->Points[1]);
                pt2 = PtFromfPt(ep->Points[2]);
                pt3 = PtFromfPt(ep->Points[3]);
                VCAddEllipseEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0),
                    AddPoint2D(lpPtHandle, &pt1),
                    AddPoint2D(lpPtHandle, &pt2),
                    AddPoint2D(lpPtHandle, &pt3));
                break;
            case BEZIER2D:
                pt0 = PtFromfPt(ep->Points[0]);
                pt1 = PtFromfPt(ep->Points[1]);
                pt2 = PtFromfPt(ep->Points[2]);
                pt3 = PtFromfPt(ep->Points[3]);
                VCAddBezierEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0),
                    AddPoint2D(lpPtHandle, &pt1),
                    AddPoint2D(lpPtHandle, &pt2),
                    AddPoint2D(lpPtHandle, &pt3));
                break;
/*			case POINT2D:	//	not in VCF, but used as handle
                pt0 = PtFromfPt(ep->Points[0]);
                VCAddPointEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0));
                break;*/
            case MINTERPCURV2D:
                VCAddSplineEntity(pErr, -1);
                VCLastEntity(pErr, &hEnt);
                VCSetCurrentEntity(pErr, hEnt);
                for( i = 0; i < ep->nPoints; i++)
                {
                    pt0 = PtFromfPt(ep->Points[i]);
                    pt1 = AddPoint2D(lpPtHandle, &pt0);
                    VCSetCurrentEntityPoint(pErr, i, &pt1);
                }
                break;
            case ELLIPTICALARC2D:
                pt0 = PtFromfPt(ep->Points[0]);
                pt1 = PtFromfPt(ep->Points[1]);
                pt2 = PtFromfPt(ep->Points[2]);
                pt3 = PtFromfPt(ep->Points[3]);
                pt4 = PtFromfPt(ep->Points[4]);
                pt5 = PtFromfPt(ep->Points[5]);
                pt6 = PtFromfPt(ep->Points[6]);
                VCAddEllipticalArcEntity(pErr, -1,
                    AddPoint2D(lpPtHandle, &pt0),
                    AddPoint2D(lpPtHandle, &pt1),
                    AddPoint2D(lpPtHandle, &pt2),
                    AddPoint2D(lpPtHandle, &pt3),
                    AddPoint2D(lpPtHandle, &pt4),
                    AddPoint2D(lpPtHandle, &pt5),
                    AddPoint2D(lpPtHandle, &pt6));
                break;
            case CONTINUOUSLINE2D:
                VCAddContinuousLineEntity(pErr, -1);
                VCLastEntity(pErr, &hEnt);
                VCSetCurrentEntity(pErr, hEnt);
                for( i = 0; i < ep->nPoints; i++)
                {
                    pt0 = PtFromfPt(ep->Points[i]);
                    pt1 = AddPoint2D(lpPtHandle, &pt0);
                    VCSetCurrentEntityPoint(pErr, i, &pt1);
                }
                break;
            case SYMBOL2D:
                break;
            case TEXT2D:
                break;
            case DIMLINEAR2D:
                break;
            case DIMANGULAR2D:
                break;
            case DIMRADIAL2D:
                break;
            case DIMDIAMETER2D:
                break;
            case FILL2D:
                break;
            case HATCH2D:
                break;
            case ATTRIBUTE2D:
                break;
            case LEADER2D:
                break;
            default:
                break;
        }

        DrawLastEntity();
        
        ep = ep->pNext;  // step to next entity
    } 
}

/////////////////////////////////////////////////////////////////////////////

void StowVCFChar(short iChr, VCFCharData* lpCharRec, Point2D* lpPtHandle, BOOL tfHandle)
{
    short bKind;
    VCFEntityData* ep;
    short iEntityCnt = 0;

    fPoint2D fpHandlePt = fPtFromPt(*lpPtHandle);

    if (VCFirstSelected(pErr, &bKind))
    {
        lpCharRec->ch = (BYTE)iChr;
        lpCharRec->bFillable = bHoldFillable;

        do
        {
            switch (bKind)
            {
                case CONTINUOUSBEZIER2D:
                    bKind = MINTERPCURV2D;   //Continuous Beziers are not used in VCF fonts, but splines are equivalent
                case ARC2D:
                case CIRCLE2D:
                case ELLIPSE2D:
                case ELLIPTICALARC2D:
                case BEZIER2D:
                case MINTERPCURV2D:
                case LINE2D:
                case CONTINUOUSLINE2D:
                {
                    iEntityCnt++;
                    ep = new VCFEntityData;
                    ep->bKind = (BYTE)bKind;
                    ep->nPoints = VCGetCurrentEntityPointCount(pErr);
                    ep->Points = new fPoint2D[ep->nPoints];

                    for (short j = 0; j < ep->nPoints; j++)
                    {
                        ep->Points[j] = fPtFromPt(VCGetCurrentEntityPoint(pErr, j));

                        //Translate point based on user-selected handle point
                        ep->Points[j].x -= fpHandlePt.x;
                        ep->Points[j].y -= fpHandlePt.y;
                    }

                    GetCharacterBounds(lpCharRec, fpHandlePt, tfHandle);

                    ep->pNext = NULL;
                    if (lpCharRec->pLast != NULL)
                        lpCharRec->pLast->pNext = ep;  // already has nodes
                    else
                        lpCharRec->pNext = ep;		// starting of node list

                    lpCharRec->pLast = ep;
                }
                break;
                default:
                    break;
            }
        } while (VCNextSelected(pErr, &bKind));

        lpCharRec->nEntities = iEntityCnt;

        lpCharRec->tfDefined = TRUE;
    }
}

VCFCharData::VCFCharData()
{
    ch = 0;
    tfDefined = FALSE;
    bFillable = FALSE;
    fpMin.x = FLT_MAX;
    fpMin.y = FLT_MAX;
    fpMax.x = -FLT_MAX;
    fpMax.y = -FLT_MAX;
    nEntities = 0;
    pLast = NULL;
    pNext = NULL;
}

VCFCharData::~VCFCharData()
{
    delete pNext;
}

VCFEntityData::~VCFEntityData()
{
    delete[] Points;
    delete pNext; //recursively delete all of the associated entities
}
