// VCADDTools.cpp: MFCDLL_Example
//

#include "stdafx.h"
#include "VCADDTools.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

///////////////////////////////////////
// Functions 
///////////////////////////////////////
//======================================================================================
void WINAPI TogglePointDisplay(char* szDllCommandLine) // Toggle Point display On & Off
//======================================================================================
{                   
	// circumvent the unreferenced formal parameter warning
	UNUSED_PARAMETER(szDllCommandLine);

	// The API calls used in this function are compatable with all versions of Visual CADD	
	short	iError;	
	vbool	vbState;
	
	// get the current state, flip its' value and reset it
	vbState = !(VCGetPointDisplay(&iError));
	
	VCSetPointDisplay(&iError, vbState);
	
	// redraw the screen to make the changes show up
	VCInvalidateRect();

}

// Toggle the back ground color between white and it original color
//======================================================================================
void WINAPI ToggleBackgroundColor(char* szDllCommandLine) 
//======================================================================================
{
	// circumvent the unreferenced formal parameter warning
	UNUSED_PARAMETER(szDllCommandLine);
	
	// use a static varible to hold the previous background color index
	static short giPreviousColorIndex = MAX_SYSTEM_COLOR_INDEX;
	
	// the API calls used in this function are only fully compatable with
	// Visual CADD version 5.0.1.0 and above so we need to do a version check
	if(MinimumVCADDVersionCheck(5, 0, 1, 0))
	{	
		short	iError;
		short iNewColorIndex = MIN_VCADD_COLOR_INDEX;
		short iWhiteColorIndex = MAX_SYSTEM_COLOR_INDEX;
		
		// since the color pallet is user customizable we
		// need to find the index for white dynamically 
		COLORREF crWhite = RGB(255,255,255); // the RGB value for white
		for(int i = MIN_VCADD_COLOR_INDEX; i <= MAX_SYSTEM_COLOR_INDEX; i++)
		{					
			if(VCGetColorRef(&iError, (short)i) == crWhite)
			{
				// there may be more then white defined in the pallet
				// if there is we want the closest to MAX_SYSTEM_COLOR_INDEX
				// which is the standard index for white 
				iWhiteColorIndex = (short)i;
			}
		}
		
		short iCurrentColor = VCGetBackgroundColor(&iError);
		
		// set the background to white if its not currently white
		if(iCurrentColor != iWhiteColorIndex)
		{		
			iNewColorIndex = iWhiteColorIndex;
		}
		
		// if its not white we will try to restore the previous color
		else
		{
			iNewColorIndex = giPreviousColorIndex;
		}	
		
		// if the new color and the previous color are the same then
		// either the background color started as white or the user 
		// changed the background color before we restored it
		// either way we need to do something 
		if(iNewColorIndex == iCurrentColor)
		{
			// if the colors match we will flip the index 
			// so the user sees some action on the screen
			iNewColorIndex = (short)((iNewColorIndex - 15) * (-1));
		}
		
		giPreviousColorIndex = iCurrentColor;
		VCSetBackgroundColor(&iError, iNewColorIndex);
	}
}

