/*SDOC*************************************************************

  Module: CmdID.h

  Copyright (C) 2019 Gold Run Partners, Inc.  All rights reserved.
  
  Description: Visual CADD command and message IDs

  Revision Record:

  Version     Changes & Additions
  ========    =====================================================
  3.0.0       Search: "version 3.0.0"
  4.0.0       Search: "version 4.0.0"
  4.0.4       Search: "version 4.0.4"
  4.0.5       Search: "version 4.0.5"
  5.0.0       Search: "version 5.0.0"
  5.0.1       Search: "version 5.0.1"
  6.0.0       Search: "version 6.0.0"
  6.0.1       Search: "version 6.0.1"
  7.0.0       Search: "version 7.0.0"
  8.0.0       Search: "version 8.0.0"
  9.0.0       Search: "version 9.0.0"

*************************************************************EDOC*/
#ifndef CMDID_H_INCLUDED
#define CMDID_H_INCLUDED

// FILE Section
// all tool commands defined between  CMD_ToolBase & CMD_ToolBaseEnd

//======================================   SETTINGS    =================================================
//======================================   SETTINGS    =================================================
//======================================   SETTINGS    =================================================
#define SettingBase                       1100
#define TOKENSETTINGFIRST                 1100
#define FIRSTVALIDTOKEN                   1100


// Symbol Tokens
#define CMD_SymClr                        1101
#define CMD_SymNm                         1102
#define CMD_SymRot                        1103
#define CMD_SymSc                         1104
#define CMD_SymScX                        1105
#define CMD_SymScY                        1106
#define CMD_Echo                          1107  // Added version 8.0.0
#define CMD_SubstText                     1108  // Added version 8.0.0 

// Text Tokens
#define CMD_TextChSp                      1109
#define CMD_TextClr                       1110
#define CMD_TextLay                       1111
#define CMD_TextLnSp                      1112
#define CMD_TextJust                      1113
#define CMD_TextHt                        1114
#define CMD_TextRot                       1115
#define CMD_TextAsp                       1116
#define CMD_TextBold                      1117
#define CMD_TextItalic                    1118
#define CMD_TextFont                      1119
#define CMD_TextStr                       1120
#define CMD_TextFracHt                    1121  // Added version 8.0.0
#define CMD_TextUnicode                   1122  // Added version 8.0.0

// Draw Setting Tokens
#define CMD_GridX                         1123
#define CMD_GridY                         1124
#define CMD_OrthoAngleVar                 1125
#define CMD_FilletRVar                    1126

// OPEN_NUMBERS

#define CMD_SnapHatchPoints               1128 // Added version 8.0.0
#define CMD_SymSnapOn                     1129
#define CMD_DrawColor                     1130
#define CMD_DrawWidth                     1131
#define CMD_DrawLayer                     1132
#define CMD_DrawLtype                     1133
#define CMD_AutoFilletOn                  1134
#define CMD_AutoFilletOff                 1135
#define CMD_SolidOn                       1136
#define CMD_SolidOff                      1137
#define CMD_WallWidth1                    1138
#define CMD_WallWidth2                    1139
#define CMD_RPolySides                    1140
#define CMD_RPolyInscribeOn               1141
#define CMD_RPolyInscribeOff              1142
#define CMD_OrthoOn                       1143
#define CMD_OrthoOff                      1144
#define CMD_CursorFreeOn                  1145
#define CMD_CursorFreeOff                 1146
#define CMD_IncSnapOn                     1147
#define CMD_IncSnapOff                    1148
#define CMD_TrapAng                       1149
#define CMD_IncSnapSize                   1150
#define CMD_MOMode                        1151
#define CMD_MBMode                        1152
#define CMD_MRMode                        1153
#define CMD_FilletPreviewOn               1154
#define CMD_FilletPreviewOff              1155
#define CMD_OffsetFixed                   1156
#define CMD_OffsetUnFixed                 1157
#define CMD_ChamferDist1                  1158
#define CMD_ChamferDist2                  1159
#define CMD_OffsetDist                    1160
#define CMD_PercentSnapVal                1161

// Mod Setting Tokens
#define CMD_MCNumCopies                   1162
#define CMD_MCRadCopies                   1163
#define CMD_MCNumRows                     1164
#define CMD_MCScale                       1165
#define CMD_MCAngle                       1166
#define CMD_MCSpanAngle                   1167
#define CMD_MCScaleXY                     1168
#define CMD_MCScaleX                      1169
#define CMD_MCScaleY                      1170

#define CMD_SymSnapOff                    1171
#define CMD_AllLayerEdOn                  1172
#define CMD_AllLayerEdOff                 1173
#define CMD_AllLayerSnapOn                1174
#define CMD_AllLayerSnapOff               1175

#define CMD_SetColor                      1176
#define CMD_SetLtype                      1177
#define CMD_SetLayer                      1178
#define CMD_SetWidth                      1180

#define CMD_UIOff                         1181
#define CMD_UIOn                          1182

#define CMD_HatchNm                       1183
#define CMD_HatchScale                    1184
#define CMD_HatchRot                      1185
#define CMD_HatchColor                    1186
#define CMD_DrawHBnd                      1187
#define CMD_FillColor                     1188
#define CMD_DrawFBnd                      1189

#define CMD_ExeName                       1190
#define CMD_ExplodeCLines                 1191
#define CMD_LTScaleW                      1192
#define CMD_LTScaleD                      1193
#define CMD_DllRunName                    1194
#define CMD_DllRunFunctionName            1195
#define CMD_DllRunCmdLine                 1196
#define CMD_OleDllName                    1197
#define CMD_OleClassName                  1198
#define CMD_OleFunctionName               1199

#define CMD_FileName                      1200
#define CMD_ScrollBar                     1201
#define CMD_OleCmdLine                    1202

#define CMD_IsoMode                       1203
#define CMD_IsoPlane                      1204 //Added version 6.0.0
//#define CMD_IsoLeft                     1204 //Version 6.0.0 moved to tools section
//#define CMD_IsoRight                    1205 //Version 6.0.0 moved to tools section
//#define CMD_IsoTop                      1206 //Version 6.0.0 moved to tools section
/*
#define CMD_IsoLeft                       1204  //  Changed and moved to command range version 6.0.0
#define CMD_IsoRight                      1205  //  Changed and moved to command range version 6.0.0
#define CMD_IsoTop                        1206  //  Changed and moved to command range version 6.0.0
*/

#define CMD_LengthVar                     1205  // Added version 8.0.0
#define CMD_AngleVar                      1206  // Added version 8.0.0
#define CMD_SetMultiLineStyle             1207  // Added version 4.0.0
#define CMD_SetRealWidth                  1208  // Added version 5.0.0
#define CMD_LargeIcons                    1209  // Added version 5.0.1

// Paths
#define CMD_SYSPath                       1210
#define CMD_VCDPath                       1211
#define CMD_VCSPath                       1212
#define CMD_VCFPath                       1213
#define CMD_DWGPath                       1214
#define CMD_DXFPath                       1215

#define CMD_MCSkewAngle                   1216  // Added version 6.0.0
#define CMD_HatchScaleX                   1217  // Added version 6.0.0
#define CMD_HatchScaleY                   1218  // Added version 6.0.0

#define CMD_DialogScale                   1219  // Added version 8.0.0

#define CMD_LayerUpdateAllViews           1220

#define CMD_HatchLayer                    1221  // Added version 6.0.0
#define CMD_HatchLType                    1222  // Added version 6.0.0
#define CMD_HatchWidth                    1223  // Added version 6.0.0
#define CMD_SnapParOffVal                 1224  // Added version 7.0.0
#define CMD_SnapAngleVal                  1225  // Added version 7.0.0
#define CMD_PrtWatermark                  1226  // Added version 8.0.0
#define CMD_PrtWatermarkPrint             1227  // Added version 8.0.0
#define CMD_PrtWatermarkGray              1228  // Added version 8.0.0
#define CMD_PrtStampCustom                1229  // Added version 8.0.0

#define CMD_DatumOff                      1230
#define CMD_DatumXY                       1231
#define CMD_DatumX                        1232
#define CMD_DatumY                        1233

#define CMD_FillLayer                     1234  // Added version 8.0.0
#define CMD_FillLType                     1235  // Added version 8.0.0
#define CMD_FillWidth                     1236  // Added version 8.0.0

#define CMD_FontScale                     1237  // Added version 8.0.1
#define CMD_HatchGDIStyle                 1238  // Added version 8.0.1
#define CMD_FillGDIStyle                  1239  // Added version 8.0.1
#define CMD_ScriptClipboard               1240  // Added version 9.0.0
#define CMD_SimulateInput                 1241  // Added version 9.0.0
#define CMD_PDFCurPreset                  1242  // Added version 9.0.0

#define CMD_UseByLayer                    1243
#define CMD_UseSymbolColor                1244

#define CMD_DimTextFont                   1245  // Added version 4.0.0
#define CMD_DimTextHt                     1246  // Added version 4.0.0
#define CMD_DimTextAsp                    1247  // Added version 4.0.0
#define CMD_DimTextSlant                  1248  // Added version 4.0.0
#define CMD_DimTextChSp                   1249  // Added version 4.0.0
#define CMD_DimTextBold                   1250  // Added version 4.0.0
#define CMD_DimTextItal                   1251  // Added version 4.0.0
#define CMD_DimTextUnder                  1252  // Added version 4.0.0
#define CMD_DimTextMono                   1253  // Added version 4.0.0
#define CMD_DimTextFill                   1254  // Added version 4.0.0
#define CMD_DimTextVert                   1255  // Added version 4.0.0
#define CMD_DimTextInLn                   1256  // Added version 4.0.0
#define CMD_DimTextAbove                  1257  // Added version 4.0.0
#define CMD_DimTextCent                   1258  // Added version 4.0.0
#define CMD_DimTextAltRo                  1259  // Added version 4.0.0
#define CMD_DimTextOvStr                  1260  // Added version 4.0.0
#define CMD_DimTextOvwrt                  1261  // Added version 4.0.0
#define CMD_DimTextPreSt                  1262  // Added version 4.0.0
#define CMD_DimTextPrefx                  1263  // Added version 4.0.0
#define CMD_DimTextSufSt                  1264  // Added version 4.0.0
#define CMD_DimTextSuffx                  1265  // Added version 4.0.0
#define CMD_DimTextTol                    1266  // Added version 4.0.0
#define CMD_DimTextTolLo                  1267  // Added version 4.0.0
#define CMD_DimTextTolUp                  1268  // Added version 4.0.0
#define CMD_DimTextScale                  1269  // Added version 4.0.0
#define CMD_DimTextLnSp                   1270  // Added version 4.0.0
#define CMD_DimAngle                      1271  // Added version 4.0.0
#define CMD_DimArrowType                  1272  // Added version 4.0.0
#define CMD_DimArrowSize                  1273  // Added version 4.0.0
#define CMD_DimArrowAng                   1274  // Added version 4.0.0
#define CMD_DimArrowFlip                  1275  // Added version 4.0.0
#define CMD_DimFlipLeft                   1276  // Added version 4.0.0
#define CMD_DimFlipRight                  1277  // Added version 4.0.0
#define CMD_DimExtOffset                  1278  // Added version 4.0.0
#define CMD_DimExtAbove                   1279  // Added version 4.0.0
#define CMD_DimExtBelow                   1280  // Added version 4.0.0
#define CMD_DimStretch                    1281  // Added version 4.0.0
#define CMD_DimUseLayer                   1282  // Added version 4.0.0
#define CMD_DimLayer                      1283  // Added version 4.0.0
#define CMD_DimLineShow                   1284  // Added version 4.0.0
#define CMD_DimLtArShow                   1285  // Added version 4.0.0
#define CMD_DimRtArShow                   1286  // Added version 4.0.0
#define CMD_DimLtExShow                   1287  // Added version 4.0.0
#define CMD_DimRtExShow                   1288  // Added version 4.0.0
#define CMD_DimTextShow                   1289  // Added version 4.0.0
#define CMD_DimLineColor                  1290  // Added version 4.0.0
#define CMD_DimLtArColor                  1291  // Added version 4.0.0
#define CMD_DimRtArColor                  1292  // Added version 4.0.0
#define CMD_DimLtExColor                  1293  // Added version 4.0.0
#define CMD_DimRtExColor                  1294  // Added version 4.0.0
#define CMD_DimTextColor                  1295  // Added version 4.0.0
#define CMD_DimLineType                   1296  // Added version 4.0.0
#define CMD_DimLtArType                   1297  // Added version 4.0.0
#define CMD_DimRtArType                   1298  // Added version 4.0.0
#define CMD_DimLtExType                   1299  // Added version 4.0.0
#define CMD_DimRtExType                   1300  // Added version 4.0.0
#define CMD_DimTextType                   1301  // Added version 4.0.0
#define CMD_DimLineWidth                  1302  // Added version 4.0.0
#define CMD_DimLtArWidth                  1303  // Added version 4.0.0
#define CMD_DimRtArWidth                  1304  // Added version 4.0.0
#define CMD_DimLtExWidth                  1305  // Added version 4.0.0
#define CMD_DimRtExWidth                  1306  // Added version 4.0.0
#define CMD_DimTextWidth                  1307  // Added version 4.0.0
#define CMD_TextUseLayer                  1308  // Added version 4.0.0
#define CMD_TextSlant                     1309  // Added version 4.0.0
#define CMD_TextUnderln                   1310  // Added version 4.0.0
#define CMD_TextMono                      1311  // Added version 4.0.0
#define CMD_TextFill                      1312  // Added version 4.0.0
#define CMD_AtbFont                       1313  // Added version 4.0.0
#define CMD_AtbHt                         1314  // Added version 4.0.0
#define CMD_AtbColor                      1315  // Added version 4.0.0
#define CMD_AtbUseLocal                   1316  // Added version 4.0.0
#define CMD_AtbLocalDsp                   1317  // Added version 4.0.0
#define CMD_AtbLclLblDsp                  1318  // Added version 4.0.0
#define CMD_AtbGlobalDsp                  1319  // Added version 4.0.0
#define CMD_AtbGlbLblDsp                  1320  // Added version 4.0.0
#define CMD_SymAutoExp                    1321  // Added version 4.0.0
#define CMD_SymExplodeTo                  1322  // Added version 4.0.0
#define CMD_OrthoAdvType                  1323  // Added version 4.0.0
#define CMD_OrthoAdvInc                   1324  // Added version 4.0.0
#define CMD_OrthoAdvStep                  1325  // Added version 4.0.0
#define CMD_OrthoAdvOne                   1326  // Added version 4.0.0
#define CMD_BasepointPt                   1327  // Added version 4.0.0
#define CMD_PrtAddPreset                  1328  // Added version 4.0.0
#define CMD_PrtDelPreset                  1329  // Added version 4.0.0
#define CMD_PrtCurPreset                  1330  // Added version 4.0.0
#define CMD_PrtDevice                     1331  // Added version 4.0.0
#define CMD_PrtPgWidth                    1332  // Added version 4.0.0
#define CMD_PrtPgHeight                   1333  // Added version 4.0.0
#define CMD_PrtMargLeft                   1334  // Added version 4.0.0
#define CMD_PrtMargBot                    1335  // Added version 4.0.0
#define CMD_PrtMargRight                  1336  // Added version 4.0.0
#define CMD_PrtMargTop                    1337  // Added version 4.0.0
#define CMD_PrtScale                      1338  // Added version 4.0.0
#define CMD_PrtOrigin                     1339  // Added version 4.0.0
#define CMD_PrtViewType                   1340  // Added version 4.0.0
#define CMD_PrtLandscape                  1341  // Added version 4.0.0
#define CMD_PrtNumCopies                  1342  // Added version 4.0.0
#define CMD_PrtRotAngle                   1343  // Added version 4.0.0
#define CMD_PrtMetric                     1344  // Added version 4.0.0
#define CMD_PrtFastDraw                   1345  // Added version 4.0.0
#define CMD_PrtSelected                   1346  // Added version 4.0.0
#define CMD_PrtToFile                     1347  // Added version 4.0.0
#define CMD_PrtDateStamp                  1348  // Added version 4.0.0
#define CMD_PrtAllBlack                   1349  // Added version 4.0.0
#define CMD_PrtLW0HasWid                  1350  // Added version 4.0.0
#define CMD_PrtLineWidth                  1351  // Added version 4.0.0
#define CMD_PrtMovePage                   1352  // Added version 4.0.0
#define CMD_PrtPaperSize                  1353  // Added version 4.0.0
#define CMD_PrtPreview                    1354  // Added version 4.0.0
#define CMD_PrtPaperLen                   1355  // Added version 4.0.0
#define CMD_PrtPaperWid                   1356  // Added version 4.0.0
#define CMD_PrtCenter                     1357  // Added version 4.0.0
#define CMD_PrtStampForm                  1358  // Added version 4.0.0
#define CMD_PrtStampSize                  1359  // Added version 4.0.0
#define CMD_PrtStampLoc                   1360  // Added version 4.0.0
#define CMD_PrtStampFont                  1361  // Added version 4.0.0
#define CMD_DimDecimal                    1362  // Added version 4.0.0
#define CMD_DimFraction                   1363  // Added version 4.0.0
#define CMD_DimAngForm                    1364  // Added version 4.0.0
#define CMD_DimLeadZero                   1365  // Added version 4.0.0
#define CMD_DimUnits                      1366  // Added version 4.0.0
#define CMD_DimSUFrac                     1367  // Added version 4.0.0
#define CMD_DimSecond                     1368  // Added version 4.0.0
#define CMD_DimDistForm                   1369  // Added version 4.0.0
#define CMD_DimSecForm                    1370  // Added version 4.0.0
#define CMD_DispDecimal                   1371  // Added version 4.0.0
#define CMD_DispFraction                  1372  // Added version 4.0.0
#define CMD_DispAngForm                   1373  // Added version 4.0.0
#define CMD_DispLeadZero                  1374  // Added version 4.0.0
#define CMD_DispUnits                     1375  // Added version 4.0.0
#define CMD_GCDPath                       1376  // Added version 4.0.0
#define CMD_MNUPath                       1377  // Added version 4.0.0
#define CMD_STYPath                       1378  // Added version 4.0.0
#define CMD_HatchDrawBnd                  1379  // Added version 4.0.0
#define CMD_CursorSize                    1380  // Added version 4.0.0
#define CMD_DefTool                       1381  // Added version 4.0.0
#define CMD_ZoomFactor                    1382  // Added version 4.0.0
#define CMD_AskCenter                     1383  // Added version 4.0.0
#define CMD_ArrowWorld                    1384  // Added version 4.0.0
#define CMD_AroWrldStep                   1385  // Added version 4.0.0
#define CMD_AroScrnStep                   1386  // Added version 4.0.0
#define CMD_BackColor                     1387  // Added version 4.0.0
#define CMD_CursColor                     1388  // Added version 4.0.0
#define CMD_SelColor                      1389  // Added version 4.0.0
#define CMD_RubColor                      1390  // Added version 4.0.0
#define CMD_ShowDrag                      1391  // Added version 4.0.0
#define CMD_SearchTol                     1392  // Added version 4.0.0
#define CMD_ShowLnType                    1393  // Added version 4.0.0
#define CMD_ShowLnWidth                   1394  // Added version 4.0.0
#define CMD_ShowFill                      1395  // Added version 4.0.0
#define CMD_ShowHatch                     1396  // Added version 4.0.0
#define CMD_ShowPoint                     1397  // Added version 4.0.0
#define CMD_EnvSaveExit                   1398  // Added version 4.0.0
#define CMD_ShiftClick                    1399  // Added version 4.0.0
#define CMD_UseFileLock                   1400  // Added version 4.0.0
#define CMD_UseFastProp                   1401  // Added version 4.0.0
#define CMD_AutoBack                      1402  // Added version 4.0.0
#define CMD_AutoBackSec                   1403  // Added version 4.0.0
#define CMD_AutoSave                      1404  // Added version 4.0.0
#define CMD_AutoSaveSec                   1405  // Added version 4.0.0
#define CMD_FontSort                      1406  // Added version 4.0.0

// Leader Settings
#define CMD_LdrTextFont                   1407  // Added version 4.0.0
#define CMD_LdrTextHt                     1408  // Added version 4.0.0
#define CMD_LdrTextAsp                    1409  // Added version 4.0.0
#define CMD_LdrTextSlant                  1410  // Added version 4.0.0
#define CMD_LdrTextChSp                   1411  // Added version 4.0.0
#define CMD_LdrTextLnSp                   1412  // Added version 4.0.0
#define CMD_LdrTextBold                   1413  // Added version 4.0.0
#define CMD_LdrTextUnder                  1414  // Added version 4.0.0
#define CMD_LdrTextItal                   1415  // Added version 4.0.0
#define CMD_LdrTextMono                   1416  // Added version 4.0.0
#define CMD_LdrTextFill                   1417  // Added version 4.0.0
#define CMD_LdrArrowType                  1418  // Added version 4.0.0
#define CMD_LdrArrowSize                  1419  // Added version 4.0.0
#define CMD_LdrArrowAng                   1420  // Added version 4.0.0
#define CMD_LdrOffset                     1421  // Added version 4.0.0
#define CMD_LdrShoulder                   1422  // Added version 4.0.0

// Filter Settings
#define CMD_FltEntity                     1423  // Added version 4.0.0
#define CMD_FltLayer                      1424  // Added version 4.0.0
#define CMD_FltColor                      1425  // Added version 4.0.0
#define CMD_FltLnType                     1426  // Added version 4.0.0
#define CMD_FltLnWidth                    1427  // Added version 4.0.0
#define CMD_FltName                       1428  // Added version 4.0.0
#define CMD_FltActive                     1429  // Added version 4.0.0

// Layer Settings
#define CMD_HideLayers                    1430  // Added version 4.0.0
#define CMD_DispLayers                    1431  // Added version 4.0.0

#define CMD_LaySelect1                    1432  // Added version 4.0.0
#define CMD_ZmViewName                    1433  // Added version 4.0.0
#define CMD_ChangeLayer                   1434  // Added version 4.0.0
#define CMD_ChangeColor                   1435  // Added version 4.0.0
#define CMD_ChangeLType                   1436  // Added version 4.0.0
#define CMD_ChangeLWidth                  1437  // Added version 4.0.0
#define CMD_ChangeRealW                   1438  // Added version 4.0.0
#define CMD_NumDivide                     1439  // Added version 4.0.0
#define CMD_DivBreak                      1440  // Added version 4.0.0
#define CMD_GroupProp                     1441  // Added version 4.0.0
#define CMD_ChangeApply                   1442  // Added version 4.0.0
#define CMD_LayerGroupApply               1443  // Added version 4.0.0

#define CMD_SaveSettings                  1444  // Added version 4.0.4
#define CMD_RestoreSettings               1445  // Added version 4.0.4

#define CMD_LdrVertAlign                  1446  // Added version 5.0.0
#define CMD_LdrJust                       1447  // Added version 5.0.0
#define CMD_LdrType                       1448  // Added version 5.0.0
#define CMD_LdrUseLayer                   1449  // Added version 5.0.0
#define CMD_LdrLayer                      1450  // Added version 5.0.0

#define CMD_OrdOffset                     1451  // Added version 6.0.0
#define CMD_DimSelected                   1452  // Added version 6.0.0
#define CMD_ExplodeMultiToSingle          1453  // Added version 6.0.0
#define CMD_LdrTextStr                    1454  // Added version 6.0.0
#define CMD_MulSetLayer                   1455  // Added version 6.0.0
#define CMD_MulSetColor                   1456  // Added version 6.0.0
#define CMD_MulSetLType                   1457  // Added version 6.0.0
#define CMD_MulSetLWidth                  1458  // Added version 6.0.0
#define CMD_MulSetRealW                   1459  // Added version 6.0.0
#define CMD_MulSetOffset                  1460  // Added version 6.0.0
#define CMD_MulSetUse                     1461  // Added version 6.0.0
#define CMD_MulSetApply                   1462  // Added version 6.0.0
#define CMD_MulSetGet                     1463  // Added version 6.0.0
#define CMD_MulSetReset                   1464  // Added version 6.0.0

#define CMD_LockLayers                    1465  // Added version 6.0.0
#define CMD_UnlockLayers                  1466  // Added version 6.0.0
#define CMD_PrintLayers                   1467  // Added version 6.0.0
#define CMD_NoPrintLayers                 1468  // Added version 6.0.0

#define CMD_FontShowTT                    1469  // Added version 6.0.0
#define CMD_FontShowVCF                   1470  // Added version 6.0.0
#define CMD_FontShowFav                   1471  // Added version 6.0.0

#define CMD_FileProtect                   1472  // Added version 6.0.1
#define CMD_FileCompress                  1473  // Added version 6.0.1
#define CMD_TextLType                     1474  // Added version 6.0.1
#define CMD_TextLWidth                    1475  // Added version 6.0.1
#define CMD_TextRealW                     1476  // Added version 6.0.1
#define CMD_TextCharset                   1477  // Added version 6.0.1
#define CMD_TextTabStops                  1478  // Added version 6.0.1

#define CMD_DispDistForm                  1479  // Added version 7.0.0

#define CMD_DimAngDecimal                 1480  // Added version 7.0.0
#define CMD_DispAngDecimal                1481  // Added version 7.0.0
#define CMD_SecondDecimal                 1482  // Added version 7.0.0
#define CMD_SecondFraction                1483  // Added version 7.0.0
#define CMD_SecondUnits                   1484  // Added version 7.0.0
#define CMD_SecondLeadZero                1485  // Added version 7.0.0
#define CMD_DispDash                      1486  // Added version 7.0.0
#define CMD_SecondDash                    1487  // Added version 7.0.0
#define CMD_SecondSUFrac                  1488  // Added version 7.0.0
#define CMD_DefaultButtons                1489  // Added version 7.0.0
#define CMD_PrintOriginPt                 1490  // Added version 7.0.0
#define CMD_ShowPrintOrigin               1491  // Added version 7.0.0
#define CMD_UsePrintOrigin                1492  // Added version 7.0.0
#define CMD_MEMode                        1493  // Added version 7.0.0
#define CMD_CompressImages                1494  // Added version 7.0.0

#define CMD_DimInLineText                 1495  // Changed version 7.0.0

#define CMD_DispBaseAngle                 1496  // Added version 7.0.1
#define CMD_DispCustomAngle               1497  // Added version 7.0.1
#define CMD_DispClockwise                 1498  // Added version 7.0.1
#define CMD_DimBaseAngle                  1499  // Added version 7.0.1
#define CMD_DimCustomAngle                1500  // Added version 7.0.1
#define CMD_DimClockwise                  1501  // Added version 7.0.1
#define CMD_DimDistanceAngle              1502  // Added version 7.0.1
#define CMD_DimReverseAngle               1503  // Added version 7.0.1

#define CMD_ReadStyle                     1504  // Added version 8.0.0
#define CMD_ShowMask                      1505  // Added version 8.0.0
#define CMD_DimAngUnits                   1506  // Added version 8.0.0
#define CMD_DispAngUnits                  1507  // Added version 8.0.0
#define CMD_DimFracHt                     1508  // Added version 8.0.0
#define CMD_LdrFracHt                     1509  // Added version 8.0.0
#define CMD_ScriptStack                   1510  // Added version 8.0.0

#define CMD_LdrLineColor                  1511  // Added version 8.0.0
#define CMD_LdrLineShow                   1512  // Added version 8.0.0
#define CMD_LdrLineType                   1513  // Added version 8.0.0
#define CMD_LdrLineWidth                  1514  // Added version 8.0.0
#define CMD_LdrLineRWidth                 1515  // Added version 8.0.0
#define CMD_LdrArrowColor                 1516  // Added version 8.0.0
#define CMD_LdrArrowShow                  1517  // Added version 8.0.0
#define CMD_LdrArrowLType                 1518  // Added version 8.0.0
#define CMD_LdrArrowWidth                 1519  // Added version 8.0.0
#define CMD_LdrArrowRWidth                1520  // Added version 8.0.0
#define CMD_LdrBrdrColor                  1521  // Added version 8.0.0
#define CMD_LdrBrdrShow                   1522  // Added version 8.0.0
#define CMD_LdrBrdrLType                  1523  // Added version 8.0.0
#define CMD_LdrBrdrWidth                  1524  // Added version 8.0.0
#define CMD_LdrBrdrRWidth                 1525  // Added version 8.0.0
#define CMD_LdrTextColor                  1526  // Added version 8.0.0
#define CMD_LdrTextShow                   1527  // Added version 8.0.0
#define CMD_LdrTextLType                  1528  // Added version 8.0.0
#define CMD_LdrTextWidth                  1529  // Added version 8.0.0
#define CMD_LdrTextRWidth                 1530  // Added version 8.0.0
#define CMD_LdrShldrAng                   1531  // Added version 8.0.0
#define CMD_LdrTextRot                    1532  // Added version 8.0.0
#define CMD_LdrBrdrStyle                  1533  // Added version 8.0.0
#define CMD_LdrTextUnicode                1534  // Added version 8.0.0
#define CMD_LdrTextHorizAlign             1535  // Added version 8.0.0
#define CMD_DimStacked                    1536  // Added version 8.0.0
#define CMD_DimNoBreak                    1537  // Added version 8.0.0
#define CMD_DimLineRWidth                 1538  // Added version 8.0.0
#define CMD_DimLtArRWidth                 1539  // Added version 8.0.0
#define CMD_DimRtArRWidth                 1540  // Added version 8.0.0
#define CMD_DimLtExRWidth                 1541  // Added version 8.0.0
#define CMD_DimRtExRWidth                 1542  // Added version 8.0.0
#define CMD_DimTextRWidth                 1543  // Added version 8.0.0
#define CMD_SetByLayer                    1544  // Added version 8.0.0
#define CMD_ApplyByLayer                  1545  // Added version 8.0.0
#define CMD_ImgShowBrdr                   1546  // Added version 8.0.0
#define CMD_ImgLckAsp                     1547  // Added version 8.0.0
#define CMD_ImgFlipX                      1548  // Added version 8.0.0
#define CMD_ImgFlipY                      1549  // Added version 8.0.0
#define CMD_ImgGray                       1550  // Added version 8.0.0
#define CMD_ImgRot                        1551  // Added version 8.0.0
#define CMD_ImgShow                       1552  // Added version 8.0.0
#define CMD_ImgAutoPos                    1553  // Added version 8.0.0
#define CMD_ImgOpacity                    1554  // Added version 8.0.0
#define CMD_ImgEmbed                      1555  // Added version 8.0.0
#define CMD_TextVertAlign                 1556  // Added version 8.0.0
#define CMD_LdrTextCharset                1557  // Added version 8.0.3
#define CMD_DimTextCharset                1558  // Added version 8.0.3
#define CMD_DimDecSep                     1559  // Added version 9.0.0
#define CMD_DimSecDecSep                  1560  // Added version 9.0.0
#define CMD_DimThsSep                     1561  // Added version 9.0.0
#define CMD_DimSecThsSep                  1562  // Added version 9.0.0
#define CMD_TextMasked                    1563  // Added version 9.0.0
#define CMD_TextMaskOffset                1564  // Added version 9.0.0
#define CMD_DimTextMasked                 1565  // Added version 9.0.0
#define CMD_LdrTextMasked                 1566  // Added version 9.0.0
#define CMD_TextWordWrap                  1567  // Added version 9.0.0
#define CMD_UpdateOleOnOpen               1568  // Added version 9.0.0
#define CMD_DivBreakLines                 1569  // Added version 9.0.0
#define CMD_OffsetAutoSeg                 1570  // Added version 9.0.0
#define CMD_OffsetNumSeg                  1571  // Added version 9.0.0
#define CMD_OffsetConvert                 1572  // Added version 9.0.0
#define CMD_OffsetReplace                 1573  // Added version 9.0.0
#define CMD_FltRWidth                     1574  // Added version 9.0.0
#define CMD_FltMulti                      1575  // Added version 9.0.0
#define CMD_SnapPreviewColor              1576  // Added version 9.0.0
#define CMD_SimKey                        1577  // Added version 9.0.0
#define CMD_GridDotStyle                  1578  // Added version 9.0.0
#define CMD_SetViewName                   1579  // Added version 9.0.0
#define CMD_RemoveViewName                1580  // Added version 9.0.0
#define CMD_BackupOnSave                  1581  // Added version 9.0.0
#define CMD_TextKern                      1582  // Added version 9.0.0
#define CMD_FontHideVertTT                1583  // Added version 9.0.0
#define CMD_IncrementalUndo               1584  // Added version 9.0.0
#define CMD_LdrTabStops                   1585  // Added version 9.0.0
#define CMD_DimFarSideArrow               1586  // Added version 9.0.0
#define CMD_DimTextJust                   1587  // Added version 9.0.0
#define CMD_HatchOffsetX                  1588  // Added version 9.0.0
#define CMD_HatchOffsetY                  1589  // Added version 9.0.0
#define CMD_HatchAlignment                1590  // Added version 9.0.0
#define CMD_SymUseBreakColor              1591  // Added version 9.0.0
#define CMD_SymIgnoreColor                1592  // Added version 9.0.0
#define CMD_RFAngle                       1593  // Added version 9.0.0
#define CMD_RFScaleX                      1594  // Added version 9.0.0
#define CMD_RFScaleY                      1595  // Added version 9.0.0
#define CMD_GridOriginPt                  1596  // Added version 9.0.0
#define CMD_DBSolidHatch                  1597  // Added version 9.0.0
#define CMD_PrtCopyPreset                 1598  // Added version 9.0.0
#define CMD_TextDrawAsVector              1599  // Added version 9.0.0
#define CMD_DimKern                       1600  // Added version 9.0.0
#define CMD_DimDrawAsVector               1601  // Added version 9.0.0
#define CMD_LdrKern                       1602  // Added version 9.0.0
#define CMD_LdrDrawAsVector               1603  // Added version 9.0.0
#define CMD_TextFillOnly                  1604  // Added version 9.0.0
#define CMD_DimTextFillOnly               1605  // Added version 9.0.0  
#define CMD_LdrTextFillOnly               1606  // Added version 9.0.0  
#define CMD_DimSUFStack                   1607  // Added version 9.0.0
#define CMD_SecondSUFStack                1608  // Added version 9.0.0

#define TOKENSETTINGLAST                  1700

//======================================  TOOLS        =================================================
//======================================  TOOLS        =================================================
//======================================  TOOLS        =================================================
// Command IDs
// Messages sent to Main Window Frame through WM_COMMAND


#define ToolBase                          2100
#define TOKENTOOLFIRST                    2100

#define CMD_DrawPoint                     2101
#define CMD_DrawLineSingle                2102
#define CMD_DrawLineContinuous            2103
#define CMD_DrawRect2Pt                   2104
#define CMD_DrawRect3Pt                   2105
#define CMD_DrawCircle3Pt                 2106
#define CMD_DrawCircle2Pt                 2107
#define CMD_DrawArc3Pt                    2108
#define CMD_DrawArc2Pt                    2109
#define CMD_DrawEllipse                   2110
#define CMD_DrawBezierSingle              2111
#define CMD_DrawBezierCont                2112
#define CMD_DrawRPolygonCenter            2113
#define CMD_DrawRPolygonSide              2114
#define CMD_DrawIPolygon                  2115
#define CMD_DrawLineDouble                2116
#define CMD_DrawEllipticalArcStartSpan    2117
#define CMD_LastSymbol                    2119
#define CMD_SymPlace                      2120
#define CMD_DrawCurve                     2121
#define CMD_DrawCircleDiameter            2122
#define CMD_DrawMultiLine                 2123
#define CMD_SymbolExplode                 2124
#define CMD_UndoLastVertex                2125
#define CMD_UndoLastDim                   2126
//#define CMD_SymPlaceFromMgr             2127  // Added version 3.0.0 //unused in 9.0.0
#define CMD_TabPrintColorMap              2127  // Added version 9.0.0

#define CMD_DrawGCADDLine                 2128  // Added version 4.0.0
//#define CMD_DrawDoubleLine                2129  // Added version 4.0.0 //unused in 9.0.0
//#define CMD_ContLineSingle                2130  // Added version 4.0.0 //unused in 9.0.0
#define CMD_MultiLineEdit                 2131  // Added version 6.0.0
#define CMD_DrawParabola                  2132  // Added version 8.0.0
#define CMD_DrawParabolaVertex            2133  // Added version 8.0.0
#define CMD_NoOp                          2134  // Added version 8.0.0
#define CMD_End                           2135  // Added version 8.0.0

// OPEN_NUMBERS

// SNAPS
#define CMD_SnapPerpendicular             2151
#define CMD_SnapTangent                   2152
#define CMD_SnapPercent                   2153
#define CMD_SnapClosestPoint              2154
#define CMD_SnapMidPoint                  2155
#define CMD_SnapObject                    2156
#define CMD_SnapIntersection              2157
#define CMD_SnapNearPoint                 2158
#define CMD_SnapQuad                      2159
#define CMD_SnapArcCenter                 2160
#define CMD_SnapLastPoint                 2161
#define CMD_SnapParallel                  2162
#define CMD_IncSnap                       2163
#define CMD_SnapMid2Points                2164
#define CMD_SnapAngle                     2165  // Added version 7.0.0
#define CMD_SnapGridPoint                 2166  // Added version 8.0.0
#define CMD_SnapFocus                     2167  // Added version 8.0.0

// Dim,Leader,Text,Hatch Change
#define CMD_LoadHatch                     2168  //  Added version 9.0.0
#define CMD_HatchAlign                    2169  //  Added version 9.0.0, replaces IDD_HatchAlign
#define CMD_DimChange                     2170
#define CMD_LeaderChange                  2171
#define CMD_TextChange                    2172
#define CMD_HatchChange                   2173
#define CMD_HatchParse                    2174  // Added version 7.0.0
#define CMD_FillChange                    2175  // Added version 8.0.0
#define CMD_FillToHatch                   2176  // Added version 8.0.1
#define CMD_HatchArrayParse               2177  // Added version 9.0.0

// DIMS
#define CMD_DimDatumCurve                 2178  // Added version 4.0.0
#define CMD_LeaderCurve                   2179  // Added version 4.0.0
#define CMD_DimDatum                      2180
#define CMD_DimLinear                     2181
#define CMD_DimAngular                    2182
#define CMD_DimDialog                     2183
#define CMD_DimRadial                     2184
#define CMD_DimDiameter                   2185
#define CMD_Leader                        2186
#define CMD_DimMoveText                   2187
#define CMD_DimSlideText                  2188
#define CMD_DimMoveLine                   2189
#define CMD_DimMoveArc                    2190
#define CMD_DimEdit                       2191
#define CMD_LinDimHorz                    2192
#define CMD_LinDimVert                    2193
#define CMD_LinDimAligned                 2194
#define CMD_LinDimAngle                   2195
#define CMD_DimOrdinate                   2196
#define CMD_DimPoint                      2197
#define CMD_ChangeRefFrameFileName        2198
#define CMD_RefFrameEdit                  2198  //+-JLW 29-Nov-17 b8-43 for HelpTableGen    //  CMD_ChangeRefFrameFileName    // Added version 8.0.0 as alternate symbol
#define CMD_LeaderEdit                    2199
#define CMD_DimPreview                    2200

// ZOOMS Section
#define CMD_ZoomRegen                     2201
#define CMD_ZoomRegenArea                 2202
#define CMD_ZoomArea                      2203
#define CMD_ZoomIn                        2204
#define CMD_ZoomOut                       2205
#define CMD_ZoomPan                       2206
#define CMD_ZoomAll                       2207
#define CMD_ZoomSelected                  2208
#define CMD_ZoomPrevious                  2209
#define CMD_ZoomLimits                    2210
#define CMD_ZoomValue                     2211
#define CMD_ZoomView                      2212
#define CMD_NameView                      2213
#define CMD_SetBasepoint                  2214
#define CMD_BackRedraw                    2215
#define CMD_QuickSearch                   2216
#define CMD_ZoomAllViews                  2217
#define CMD_ZoomRegenAllViews             2218
#define CMD_ZoomAutoPan                   2219  // Added version 6.0.0

// OPEN_NUMBERS

#define CMD_ApplyRFZoomScale              2227  // Added version 3.0.0
#define CMD_ApplyRFZoomView               2228  // Added version 3.0.0

// OPEN_NUMBERS

// MODIFY Section
#define CMD_MultiCopy                     2230
#define CMD_ModCopy                       2231
#define CMD_ModErase                      2232
#define CMD_ModMirror                     2233
#define CMD_ModMove                       2234
#define CMD_ModRotate                     2235
#define CMD_ModMovePoint                  2236
#define CMD_ModFillet                     2237
#define CMD_ModDoubleTrim                 2238
#define CMD_ModStretch                    2239
#define CMD_ModTrim                       2240
#define CMD_ModExtend                     2241
#define CMD_ModBreak                      2242
#define CMD_ModSelectionTrim              2243
#define CMD_ModChamfer                    2244
#define CMD_ModCornerTrim                 2245
#define CMD_ModAlign                      2246
#define CMD_ModFitScale                   2247
#define CMD_ModRadCopy                    2248
#define CMD_ModArrayCopy                  2249
#define CMD_ModExplode                    2250
#define CMD_ModBezEdit                    2251
#define CMD_ModOffset                     2252
#define CMD_Reserve                       2253
#define CMD_ModCloseContour               2254
#define CMD_ModChange                     2255
#define CMD_ModScale                      2256
#define CMD_EraseLast                     2257
#define CMD_TUserVarP1                    2258
#define CMD_ModSelectionExtend            2259
#define CMD_ModAdjoiningToMEP             2260
#define CMD_ModOffsetMEP                  2261
#define CMD_ModBooleanAdd                 2262
#define CMD_ModBooleanSubtract            2263
#define CMD_ModBooleanIntersect           2264
#define CMD_WindowStretch                 2265
#define CMD_SingleTargetSelectionTrim     2266
#define CMD_ModUsePlacementColorOn        2267
#define CMD_ModUsePlacementColorOff       2268

#define CMD_ModAttributeDisplayOn         2269
#define CMD_ModAttributeDisplayOff        2270
#define CMD_ModAttributeLabelOn           2271
#define CMD_ModAttributeLabelOff          2272
#define CMD_ModSplitPolygon               2273  // Added version 3.0.0
#define CMD_ModMergePolygons              2274  // Added version 3.0.0
#define CMD_ModJoin                       2275  // Added version 3.0.0

#define CMD_ModCopySingle                 2276  // Added version 4.0.0
#define CMD_ModMultiBreak                 2277  // Added version 4.0.0
#define CMD_Divide                        2278  // Added version 4.0.0
#define CMD_ModExplodeToGroup             2279  // Added version 6.0.0
#define CMD_ModSkew                       2280  // Added version 6.0.0

#define CMD_DatabaseScale                 2281  // Added version 7.0.0
#define CMD_DatabaseMove                  2282  // Added version 7.0.0
#define CMD_ModBreakTo                    2283  // Added version 7.0.0
#define CMD_ModFenceTrim                  2284  // Added version 7.0.0
#define CMD_ModJoinCorner                 2285  // Added version 7.0.0
#define CMD_ModMixedJoin                  2286  // Added version 8.0.0
#define CMD_ExDataEditHdr                 2287  // Added version 8.0.0
#define CMD_ExDataEditEnt                 2288  // Added version 8.0.0

// OPEN_NUMBERS

// Utility
#define CMD_InspectorMatch                2300  // Added version 3.0.0
#define CMD_MeasureDistance               2301
#define CMD_MeasureArea                   2302
#define CMD_MeasureAngle2                 2303
#define CMD_MeasureAngle3                 2304
#define CMD_MatchEntity                   2305
#define CMD_MatchTool                     2306
#define CMD_MeasureDone                   2308
#define CMD_PackData                      2309
#define CMD_TabletMode                    2310
#define CMD_TraceScale                    2311
#define CMD_DigDrawingAlign               2312
#define CMD_ActiveArea                    2313
#define CMD_WTConfig                      2314
#define CMD_DigInfo                       2315
#define CMD_SaveEnvironment               2316
#define CMD_FontConvert                   2317
#define CMD_WinExec                       2318
//#define CMD_JustText                    2319  // Removed version 5.0.0
#define CMD_DimLeaderString               2319  // Added version 5.0.0
#define CMD_SymbolCount                   2320
#define CMD_BOM2CLIP                      2321
#define CMD_CLIP2BOM                      2322
#define CMD_DllRun                        2323
#define CMD_DoDragDrop                    2324
#define CMD_PurgeLnt                      2325
#define CMD_LoadLnt                       2326
#define CMD_OleCreateClass                2327
#define CMD_OleInvokeMethod               2328
#define CMD_OlePropertyDlg                2329  // Added version 4.0.4
#define CMD_OleTransparent                2330  // Added version 5.0.0
#define CMD_OleForceToBack                2331  // Added version 5.0.0
#define CMD_MatchOrtho                    2332  // Added version 7.0.0
#define CMD_MatchChange                   2333  // Added version 7.0.0

// OPEN_NUMBERS

#define CMD_ImplicitEntityEdit            2335
#define CMD_LayerGroupCombo               2336
#define CMD_FilterReset                   2337
#define CMD_LayerGroupDlg                 2338
#define CMD_LayerEdit                     2339

// Misc Tools
#define CMD_SeedHatch                     2340
#define CMD_SeedFill                      2341

#define CMD_CleanData                     2342  // Added version 4.0.0
#define CMD_CleanDataWindow               2343  // Added version 8.0.0

// OPEN_NUMBERS

#define CMD_SymbolChange                  2350
#define CMD_SymCreate                     2351
#define CMD_HatchSelected                 2352
#define CMD_FillSelected                  2353
#define CMD_Text                          2354
#define CMD_Like                          2355
#define CMD_TextBox                       2356
#define CMD_Help                          2358
#define CMD_BoundaryHatch                 2359
#define CMD_BoundaryFill                  2360
#define CMD_About                         2361
#define CMD_AboutDlg                      2363
#define CMD_AttributeAttach               2364
#define CMD_AttributeCreate               2365
#define CMD_ScriptAssign                  2366
#define CMD_AttributeEmbed                2367
#define CMD_SpecificAttributeAttach       2368
#define CMD_AttributeEdit                 2369
#define CMD_AttributeMove                 2370
#define CMD_AttributeMultiAttach          2371
#define CMD_HelpIndex                     2372
#define CMD_HelpSupport                   2373  // Redefined version 5.0.0 was CMD_HelpKey
#define CMD_HelpWebsite                   2374  // Redefined version 5.0.0 was CMD_HelpTechSupport

// Windows Section
#define CMD_WindowCascade                 2375
#define CMD_WindowTileVert                2376
#define CMD_WindowTileHorz                2377
#define CMD_WindowArrangeIcons            2378
#define CMD_WindowCloseAll                2379
#define CMD_WindowNew                     2380
#define CMD_HelpCursor                    2381

#define CMD_IsoLeft                       2382  //  Changed and moved from settings range version 6.0.0
#define CMD_IsoRight                      2383  //  Changed and moved from settings range version 6.0.0
#define CMD_IsoTop                        2384  //  Changed and moved from settings range version 6.0.0

#define CMD_BoundaryMask                  2385  // Added version 8.0.0
#define CMD_SaveEnvGlobal                 2386  // Added version 8.0.0
#define CMD_SaveEnvDrawing                2387  // Added version 8.0.0
#define CMD_EnvSaveExitGlobal             2388  // Added version 8.0.0
#define CMD_EnvSaveExitDrawing            2389  // Added version 8.0.0
#define CMD_ModBoundary                   2390  // Added version 8.0.0
#define CMD_ModGDIStyle                   2391  // Added version 8.0.1

// OPEN_NUMBERS

// File Section
#define CMD_FileNew                       2400
#define CMD_FileOpen                      2401
#define CMD_FileSave                      2402
#define CMD_FileSaveAs                    2403
#define CMD_FileExit                      2404
#define CMD_FileClose                     2405
#define CMD_FilePrint                     2406
#define CMD_SymbolOpen                    2407
#define CMD_SymbolSave                    2408
#define CMD_ClearDrawing                  2409
#define CMD_FileMerge                     2410
#define CMD_PrintSetup                    2411
#define CMD_FilePlot                      2412
#define CMD_StyleOpen                     2413
#define CMD_StyleSave                     2414
#define CMD_AtbOpen                       2415
#define CMD_AtbSave                       2416
#define CMD_OleSaveCopyAs                 2417
#define CMD_OleUpdate                     2418 // Special Ole Function
#define CMD_LoadMenu                      2419
#define CMD_FileRun                       2420
#define CMD_NestedRun                     2421
#define CMD_NewView                       2422
#define CMD_BirdsEye                      2423
#define CMD_PlotOptions                   2424
#define CMD_PlotSetup                     2425
#define CMD_LoadAscii                     2426
#define CMD_ResetCmdExt                   2427
#define CMD_RefFrameCreate                2428
#define CMD_FileSend                      2429  // Send file via Exchange
#define CMD_RefFramePlace                 2430
#define CMD_Edit                          2431
#define CMD_NestedRunDll                  2432
//#define CMD_LoadDrawingFromName         2433  // Removed version 5.0.0
#define CMD_FileSaveAll                   2433  // Added version 6.0.0

#define CMD_PreviewOpen                   2434  // Added version 4.0.0  
#define CMD_PreviewSave                   2435  // Added version 4.0.0
#define CMD_PreviewSaveAs                 2436  // Added version 4.0.0
#define CMD_PrintNoDlg                    2437  // Added version 4.0.0
#define CMD_EmergencyExit                 2438  // Added version 5.0.0
#define CMD_RefFrameDetail                2439  // Added version 8.0.0

// EDIT Section
#define CMD_EditUndo                      2440
#define CMD_EditRedo                      2441
#define CMD_EditCut                       2442
#define CMD_EditCopy                      2443
#define CMD_EditPaste                     2444
#define CMD_EditClear                     2445
#define CMD_SelectAll                     2446
#define CMD_ClearSelection                2447
#define CMD_InverseSelection              2448
#define CMD_SelectionTool                 2449
#define CMD_TrackingTool                  2450
#define CMD_Penup                         2451
#define CMD_Abort                         2452
#define CMD_SelectionFilter               2453
#define CMD_SelectWindow                  2454
#define CMD_TrackEnd                      2455
#define CMD_SelectObject                  2456
#define CMD_NewHandle                     2457
#define CMD_SelectLayer                   2458
#define CMD_SelectCrossing                2460
#define CMD_SelectAdjoining               2461
#define CMD_UserPoint                     2462
#define CMD_SelectionRibalog              2463
#define CMD_Properties                    2464
#define CMD_Color                         2465
#define CMD_Layer                         2466
#define CMD_Ltype                         2467
#define CMD_Width                         2468
#define CMD_SelectLast                    2470
#define CMD_SelectModified                2471  // Added version 6.0.0
#define CMD_UserMatch                     2472
#define CMD_DeSelectAll                   2473
#define CMD_UserPointPenup                2474
#define CMD_UserPointAbort                2475
#define CMD_Hilite                        2476
#define CMD_FastProperties                2477
#define CMD_AllLayerEdit                  2478
#define CMD_SnapLayer                     2479
#define CMD_SymSnap                       2480
#define CMD_LayerDisplay                  2481
#define CMD_LayerHide                     2482
#define CMD_LayerCurrent                  2483
#define CMD_RealWorldLW                   2484
#define CMD_SelectLastObject              2485
#define CMD_LayerProperties               2486
#define CMD_LayerPropertyReset            2487

#define CMD_Group                         2488  // Added version 5.0.0
#define CMD_Ungroup                       2489  // Added version 5.0.0
#define CMD_LeaveGroup                    2490  // Added version 5.0.0
#define CMD_JoinGroup                     2491  // Added version 5.0.0

//NEW File menu items
#define CMD_ImportImage                   2492  // Added version 5.0.0
#define CMD_ExportImage                   2493  // Added version 5.0.0
#define CMD_ExportPDF                     2494  // Added version 5.0.0
#define CMD_ImageEdit                     2495  // Added version 6.0.0
#define CMD_ImageEditDlg                  2496  // Added version 6.0.0

#define CMD_LayerLock                     2497  // Added version 6.0.0
#define CMD_LayerUnlock                   2498  // Added version 6.0.0
#define CMD_SymSelect                     2499  // Added version 8.0.0

// Dialog section
#define CMD_FillDlg                       2500
#define CMD_HatchDlg                      2501
#define CMD_DimTextVectDlg                2502
#define CMD_AttribDlg                     2503
#define CMD_ObjectInfo                    2504
#define CMD_SpeedSym                      2505
#define CMD_SymDlg                        2506
#define CMD_DimTextDlg                    2507
#define CMD_DimArrowDlg                   2508
#define CMD_DimExtDlg                     2509
#define CMD_DimLineDlg                    2510
#define CMD_DimTolDlg                     2511
#define CMD_SymCreateDlg                  2512
#define CMD_LayerManager                  2513

#define CMD_AtbValueDlg                   2514
#define CMD_DimDisplayDlg                 2515
#define CMD_ToolBar                       2516
#define CMD_OptionMgr                     2517
#define CMD_PrintDlg                      2518
#define CMD_DimLeaderTextDlg              2519
#define CMD_DimStringsDlg                 2520
#define CMD_TextSett                      2521
#define CMD_TextSettFromTextDlg           2522
#define CMD_StyleDlg                      2523
#define CMD_DimEditDlg                    2524
#define CMD_SymReplace                    2525
#define CMD_MeasureDistanceDlg            2526
#define CMD_MeasureAreaDlg                2527
#define CMD_MeasureAngleDlg               2528
#define CMD_SymRemove                     2529
#define CMD_ExportPDFNoDlg                2530  // Added version 9.0.0
#define CMD_LineScale                     2531  // Added version 4.0.0
#define CMD_FilletRadius                  2532
#define CMD_OrthoAngle                    2533
#define CMD_DBLineSettings                2534
#define CMD_RPolygonNSides                2535
#define CMD_ChamferDist                   2536
#define CMD_GridSize                      2537
#define CMD_GridDisplay                   2538
#define CMD_SnapGrid                      2539
#define CMD_GridOrigin                    2540

#define CMD_AutoFillet                    2541
#define CMD_OrthoMode                     2542
#define CMD_CursorFree                    2543
#define CMD_DimModeSingle                 2544
#define CMD_DimModeCumulative             2545
#define CMD_DimModePartitioned            2546

#define CMD_ObjectXML                     2547  // Repurposed version 9.0.0 
#define CMD_TabText                       2548
#define CMD_TabHatch                      2549
#define CMD_TabDim                        2550
#define CMD_TabSystem                     2551  // Removed version 4.0.0 replaced with CMD_TabSystem1
#define CMD_TabGeneral                    2552
#define CMD_TabConstraint                 2553
#define CMD_TabPath                       2554
#define CMD_TabDimText                    2555
#define CMD_TabNumeric                    2556
#define CMD_TabImportGCDFontMapping       2557
#define CMD_TabExportGCDFontMapping       2558
#define CMD_TabImportDWGFontMapping       2559
#define CMD_TabExportDWGFontMapping       2560
#define CMD_TabGCDFontNamePool            2561  // Unused version 8.0.0
#define CMD_TabDWGFontNamePool            2562  // Unused version 8.0.0
#define CMD_TabGCDSettings                2563
#define CMD_TabDWGSettings                2564

#define CMD_ConstPts                      2565
#define CMD_HandlePts                     2566
#define CMD_CurveTangentPoints            2567
#define CMD_DBaseDlg                      2568
#define CMD_DBaseAssocList                2569
#define CMD_ToolbarDlg                    2570
#define CMD_ConstraintViewDlg             2571
#define CMD_AcadPolylineWidth             2572

#define CMD_ACADImportExportMgr           2573  // Added version 4.0.0
#define CMD_GCDImportExportMgr            2574  // Added version 4.0.0
#define CMD_TabDWGColorImport             2575  // Added version 4.0.0
#define CMD_TabDWGColorExport             2576  // Added version 4.0.0
#define CMD_TabSystem1                    2577  // Added version 4.0.0 replaces CMD_TabSystem
#define CMD_TabSystem2                    2578  // Added version 4.0.0
#define CMD_TabSys2_Adv                   2579  // Added version 4.0.0
#define CMD_OrthoAdv                      2580  // Added version 4.0.0
#define CMD_HidLayerMsg                   2581  // Added version 4.0.0
#define CMD_HatchDisplay                  2582  // Added version 6.0.0
#define CMD_LayerPrint                    2583  // Added version 6.0.0
#define CMD_LayerNoPrint                  2584  // Added version 6.0.0
#define CMD_TabTools                      2585  // Added version 7.0.0
#define CMD_PrintOrigin                   2586  // Added version 7.0.0
#define CMD_TabColor                      2587  // Added version 8.0.0
#define CMD_TabImageImport                2588  // Added version 8.0.0
#define CMD_TabRefFrame                   2589  // Added version 8.0.0

#define CMD_DimProxFixed                  2590
#define CMD_DimHorzText                   2591
#define CMD_TextDisplay                   2592  // Added version 8.0.0
#define CMD_DimRefFlip                    2593  // Added version 6.0.0
#define CMD_TabUserInterface              2594  // Added version 8.0.0
#define CMD_DimPrefixAbove                2595  // Added version 8.0.0
#define CMD_DimSuffixBelow                2596  // Added version 8.0.0
#define CMD_ExDataEditDlg                 2597  // Added version 8.0.0
#define CMD_DimLeaderDisplayDlg           2598  // Added version 8.0.0
#define CMD_TabFill                       2599  // Added version 8.0.1

#define CMD_ArrowFlip                     2600
#define CMD_TabLeader                     2601

#define CMD_TabPlotterPenMapSettings      2602
#define CMD_TabPlotterSettings            2603
#define CMD_TabPlotterLanguageSettings    2604

#define CMD_DimTextAlignDlg               2605
#define CMD_LeaderEditDlg                 2606
#define CMD_DimShowDash                   2607
#define CMD_TextSettingsDlg               2608
#define CMD_DimSettingsDlg                2609
#define CMD_LeaderSettingsDlg             2610

// Reference Frame Zooms
#define CMD_RFZoomRegen                   2611
#define CMD_RFZoomScale                   2612
#define CMD_RFZoomArea                    2613
#define CMD_RFZoomIn                      2614
#define CMD_RFZoomOut                     2615
#define CMD_RFZoomPan                     2616
#define CMD_RFZoomAll                     2617
#define CMD_RFZoomView                    2618
#define CMD_RFZoomPrevious                2619
#define CMD_RFDrawBoundary                2620
#define CMD_RFBirdsEye                    2621
#define CMD_RFResize                      2622
#define CMD_RFLayerManager                2623
#define CMD_RFTransparent                 2624
#define CMD_RFSize                        2625
#define CMD_RFUpdateFileLink              2626
#define CMD_RFZoomAnchor                  2627  // Added version 7.0.0
#define CMD_RFTrim                        2628  // Added version 8.0.0
#define CMD_RFLayerChange                 2629  // Added version 8.0.0
#define CMD_SelectFence                   2630  // Added version 9.0.0  
#define CMD_SelectFenceCrossing           2631  // Added version 9.0.0
#define CMD_CommandList                   2632  // Added version 9.0.0
#define CMD_RemovePoint                   2633  // Added version 9.0.0
#define CMD_InsertPoint                   2634  // Added version 9.0.0
#define CMD_ModOffsetAdv                  2635  // Added version 9.0.0
#define CMD_DimOverwriteDlg               2636  // Added version 9.0.0
#define CMD_FileRevert                    2637  // Added version 9.0.0
#define CMD_FileBackup                    2638  // Added version 9.0.0
#define CMD_ModFitVector                  2639  // Added version 9.0.0

#define CMD_ToFront                       2640
#define CMD_ToBack                        2641
//#define CMD_RemoveNameView              2642  // Added version 3.0.0 / Removed version 5.0.3
#define CMD_TabFonts                      2642  // Added version 6.0.0
#define CMD_TabSymbols                    2643  // Added version 6.0.0
#define CMD_TabLeaderText                 2644  // Added version 6.0.0
#define CMD_RFElliptical                  2645  // Added version 6.0.0

#define CMD_RFDrawBoundaryCh              2646  // Added version 7.0.1
#define CMD_RFTransparentCh               2647  // Added version 7.0.1
#define CMD_RFEllipticalCh                2648  // Added version 7.0.1
#define CMD_LeaderTextVectDlg             2649  // Added version 9.0.0

// Ref Frame Dlg id
#define CMD_Tab                           2650
#define CMD_RefFrameNameDlg               2651
#define CMD_RefFrameDlg                   2651  //+-JLW 29-Nov-17 b8-43 for HelpTableGen    //  CMD_RefFrameNameDlg   // Added version 8.0.0 as alternate symbol
#define CMD_RefFrameMDIDlg                2652  // Removed version 5.0.0 TBD  //ooJLW 28-Jan-04 obsolete, but leave for now because it is still used in RC file
#define CMD_DimScaleDlg                   2653

#define CMD_MultiLineSettingsDlg          2654  // Added version 4.0.0
#define CMD_DateStamp                     2655  // Added version 4.0.0

#define CMD_LGUNDO                        2660
#define CMD_LGSAVE                        2661
#define CMD_LGREDO                        2663
#define CMD_LGPRINT                       2664
#define CMD_LGPASTE                       2665
#define CMD_LGOPEN                        2666
#define CMD_LGHELP                        2667
#define CMD_LGCUT                         2668
#define CMD_LGCOPYC                       2669
#define CMD_LGNEW                         2670
#define CMD_LGHELPCUR                     2671
#define CMD_LGPRINTSETUP                  2672

#define CMD_TabCustomCommand              2673  // Added version 9.0.0
#define CMD_TabCustomShortcut             2674  // Added version 9.0.0
#define CMD_TabDimNumeric                 2675  // Added version 9.0.0
#define CMD_WizSummary                    2676  // Added version 9.0.0
#define CMD_CurveText                     2677  // Added version 9.0.0

#define CMD_FileOpenAsCopy                2678  // Added version 9.0.0
#define CMD_FileOpenAsStyle               2679  // Added version 9.0.0
#define CMD_FileSaveAsCopy                2680  // Added version 9.0.0
#define CMD_FileSaveAsCopyAndOpen         2681  // Added version 9.0.0
#define CMD_SymbolOpenAndPlace            2682  // Added version 9.0.0
#define CMD_SymbolOpenAndPlaceSingle      2683  // Added version 9.0.0
#define CMD_SymbolOpenAsDrawing           2684  // Added version 9.0.0
#define CMD_ConfigDiff                    2685  // Added version 9.0.0

// OPEN_NUMBERS

#define CMD_TextVectorSett                2700

// OPEN_NUMBERS

// CMD_DimLeaderTextDlg
#define CMD_DimDatumStringDlg             2708  // Added version 9.0.0
#define CMD_DimLeaderStringDlg            2709
#define CMD_DimLeaderArrowDlg             2710
#define CMD_DimLeaderEditDlg              2711
#define CMD_DimLeaderDatumDlg             2712
#define CMD_DimLeaderSpacingDlg           2713

#define CMD_BearingDistance               2714  // Added version 4.0.0
#define CMD_BearingSettingsDlg            2715  // Added version 4.0.0
#define CMD_BearingLabel                  2716  // Added version 4.0.0

// OPEN_NUMBERS

#define CMD_DocMgr                        2720  // Added version 3.0.0
#define CMD_SymBreak                      2721  // Added version 3.0.0
#define CMD_SymMend                       2722  // Added version 3.0.0
#define CMD_SymSetInsertColor             2723  // Added version 3.0.0
#define CMD_Customize                     2724  // Added version 3.0.0
#define CMD_RubberSheeting                2725  // Added version 3.0.0
#define CMD_MoveToLayer                   2726  // Added version 3.0.0
#define CMD_CopyToLayer                   2727  // Added version 3.0.0

// OPEN_NUMBERS

//Display Units 100 below Dimension Units
#define CMD_UnitDisplayInch               2731  // Added version 3.0.0
#define CMD_UnitDisplayFeet               2732  // Added version 3.0.0
#define CMD_UnitDisplayFeetInch           2733  // Added version 3.0.0
#define CMD_UnitDisplayMile               2734  // Added version 3.0.0

#define CMD_UnitDisplayFracInch           2735  // Added version 3.0.0
#define CMD_UnitDisplayFracFeet           2736  // Added version 3.0.0
#define CMD_UnitDisplayFracFeetInch       2737  // Added version 3.0.0

#define CMD_UnitDisplayMM                 2738  // Added version 3.0.0
#define CMD_UnitDisplayCM                 2739  // Added version 3.0.0
#define CMD_UnitDisplayMeter              2740  // Added version 3.0.0
#define CMD_UnitDisplayKilo               2741  // Added version 3.0.0


#define CMD_XYLock                        2742  // Added version 3.0.0


// all tool commands defined between  1000+1024+76 & ToolBaseEnd

#define CMD_WinErase                      2743  // Added version 3.0.0 WINERASE,WE, ,Window &Erase,Erase by Window,HI;CS;SW;@;@;ER;HI;
#define CMD_ObjErase                      2744  // Added version 3.0.0 OBJERASE,OE, ,Object E&rase,Object Erase,CS;HI;SB;@;ER;HI;
#define CMD_WinMove                       2745  // Added version 3.0.0 WINMOVE,WM, ,Window &Move,Place Window,CS;SW;@;@;MV;@;@;
#define CMD_WinCopy                       2746  // Added version 3.0.0 WINCOPY,WC, ,Window &Copy, Place Window,CS;sw;@;@;co;
#define CMD_ObjCopy                       2747  // Added version 3.0.0 OBJCOPY,OC, ,Object C&opy, Select Object,CS;sb;@;co;
#define CMD_ObjMove                       2748  // Added version 3.0.0 OBJMOVE,OM, ,Object Mo&ve, Select Object,CS;SB;@;MV;@;@;
#define CMD_WinRotate                     2749  // Added version 3.0.0 WINROTATE,WT, ,Window &Rotate, Place Window,CS;SW;@;@;RO;
#define CMD_DwgRotate                     2750  // Added version 3.0.0 DWGROTATE,DT, ,&Drawing Rotate, ,SA;RO;
#define CMD_WinChange                     2751  // Added version 3.0.0 WINCHANGE,WG, ,Window Chan&ge, Place Window,CS;sw;@;@;cg;
#define CMD_DwgChange                     2752  // Added version 3.0.0 DWGCHANGE,DG, ,Drawing Change, ,sa;cg;
#define CMD_WinScale                      2753  // Added version 3.0.0 WINSCALE,WZ, ,Window Sc&ale,Place Window,CS;SW;@;@;SZ;@;
#define CMD_DwgScale                      2754  // Added version 3.0.0 DWGSCALE,DZ, ,Drawing Scal&e,Drawing Scale,CS;SA;SZ;@;
#define CMD_ObjChange                     2755  // Added version 3.0.0 OBJCHANGE,OG, ,&Object Change,Select Object to Change,CS;SB;@;CG;
#define CMD_WinHatch                      2756  // Added version 3.0.0 WinHatch,WH, ,Window &Hatch, Window Hatch,CS;SW;@;@;HS;
#define CMD_WinFill                       2757  // Added version 3.0.0 WinFill,WF, ,Window &Fill,Window Fill,CS;SW;@;@;FS;
#define CMD_WizText                       2758  // Added version 3.0.0 WIZTEXT,WIT,,Text Wizard,Text Wizard,DLLNAme;VCWiz32.dll;DLLFunName;VCWizard;DLLCmdLine;TEXT;DLLRUN;
#define CMD_WizDim                        2759  // Added version 3.0.0 WIZDIM,WID,,Dimension Wizard,Dimension Wizard,DLLNAme;VCWiz32.dll;DLLFunName;VCWizard;DLLCmdLine;DIMENSION;DLLRUN;
#define CMD_WizDraw                       2760  // Added version 3.0.0 WIZDRAW,WIR,,Drawing Wizard,Drawing Wizard,DLLNAme;VCWiz32.dll;DLLFunName;VCWizard;DLLCmdLine;DRAWING;DLLRUN;
#define CMD_WizProp                       2761  // Added version 3.0.0 WIZPROP,WIP,,&Drawing Properties,Drawing Properties,DLLNAme;VCWiz32.dll;DLLFunName;VCWizard;DLLCmdLine;PSHEET;DLLRUN;
#define CMD_DwgMove                       2762  // Added version 6.0.0 

// OPEN_NUMBERS

#define CMD_OSnapMode                     2770  // Added version 3.0.0
#define CMD_OSnapType                     2771  // Added version 3.0.0
#define CMD_OSnapPreview                  2772  // Added version 3.0.0
#define CMD_ApertureMode                  2773  // Added version 3.0.0

#define CMD_RSEndPoint                    2774  // Added version 4.0.0
#define CMD_RSObject                      2775  // Added version 4.0.0
#define CMD_RSMidPoint                    2776  // Added version 4.0.0
#define CMD_RSIntersec                    2777  // Added version 4.0.0
#define CMD_RSPerpend                     2778  // Added version 4.0.0
#define CMD_RSTangent                     2779  // Added version 4.0.0
#define CMD_RSPercent                     2780  // Added version 4.0.0
#define CMD_RSQuadrant                    2781  // Added version 4.0.0
#define CMD_RSCenter                      2782  // Added version 4.0.0
#define CMD_RSAll                         2783  // Added version 4.0.0

#define CMD_Solid                         2784  // Added version 8.0.0
#define CMD_FilletPreview                 2785  // Added version 8.0.0
#define CMD_FixedOffset                   2786  // Added version 8.0.0
#define CMD_RSGrid                        2787  // Added version 8.0.0
#define CMD_RSApertureMode                2788  // Added version 8.0.0

// OPEN_NUMBERS

#define CMD_DrawLineMid                   2800  // Added version 3.0.0 
#define CMD_UserAlert                     2801  // Added version 3.0.0

#define CMD_ToolScriptRun                 2802  // Added version 4.0.0
#define CMD_AutoProperties                2803  // Added version 4.0.0

#define CMD_SendAlert                     2804  // Added version 5.0.0

// OPEN_NUMBERS

// Dimension Units 100 above Display Units
#define CMD_UnitDimensionInch             2831  // Added version 4.0.5
#define CMD_UnitDimensionFeet             2832  // Added version 4.0.5
#define CMD_UnitDimensionFeetInch         2833  // Added version 4.0.5
#define CMD_UnitDimensionMile             2834  // Added version 4.0.5

#define CMD_UnitDimensionFracInch         2835  // Added version 4.0.5
#define CMD_UnitDimensionFracFeet         2836  // Added version 4.0.5
#define CMD_UnitDimensionFracFeetInch     2837  // Added version 4.0.5

#define CMD_UnitDimensionMM               2838  // Added version 4.0.5
#define CMD_UnitDimensionCM               2839  // Added version 4.0.5
#define CMD_UnitDimensionMeter            2840  // Added version 4.0.5
#define CMD_UnitDimensionKilo             2841  // Added version 4.0.5

// OPEN_NUMBERS

// Dimension Secondary Units 100 above Dimension Units
#define CMD_UnitSecondaryInch             2931  // Added version 4.0.5
#define CMD_UnitSecondaryFeet             2932  // Added version 4.0.5
#define CMD_UnitSecondaryFeetInch         2933  // Added version 4.0.5
#define CMD_UnitSecondaryMile             2934  // Added version 4.0.5

#define CMD_UnitSecondaryFracInch         2935  // Added version 4.0.5
#define CMD_UnitSecondaryFracFeet         2936  // Added version 4.0.5
#define CMD_UnitSecondaryFracFeetInch     2937  // Added version 4.0.5

#define CMD_UnitSecondaryMM               2938  // Added version 4.0.5
#define CMD_UnitSecondaryCM               2939  // Added version 4.0.5
#define CMD_UnitSecondaryMeter            2940  // Added version 4.0.5
#define CMD_UnitSecondaryKilo             2941  // Added version 4.0.5

// OPEN_NUMBERS

#define CMD_DrawFirst                     2950  // Added version 5.0.0
#define CMD_DrawLast                      2951  // Added version 5.0.0
#define CMD_DrawAfter                     2952  // Added version 5.0.0
#define CMD_DrawBefore                    2953  // Added version 5.0.0

// OPEN_NUMBERS

#define CMD_SpellCheck                    2960  // Added version 5.0.0
#define CMD_SpellOptions                  2961  // Added version 5.0.0

#define CMD_ConfigEdit                    2965  // Added version 6.0.0
#define CMD_SetCfgEditor                  2966  // Added version 6.0.0
#define CMD_HatchChangeDlg                2967  // Added version 6.0.0

#define CMD_EditPasteSpecial              2968  // Added version 7.0.0
#define CMD_SpellCheckDlg                 2969  // Added version 7.0.0
#define CMD_NameViewCombo                 2970  //.Added version 7.0.0
#define CMD_Persist                       2971  // Added version 7.0.0
#define CMD_DllRunNET                     2972  // Added version 7.0.0
#define CMD_FillChangeDlg                 2973  // Added version 8.0.1
#define CMD_SymbolChangeDlg               2974  // Added version 9.0.0

// OPEN_NUMBERS

// NEXT OPEN ID search under OPEN_NUMBERS

//  BezEdit options
#define CMD_BezEdit_MoveNodeOnly            3001  //  Added version 8.0.0
#define CMD_BezEdit_MoveNodeAndControls     3002  //  Added version 8.0.0
#define CMD_BezEdit_ApplyBCSmoothing        3003  //  Added version 8.0.0
#define CMD_BezEdit_ApplyCVSmoothing        3004  //  Added version 8.0.0
#define CMD_BezEdit_ApplyTangentSmoothing   3005  //  Added version 8.0.0
#define CMD_BezEdit_MoveControlOnly         3006  //  Added version 8.0.0
#define CMD_BezEdit_MoveControlAngleOnly    3007  //  Added version 8.0.0
#define CMD_BezEdit_MoveControlDistanceOnly 3008  //  Added version 8.0.0
#define CMD_BezEdit_MoveBothControls        3009  //  Added version 8.0.0
#define CMD_BezEdit_ApplyMatchTangent       3010  //  Added version 8.0.0
#define CMD_BezEdit_MoveTwoNodesOnly        3011  //  Added version 8.0.0
#define CMD_BezEdit_MoveTwoNodesAndControls 3012  //  Added version 8.0.0


#define TOKENTOOLLAST                     3100


//======================================  OTHER        =================================================
//======================================  OTHER        =================================================
//======================================  OTHER        =================================================

#define TOKENOTHERFIRST                   3101
#define CMD_Base                          3101
#define ID_Message                        3101

#define ID_UpdateByExampleInspector       3101  // Added version 3.0.0
#define ID_UpdateByExample                3102
#define ID_OpenToolbar                    3103
#define ID_StatusBar                      3104
#define ID_StatusBarToggles               3105
#define ID_OpenLeftToolbar                3106
#define ID_CreateToolDialog               3107
#define ID_DeleteToolDialog               3108
#define MSG_EditChange                    3109
#define ID_UpdateControls                 3110
#define ID_CurrDlgMessage                 3111
#define MSG_DisplayDlgValues              3112
#define MSG_EditComplete                  3113
#define ID_AbortCurrentDialog             3114
#define MSG_EditAbort                     3115

#define MSG_DispatchNextPoint             3116
#define MSG_DispatchCommand               3117
#define ID_ProcessTool                    3118
#define ID_CreateDialogModeless           3119
#define ID_OpenLastDrawing1               3120
#define ID_OpenLastDrawing2               3121
#define ID_OpenLastDrawing3               3122
#define ID_OpenLastDrawing4               3123
#define ID_OpenLastDrawing5               3124
#define ID_OpenLastDrawing6               3125
#define ID_OpenLastDrawing7               3126
#define ID_OpenLastDrawing8               3127
#define ID_OpenLastDrawing9               3128
#define ID_OpenLastDrawing10              3129
#define ID_OpenLastDrawing11              3130  // Added version 3.0.0
#define ID_OpenLastDrawing12              3131  // Added version 3.0.0
#define ID_OpenLastDrawing13              3132  // Added version 3.0.0
#define ID_OpenLastDrawing14              3133  // Added version 3.0.0
#define ID_OpenLastDrawing15              3134  // Added version 3.0.0
#define ID_OpenLastDrawing16              3135  // Added version 3.0.0
#define ID_CreateToolDialogWithId         3136
#define ID_GetDialogFromId                3137  // Added version 4.0.0
#define ID_DisplayValues                  3138  // Added version 5.0.2

// OPEN_NUMBERS

#define ID_CreateToolModal                3140
#define ID_CreateToolModalWithId          3141
#define ID_CreateDialogModal              3142
#define ID_UpdateManager                  3143
#define ID_AllWorldsDestroyed             3144
#define MSG_METERSTART                    3145
#define MSG_METERSTOP                     3146
#define MSG_METERSTEP                     3147
#define ID_DeleteDialog                   3148
#define MSG_ReleaseMouseMenu              3149
#define MSG_RegenMerge                    3150
#define MSG_DrawEntity                    3151
#define MSG_UpdateBirdsEyeView            3152
//#define MSG_MyMsgBox                    3153  // Removed version 5.0.2 - obsolete 
#define MSG_DIGPOINT                      3154
#define ID_UpdateProperties               3155
#define ID_UpdateByExampleMulti           3156  // Added version 3.0.0
#define ID_HatchErrorDlg                  3157  // Added version 4.0.0
#define ID_CheckMessageBox                3158  // Added version 5.0.0

// OPEN_NUMBERS

// symbol manager messages
#define ID_CreateFromDrag                 3160  // Added version 3.0.0
#define ID_AbortCreateFromDrag            3161  // Added version 3.0.0
#define ID_GetHandlePoint                 3162  // Added version 8.0.0

// OPEN_NUMBERS

#define ID_PersistentTools                3170  // Added version 3.0.0
#define ID_MenuShortcuts                  3171  // Added version 3.0.0

#define CMD_BTProperty                    3172  // Redefined version 5.0.0 was 3102
#define CMD_FilterFromSelectionRibalog    3173  // Redefined version 5.0.0 was 3103
#define CMD_SelectionRibalogWithId        3174  // Redefined version 5.0.0 was 3104
#define CMD_SelLayerFromSelectionRibalog  3175  // Redefined version 5.0.0 was 3105
#define CMD_VCF                           3176  // Redefined version 5.0.0 was 3106
#define CMD_TrueType                      3177  // Redefined version 5.0.0 was 3107
#define CMD_Maximize                      3178  // Redefined version 5.0.0 was 3108
#define CMD_MaximizeDn                    3179  // Redefined version 5.0.0 was 3109

#define ID_OpenMDITabs                    3180  // Added version 8.0.0
#define CMD_OleManager                    3181  // Added version 8.0.0
// OPEN_NUMBERS

// HARD TO CATEGORIZE Section
#define CMD_Misc                          3301

// OPEN_NUMBERS

#define CMD_FontName                      3308
#define DBaseDlgReset                     3309
#define ID_RestoreToolbar                 3310
//#define CMD_Macro                         3312
//#define CMD_Hint                          3313
#define CMD_DlgOk                         3315
#define CMD_DlgMatch                      3316

// OPEN_NUMBERS

#define CMD_DefaultTool                   3329
#define CMD_ShowAngle2                    3333
#define CMD_ShowAngle3                    3334
#define CMD_ShowDist                      3335
#define CMD_AutomationMacro               3344
#define CMD_AttributeEmbedDlg             3368
#define CMD_AttributeCreateDlg            3369
#define CMD_AttributeAttachDlg            3370
//#define CMD_SpecificAttributeAttachDlg    3371  // unused
#define CMD_AttributeEditDlg              3372
#define CMD_UpdateControls                3373
#define CMD_OLEDrawingDirty               3374
// OPEN_NUMBERS

#define ID_MESSAGE                        3376
#define CMD_ShowHidLayerMsg               3377  // Added version 5.0.0
#define CMD_GetUpdate                     3378
#define CMD_UpdateSettings                3379
#define CMD_ExportXML                     3380  // Added version 6.0.0
#define CMD_ImportXML                     3381  // Added version 6.0.0
#define CMD_ExportCADD                    3382  // Added version 6.0.0
#define CMD_ImportCADD                    3383  // Added version 6.0.0
#define CMD_PromptVCDName                 3384  // Added version 6.0.0
// OPEN_NUMBERS

#define CMD_StyleDlg2                     3391  // Added version 6.0.0

#define CMD_EditCopyRef                   3392  // Added version 8.0.0
#define CMD_EditCutRef                    3393  // Added version 8.0.0
#define CMD_RFOpenReference               3394  // Added version 8.0.0

// Windows Section
#define CMD_WindowCloseExcept             3401  // Added version 9.0.0, replaces unused CMD_Windows

//  Windows visual managers
#define ID_VISUAL_MGR_WIN_2000            3411
#define ID_VISUAL_MGR_OFF_XP              3412
#define ID_VISUAL_MGR_WIN_XP              3413
#define ID_VISUAL_MGR_OFF_2003            3414
#define ID_VISUAL_MGR_VS_2005             3415
#define ID_VISUAL_MGR_VS_2008             3416
#define ID_VISUAL_MGR_OFF_2007_BLUE       3417
#define ID_VISUAL_MGR_OFF_2007_BLACK      3418
#define ID_VISUAL_MGR_OFF_2007_SILVER     3419
#define ID_VISUAL_MGR_OFF_2007_AQUA       3420
#define ID_VISUAL_MGR_WINDOWS_7           3421
#define ID_VISUAL_MGR_VCADD_8             3422

// OPEN_NUMBERS

// Non Tool Settings
#define NonToolBase                       6101
// all non tool commands defined between  CMD_NonToolBase & CMD_NonToolBaseEnd

// Drawing Settings
#define CMD_DrawingSettings               6101
#define CMD_RPolygonNSides3               6106
#define CMD_RPolygonNSides4               6107
#define CMD_RPolygonNSides5               6108
#define CMD_RPolygonNSides6               6109
#define CMD_RPolygonNSides7               6110
#define CMD_RPolygonNSides8               6111
#define CMD_RPolygonNSides9               6112
#define CMD_RPolygonNSides10              6113
#define CMD_RPolygonNSides11              6114
#define CMD_RPolygonNSides12              6115
#define CMD_LeftJustify                   6117
#define CMD_LeftJustifyDn                 6118
#define CMD_CenterJustify                 6119
#define CMD_CenterJustifyDn               6120
#define CMD_RightJustify                  6121
#define CMD_RightJustifyDn                6122
#define CMD_Bold                          6123
#define CMD_BoldDn                        6124
#define CMD_Italic                        6125
#define CMD_ItalicDn                      6126
#define CMD_MEAbsolute                    6127
#define CMD_MERelative                    6128
#define CMD_MEBasepoint                   6129
#define CMD_RPolygonInscribed             6130
#define CMD_Underline                     6131
#define CMD_UnderlineDn                   6132
#define CMD_Strikeout                     6133

// OPEN_NUMBERS

// Bool commands
#define CMD_Bool                          6501

// OPEN_NUMBERS

// all NON tool commands defined between  CMD_3000+1000+1024+76+1000+1 & CMD_NonToolBaseEnd
#define NonToolBaseEnd                    6601
#define LASTVALIDTOKEN                    6601

// script constants
// 2K of Script commands, ok that they overlap the Help ids
#define ScriptBase                        6602
#define CMD_Script001                     6603
#define ScriptLast                        8652  // 2048 commands

#if FALSE
#define ID_OLE_INSERT_NEW               57856   //  0xE200
#define ID_OLE_EDIT_LINKS               57857   //  0xE201
#define ID_OLE_VERB_FIRST               57872   //  0xE210
#define ID_EDIT_PASTE                   57637   //  0xE125
#define ID_FILE_MRU_FILE1               57616   //  0xE110
#endif

#endif
