/*SDOC*************************************************************

  Module:	VCTypes.h

  Copyright (C) 2017 Gold Run Partners, Inc.  All rights reserved.
  
  Description: Visual CADD specific type definitions and constants
  
  Revision Record:

    Version			Changes & Additions
    ========		=====================================================
    2.0.0				Changed struct EAttr to include float fWidth

    2.0.2				Changed iPoint2D x&y to 4 byte integers

    3.0.0				Added new AlertApp codes
    3.0.0				Added new AlertAppEx function and AlertAppEx codes
    3.0.0				Added new file type constants
    3.0.0				Added new unit constants

    3.0.1				Added new AlertAppEx codes

    4.0.0				Added packed lparam values to Tool start, complete and abort alerts
    4.0.0				Added Visual CADD tool types for use in alerts 
    4.0.0				Added new AlertAppEx codes
    4.0.0				Added new Dimension constant
    4.0.0				Added status codes on completion of HatchGen
    4.0.0				Added Ortho Advanced type flags
    4.0.0				Added Running snap type flags
    4.0.0				Added Running snap types bitwise operators
    4.0.0				Added Font list sorting order flags 

    5.0.0				Added new AlertAppEx codes
    5.0.0				Added FileOpen/FileSave AlertAppEx constants
    5.0.0				Added new file type constants
    5.0.0				Added new font type constants
    5.0.0				Added hatch alignment flags
    5.0.0				Added sound event flags
    5.0.0				Added VCSetCurrentErasedEx constants and flags
    5.0.3				Added PDFExportSettings

    6.0.0				Added new angle formats
    6.0.0				Added new Multiline and Image entity types
    6.0.0				Added dimension angle constants
    6.0.0				Added leader border and part constants
    6.0.0				Added file locking constants

    7.0.0               Added image export definitions
    7.0.0               Added XML settings structure
    7.0.0               Added file translation constants

*************************************************************EDOC*/

#if !defined(VCTYPE32_H_INCLUDED)
#define VCTYPE32_H_INCLUDED

// Note: Visual CADD expects all structures defined by the API to be 1-byte aligned.  Most compilers use 8-byte alignment as the default.
// To ensure that structure members are correctly aligned, you must ensure that your compiler treats the structures defined in this file
// as 1-byte aligned.
// The following lines and the #pragma pack(pop) at the end of the file will set 1-byte alignment for Microsoft compilers.
// For other compilers, equivalent directives should be used.
#if defined _MSC_VER
#pragma pack(push)
#pragma pack(1)
#endif


// Entity Kinds
// extern "C" short WINAPI VCGetCurrentEntityKind(short* iError);
// Reserve 1-100 for 2D kinds
#define UNKNOWN             0
#define LINE2D              1
#define ARC2D               2
#define CIRCLE2D            3
#define ELLIPSE2D           4
#define BEZIER2D            5
#define POINT2D             6
#define SYMBOL2D            7
#define TEXT2D              8
#define DIMLINEAR2D         9
#define DIMANGULAR2D        10
#define DIMRADIAL2D         11
#define DIMDIAMETER2D       12
#define FILL2D              13
#define HATCH2D             14
#define ATTRIBUTE2D         15
#define INTERPCURV2D        16
#define MINTERPCURV2D       17
#define ELLIPTICALARC2D     18
#define CONTINUOUSLINE2D    19
#define CONTINUOUSBEZIER2D  20
#define LEADER2D            21
#define REFFRAME2D          22
#define ORDDIM2D            23
#define IMAGE2D             24 //Added version 6.0.0
#define MULTILINE2D         25 //Added version 6.0.0

// Reserve 101-200 for 3D kinds
#define POLYGON3D           101
#define POINT3D             102
#define LINE3D              103
#define SYMBOL3D            104
#define CONTINUOUSLINE3D    105


// extern "C" ENTITYHANDLE WINAPI VCGetCurrentEntityHandle(short* iError);
typedef long ENTITYHANDLE;

// extern "C" WORLDHANDLE WINAPI VCGetCurrWorld(void);
typedef long WORLDHANDLE;

// extern "C" GRAPHICHANDLE WINAPI VCCreateGraphicHandle(short* iError);
typedef long GRAPHICHANDLE;

// extern "C" UID WINAPI VCGetCurrentEntityUID(short* iError);
typedef unsigned long UID;

// extern "C" vbool WINAPI VCGetAutoSave(short* iError);
typedef short vbool;

// extern "C" void WINAPI VCScreenToWorld2D(short* iError, iPoint2D ipScreen, Point2D* dpWorld);
// ipScreen = 
typedef struct iPoint2D {
    int x;	// 4-byte integers - long
    int y;
} iPoint2D;

// extern "C" void WINAPI VCDigPoint(lPoint2D lpt, short bButtonNum, short bButtonState);
// lpt =
typedef struct lPoint2D {
    long x;
    long y;
} lPoint2D;

// extern "C" void WINAPI VCAddLineEntity(short* iError, short iSymbolIndex, Point2D dpP0, Point2D dpP1);
// dpP0 = 
typedef struct Point2D {
    double x;
    double y;
} Point2D;

// extern "C" void WINAPI VCAddLine3D(short* iError, short iSymbolIndex, Point3D* dpP0, Point3D* dpP1);
// dpP0 =
typedef struct Point3D {
    double x;
    double y;
    double z;
} Point3D;

// extern "C" void WINAPI VCChangeSelected(EAttr* ea);
// ea =
typedef struct EAttr {
    short iColor;
    short iLayer;
    short iLinetype;
    short iLinewidth;
    float fWidth;
    BYTE bByLayerFlag;
} EAttr;
// Bitwise flags that can be "OR"ed together for the bByLayerFlag member of the EAttr Struct
#define COLORBYLAYER      0x01
#define TYPEBYLAYER       0x02
#define WIDTHBYLAYER      0x04
#define RESERVEBYLAYER    0x08

//======================================================================================
// Defines for VCSetAlertApp, VCSetAlertAppEx, VCSetAlertAppDll & VCSetAlertAppDllEx
// extern "C" void WINAPI VCSetAlertAppDllEx(short* iError, char* DllName, char* NativeCmd, long iCode0, long iCode1);

// iCode0 = ALERT_APP_....
// Code1 = ALERT_APP_EX_.....
// These values can be bit-wise "OR"ed together.
// Example:
// VCSetAlertAppDllEx(iError, DllName, NativeCmd, iCode0, iCode1);
// iCode0 = ALERT_APP_WORLD_CLOSE | ALERT_APP_UTOOL_MOUSEMOVE
// iCode1 = ALERT_APP_EX_WORLD_ACTIVATE


// The ALERT_APP_..._DLL defines are the DLL function name postfixes when using
// VCSetAlertAppDll(...) and VCSetAlertAppDllEx(...). They are separated from the
// NativeCmd parameter by a '_'.
// Example:
// NativeCmd = "MyFunction"
// iCode0 = ALERT_APP_UTOOL_MOUSEDOWN | ALERT_APP_UTOOL_MOUSEMOVE
// You need to define the following the functions in your DLL:
// void WINAPI MyFunction_MouseDown( WPARAM, LPARAM); //ALERT_APP_UTOOL_MOUSEDOWN
// void WINAPI MyFunction_MouseMove( WPARAM, LPARAM); // ALERT_APP_UTOOL_MOUSEMOVE 

// The ALERT_..._CHARCODE defines values are sent to your application as the wParam
// parameters of a WM_CHAR message when using VCSetAlertApp(...) and VCSetAlertAppEx(...).

// The ALERT_APP_... HEX value defines are for the iCode0
// The ALERT_APP_EX_... HEX value defines are for the iCode1
//======================================================================================

// Added version 6.0.0
typedef struct AlertMSG {
    HWND      hwnd;
    UINT      message;
    WPARAM    wParam;
    LPARAM    lParam;
    DWORD     dwUnused;
    LRESULT   lResult;
    LONG      lResultFlag;
} AlertMSG;

#define ALERT_APP_ALL             0
#define ALERT_APP_NONE            0x80000000

#define ALERT_APP_UTOOL_MOUSEDOWN 0x00000001
#define ALERT_APP_UTOOL_MOUSEDOWN_DLL "MouseDown"

#define ALERT_APP_UTOOL_MOUSEMOVE 0x00000002
#define ALERT_APP_UTOOL_MOUSEMOVE_DLL "MouseMove"

#define ALERT_APP_UTOOL_ABORT 0x00000004
#define ALERT_APP_UTOOL_ABORT_DLL "Abort"

#define ALERT_APP_CMDLINE_CHAR 0x00000008
#define ALERT_APP_CMDLINE_CHAR_DLL "Char"

#define ALERT_APP_CLOSE 0x00000010
#define ALERT_APP_CLOSE_DLL "AppClose"

#define ALERT_APP_UTOOL_PENUP 0x00000020
#define ALERT_APP_UTOOL_PENUP_DLL "PenUp"
#define ALERT_PENUP_CHARCODE 252

#define ALERT_APP_WORLD_CLOSE 0x00000040 
#define ALERT_APP_WORLD_CLOSE_DLL "DrawingClose"
#define ALERT_APP_WORLD_CLOSE_CHARCODE 253

#define ALERT_APP_UTOOL_ERASERUBBER 0x00000080
#define ALERT_APP_UTOOL_ERASERUBBER_DLL "EraseRubber"
#define ALERT_UTOOL_ERASERUBBER_CHARCODE 255

#define ALERT_APP_TOOL_COMPLETE 0x00000100
#define ALERT_APP_TOOL_COMPLETE_DLL "ToolComplete"
#define ALERT_TOOL_COMPLETE_CHARCODE 254
// Added version 4.0.0
// Added an encoded lParam which is sent with the alert 
// LOWORD = the ID of the tool completing. See CmdID.h
// HIGHWORD = the tool type. See Visual CADD Tool Types.

#define ALERT_APP_UTOOL_INIT 0x00000200
#define ALERT_APP_UTOOL_INIT_DLL "Init"
#define ALERT_UTOOL_INIT_CHARCODE 251

#define ALERT_APP_UTOOL_TERMINATE 0x00000400
#define ALERT_APP_UTOOL_TERMINATE_DLL "Terminate"
#define ALERT_UTOOL_TERMINATE_CHARCODE 250

#define ALERT_APP_FRAME_CLOSE 0x00000800
#define ALERT_APP_FRAME_CLOSE_DLL "FrameClose"
#define ALERT_FRAME_CLOSE_CHARCODE 249

#define ALERT_APP_FRAME_RESIZE 0x00001000
#define ALERT_APP_FRAME_RESIZE_DLL "FrameResize"
#define ALERT_FRAME_RESIZE_CHARCODE 248

#define ALERT_APP_ENTITY_ERASED 0x00002000
#define ALERT_APP_ENTITY_ERASED_DLL "EntityErased"
#define ALERT_APP_ENTITY_ERASED_CHARCODE 247

#define ALERT_APP_ENTITY_SELECT_CHANGE 0x00004000
#define ALERT_APP_ENTITY_SELECT_CHANGE_DLL "EntitySelectChange"
#define ALERT_APP_ENTITY_SELECT_CHANGE_CHARCODE 246

#define ALERT_APP_ACTIVATE 0x00008000
#define ALERT_APP_ACTIVATE_DLL "Activate"
#define ALERT_APP_ACTIVATE_CHARCODE 245

#define ALERT_APP_DEACTIVATE 0x00010000
#define ALERT_APP_DEACTIVATE_DLL "DeActivate"
#define ALERT_APP_DEACTIVATE_CHARCODE 244

#define ALERT_APP_UTOOL_MOUSEUP 0x00020000
#define ALERT_APP_UTOOL_MOUSEUP_DLL "MouseUp"

#define ALERT_APP_WORLD_MOUSEMOVE 0x00040000 
#define ALERT_APP_WORLD_MOUSEMOVE_DLL "WorldMouseMove"
#define ALERT_APP_WORLD_MOUSEMOVE_CHARCODE 243

#define ALERT_APP_WORLD_MOUSEDOWN 0x00080000 
#define ALERT_APP_WORLD_MOUSEDOWN_DLL "WorldMouseDown"
#define ALERT_APP_WORLD_MOUSEDOWN_CHARCODE 242

#define ALERT_APP_WORLD_MOUSEUP 0x00100000 
#define ALERT_APP_WORLD_MOUSEUP_DLL "WorldMouseUp"
#define ALERT_APP_WORLD_MOUSEUP_CHARCODE 241

#define ALERT_APP_WORLD_END_REDRAW 0x00200000 
#define ALERT_APP_WORLD_END_REDRAW_DLL "WorldEndRedraw"
#define ALERT_APP_WORLD_END_REDRAW_CHARCODE 240

#define ALERT_APP_WORLD_BEGIN_REDRAW 0x00400000 
#define ALERT_APP_WORLD_BEGIN_REDRAW_DLL "WorldBeginRedraw"
#define ALERT_APP_WORLD_BEGIN_REDRAW_CHARCODE 239

#define ALERT_APP_WORLD_BEGIN_PRINT 0x00800000
#define ALERT_APP_WORLD_BEGIN_PRINT_DLL "WorldBeginPrint"
#define ALERT_APP_WORLD_BEGIN_PRINT_CHARCODE 238

#define ALERT_APP_WORLD_END_PRINT 0x01000000 
#define ALERT_APP_WORLD_END_PRINT_DLL "WorldEndPrint"
#define ALERT_APP_WORLD_END_PRINT_CHARCODE 237

// Added version 3.0.0
#define ALERT_APP_TOOL_START 0x02000000  
#define ALERT_APP_TOOL_START_DLL "ToolStart"
#define ALERT_APP_TOOL_START_CHARCODE 236
// Added version 4.0.0
// encoded lParam which is sent with the alert 
// LOWORD = the ID of the tool being starting. See CmdID.h
// HIGHWORD = the tool type. See Visual CADD Tool Types.

// Added version 3.0.0
#define ALERT_APP_TOOL_ABORT 0x04000000
#define ALERT_APP_TOOL_ABORT_DLL "ToolAbort"
#define ALERT_APP_TOOL_ABORT_CHARCODE 235
// Added version 4.0.0
// encoded lParam which is sent with the alert
// LOWORD = the ID of the tool being aborted. See CmdID.h
// HIGHWORD = the tool type. See Visual CADD Tool Types.

//======================================================================================
// Defines for VCSetAlertAppEx & VCSetAlertAppDllEx iCode1 Parameter Added version 3.0.0
//======================================================================================
// Added version 3.0.0
#define ALERT_APP_EX_ALL 0xFFFFFFFF

// Added version 3.0.0
#define ALERT_APP_EX_PRE_TRANSLATE_GET_MESSAGE 0x00000001
#define ALERT_APP_EX_PRE_TRANSLATE_GET_MESSAGE_DLL "PreTranslateGetMessage"
#define ALERT_APP_EX_PRE_TRANSLATE_GET_MESSAGE_CHARCODE 233

// Added version 3.0.0
#define ALERT_APP_EX_PRE_TRANSLATE_FRAME_MESSAGE 0x00000002
#define ALERT_APP_EX_PRE_TRANSLATE_FRAME_MESSAGE_DLL "PreTranslateFrameMessage"
#define ALERT_APP_EX_PRE_TRANSLATE_FRAME_MESSAGE_CHARCODE 232

// Added version 3.0.0
#define ALERT_APP_EX_PRE_TRANSLATE_DIALOG_MESSAGE 0x00000004
#define ALERT_APP_EX_PRE_TRANSLATE_DIALOG_MESSAGE_DLL "PreTranslateDialogMessage"
#define ALERT_APP_EX_PRE_TRANSLATE_DIALOG_MESSAGE_CHARCODE 231

// Added version 3.0.0
// VCM_USER_ALERT Posted as the wParam of a WM_COMMAND Message will cause Visual CADD
// to call the ALERT_APP_EX_USER_ALERT_MESSAGE. The lParam the user sends in the WM_COMMAND
// message will be sent back to them. This call can be used to avoid recursion which can
// happen in many of the AlertApp messages such as starting a new tool from within the 
// AlertAppToolComplete message.
#define ALERT_APP_EX_USER_ALERT_MESSAGE 0x00000008
#define ALERT_APP_EX_USER_ALERT_DLL "UserAlert"
#define ALERT_APP_EX_USER_ALERT_CHARCODE 230
#define VCM_USER_ALERT	2801

// Added version 3.0.1
#define ALERT_APP_EX_DIALOG_OPEN_MESSAGE 0x00000010
#define ALERT_APP_EX_DIALOG_OPEN_DLL "DialogOpen"
#define ALERT_APP_EX_DIALOG_OPEN_CHARCODE 229

// Added version 3.0.1
#define ALERT_APP_EX_DIALOG_CLOSE_MESSAGE 0x00000020
#define ALERT_APP_EX_DIALOG_CLOSE_DLL "DialogClose"
#define ALERT_APP_EX_DIALOG_CLOSE_CHARCODE 228

// Added version 4.0.0
#define ALERT_APP_EX_PRE_TRANSLATE_MDICHILD_MESSAGE 0x00000040
#define ALERT_APP_EX_PRE_TRANSLATE_MDICHILD_MESSAGE_DLL "PreTranslateMdiChildMessage"
#define ALERT_APP_EX_PRE_TRANSLATE_MDICHILD_MESSAGE_CHARCODE 227

// Added version 5.0.0
// ALERT_APP_EX_WORLD_ACTIVATE sends the
// HWND of the world just activated as the lParam.
// This alert is sent after the world has been activated.
#define ALERT_APP_EX_WORLD_ACTIVATE 0x00000080 
#define ALERT_APP_EX_WORLD_ACTIVATE_DLL "WorldActivate"
#define ALERT_APP_EX_WORLD_ACTIVATE_CHARCODE 226

// Added version 5.0.0
// ALERT_APP_EX_WORLD_DEACTIVATE sends the
// HWND of the world to be deactivated as the lParam.
// This alert is sent before the window is deactivated.
#define ALERT_APP_EX_WORLD_DEACTIVATE 0x00000100
#define ALERT_APP_EX_WORLD_DEACTIVATE_DLL "WorldDeActivate"
#define ALERT_APP_EX_WORLD_DEACTIVATE_CHARCODE 225

// Added version 5.0.0
// ALERT_APP_EX_FILE_OPEN sends a flag indicating its
// state as the lParam.
// See ALERT_APP_EX_FILE_OPEN/FILE_SAVE alerts flags
#define ALERT_APP_EX_FILE_OPEN 0x00000200
#define ALERT_APP_EX_FILE_OPEN_DLL "FileOpen"
#define ALERT_APP_EX_FILE_OPEN_CHARCODE 224

// Added version 5.0.0
// ALERT_APP_EX_FILE_SAVE sends a flag indicating its
// state as the lParam.
// See ALERT_APP_EX_FILE_OPEN/FILE_SAVE alerts flags
#define ALERT_APP_EX_FILE_SAVE 0x00000400
#define ALERT_APP_EX_FILE_SAVE_DLL "FileSave"
#define ALERT_APP_EX_FILE_SAVE_CHARCODE 223

// Added version 4.0.0
// The Visual CADD Tool Types flags sent as the lParam with
// the ALERT_APP_TOOL_START/COMPLETE/ABORT alerts.
#define TOOL_NON_NESTABLE         0
#define TOOL_NESTABLE             1
#define TOOL_PHANTOM              2
#define TOOL_ALLOW_NON_NESTABLE   3

// Added version 5.0.0
// The lParam flags sent with the ALERT_APP_EX_FILE_OPEN/FILE_SAVE alerts
#define VC_FA_PRE_OPEN    1
#define VC_FA_POST_OPEN   2
#define VC_FA_PRE_DATA    3
#define VC_FA_POST_DATA   4
#define VC_FA_PRE_CLOSE   5
#define VC_FA_POST_CLOSE  6

// API calls which use "SymbolIndex", use this parameter for entity section additions
// extern "C" void WINAPI VCAddLineEntity(short* iError, short iSymbolIndex, Point2D dpP0, Point2D dpP1);
// iSymbolIndex = or iSymbolIndex = VCGetSymbolIndex(iError, pName);
#define NONDEFENTITY    (-1)
#define HATCHFILLENTITY (-2)

// extern "C" void WINAPI VCSetProjection3D(short* iError, short iCode);
// iCode =
#define VIEW3D_FLAT         0
#define VIEW3D_PARALLEL     1
#define VIEW3D_PERSPECTIVE  2

// extern "C" void WINAPI VCSet3DDisplay(short* iError, short iCode);
// iCode =
#define VIEW3D_WIREFRAME  0
#define VIEW3D_QSHADE     1

// extern "C" void WINAPI VCSet3DQShadeOptions(short* iError, short iCode);
// iCode =
#define QSHADE_ROUGH            0
#define QSHADE_EXACT            1
#define QSHADE_EXACT_AND_SPLIT  2

// extern "C" void WINAPI VCChangeView3D(short* iError, short iCode, double dFact);
// iCode =
#define CHANGE_VIEW3D_LEFT  0
#define CHANGE_VIEW3D_RIGHT 1
#define CHANGE_VIEW3D_UP    2
#define CHANGE_VIEW3D_DOWN  3

// VC Supported File Types
// extern "C" void WINAPI VCSaveDrawing(short* iError, char* pName, short iFileType, vbool tfSaveSelected);
// iFileType =
#define FILE_NONVALID (-1)
#define FILE_VCD        0
#define FILE_VCS        1
#define FILE_VCA        2
#define FILE_GCD        3
#define FILE_CMP        4
#define FILE_DWG        5
#define FILE_DXF        6
#define FILE_STY        7
#define FILE_VCF        8
#define FILE_EMF        9
#define FILE_WMF       10
#define FILE_SHP       11  // Added version 3.0.0
#define FILE_MIF       12  // Added version 3.0.0
#define FILE_VBK       13  // Added version 3.0.0
#define FILE_PDF       14  // Added version 5.0.0
#define FILE_VBS       15  // Added version 6.0.0
#define FILE_JS        16  // Added version 6.0.0

// Conversion unit constants 
#define UNIT_INCH   0
#define UNIT_FEET   1
#define UNIT_MM     2
#define UNIT_CM     3
#define UNIT_M      4
#define UNIT_MILE  10  // Added version 3.0.0
#define UNIT_K     11  // Added version 3.0.0

// Display and dimension units
// extern "C" void WINAPI VCSetDisplayDistFormat(short* iError, short iF);
// extern "C" void WINAPI VCSetDimDistFormat(short* iError, short iF_);
// iF =
#define InDec      0
#define FtInDec    1
#define FtDec      2
#define InFrac     3
#define FtInFrac   4
#define FtFrac     5
#define Mil        6
#define Cen        7
#define Met        8
#define Mile      20  // Added version 3.0.0
#define Kilo      21  // Added version 3.0.0

// Angular display and dimension units
// extern "C" void WINAPI VCSetDisplayAngleFormat(short* iError, short iF);
// extern "C" void WINAPI VCSetDimAngleFormat(short* iError, short iF_); 
// iF =
#define AngDeg     9
#define AngDMS    10
#define AngDM     11 // Added version 3.0.0
#define AngRad    12 // Added version 6.0.0
#define AngGrad   13 // Added version 6.0.0
#define AngSurvey 14 // Added version 6.0.0

// Dimension mode
// extern "C" void WINAPI VCDimSetDimMode(short* iError, short b);
// b =
#define DIMMODESINGLE       0
#define DIMMODECUMULATIVE   1
#define DIMMODEPARTITIONED  2

// Dimension Direction
// extern "C" void WINAPI VCSetDimLineDirect(short* iError, short b);
// b =
#define DIMALIGNED    1
#define DIMHORIZONTAL 2
#define DIMVERTICAL   3
#define DIMATANANGLE  4

// Tolerance Type
// extern "C" void WINAPI VCSetDimTextTolType(short* iError, short b);
// b =
#define DIMNOTOLERANCE      0
#define DIMSTACKEDMINMAX    1
#define DIMSTACKEDVARIANCE  2
#define DIMFIXEDVARIANCE    3
#define DIMBASICTOLERANCE   4

// Dimension Extension Stretch
// extern "C" void WINAPI VCDimSetDimExtStretch(short* iError, short b);
// b =
#define DIMEXTNOSTRETCH  0
#define DIMEXTSTRETCH    1

// Arrow Types
// extern "C" void WINAPI VCSetDimArrowType(short* iError, short b);
// b =
#define DIMARROWREGNOFILL     0
#define DIMARROWREGFILLED     1
#define DIMARROWREGOPEN       2
#define DIMARROWNOTCHED       3
#define DIMARROWSLASH         4
#define DIMARROWCIRCLENOFILL  5
#define DIMARROWCIRCLEFILL    6

// Dimension Text Position
// extern "C" void WINAPI VCSetDimLineText(short *iError, short b);
// b =
#define DIMTEXTINLINE           0
#define DIMTEXTABOVELINE        1
#define DIMTEXTFREEFLOAT        2
#define DIMTOUTSIDELINE         3 // Added version 4.0.0
#define DIMTEXTINLINE_CENTER    4 // Added version 8.0.0

// Dimension Text Rotation
// extern "C" void WINAPI  VCSetDimTextRotationType(short* iError, short b);
// b =
#define DIMTEXTROTATIONALIGNED    0
#define DIMTEXTROTATIONHORIZONTAL 1

// Dimension Proximity Mode
// extern "C" void WINAPI VCDimSetDimProximity(short* iError, short b);
// b =
#define DIMLINENOPROXFIX  0
#define DIMLINEPROXFIX    1

// Arrow Mode
// extern "C" void WINAPI VCSetDimArrowMode(short* iError, short b);
// b =
#define DIMARROWNOFLIP  0
#define DIMARROWFLIP    1

// Dimension items
// extern "C" void WINAPI VCSetDimItemColor(short* iError, short i, short j);
// i =
#define DIMLINE       0
#define DIMLEFTARROW  1
#define DIMRIGHTARROW 2
#define DIMLEFTEXT    3
#define DIMRIGHTEXT   4
#define DIMTEXT       5

//Added version 6.0.0
// Dimension angle styles
#define DIMANGLESTYLE_DEFAULT     0
#define DIMANGLESTYLE_ANGLEFIRST  1
#define DIMANGLESTYLE_ANGLELAST   2
#define DIMANGLESTYLE_ANGLEONLY   3

//Added version 9.0.0
// Dimension decimal separators
#define DIM_DECIMAL_SEPARATOR_PERIOD     0
#define DIM_DECIMAL_SEPARATOR_COMMA      1
#define DIM_DECIMAL_SEPARATOR_MIDDLE_DOT 2
#define DIM_DECIMAL_SEPARATOR_APOSTROPHE 3

//Added version 9.0.0
// Dimension thousands separators
#define DIM_THOUSANDS_SEPARATOR_NONE       0
#define DIM_THOUSANDS_SEPARATOR_COMMA      1
#define DIM_THOUSANDS_SEPARATOR_SPACE      2
#define DIM_THOUSANDS_SEPARATOR_PERIOD     3
#define DIM_THOUSANDS_SEPARATOR_APOSTROPHE 4
#define DIM_THOUSANDS_SEPARATOR_UNDERSCORE 5

//Added version 6.0.0
// Leader vertical alignments
// extern "C" void WINAPI VCSetLeaderVerticalAlign(short* iError, short b);
// b =
#define LEADER_VERT_DEFAULT         0
#define LEADER_VERT_TOPCENTER       0
#define LEADER_VERT_BASELINE        1
#define LEADER_VERT_TOP             2
#define LEADER_VERT_CENTER          3
#define LEADER_VERT_BOTTOMCENTER    4
#define LEADER_VERT_BOTTOMBASELINE  5

//Added version 8.0.0
// Text vertical alignments
// extern "C" void WINAPI VCSetTextVerticalAlign(short* iError, BYTE b);
// b =
#define TEXT_VERT_DEFAULT         1
#define TEXT_VERT_TOPCENTER       0
#define TEXT_VERT_BASELINE        1
#define TEXT_VERT_TOP             2
#define TEXT_VERT_CENTER          3
#define TEXT_VERT_BOTTOMCENTER    4
#define TEXT_VERT_BOTTOMBASELINE  5

//Added version 8.0.0
// Text position
// extern "C" void WINAPI VCSetLeaderHorizontalAlign(short* iError, BYTE b);
// b =
#define LEADER_HORZ_DEFAULT     0
#define LEADER_HORZ_LEFT        1
#define LEADER_HORZ_RIGHT       2
#define LEADER_HORZ_CENTER      3

//Added version 6.0.0
// Leader borders
#define LEADER_BORDER_BOX           0
#define LEADER_BORDER_CIRCLE_FIX    1
#define LEADER_BORDER_CIRCLE_VAR    2
#define LEADER_BORDER_VLINE         3
#define LEADER_BORDER_HLINE         4

//Added version 6.0.0
// Leader items
#define LEADERTEXT        0
#define LEADERLINE        1
#define LEADERARROW       2
#define LEADERBORDER      3

// Datum modes
// extern "C" void WINAPI VCSetDatumType(short* iError, short iDatumType);
// iDatumType =
#define DATUMNONE 0
#define DATUMXY   1
#define DATUMX    2
#define DATUMY    3

// Text justify modes
// extern "C" void WINAPI VCSetTextJustify(short* iError, short j);
// j =
#define JUSTIFY_CENTER  67  //  ASCII character 'C'
#define JUSTIFY_LEFT    76  //  ASCII character 'L'
#define JUSTIFY_RIGHT   82  //  ASCII character 'R'

// Symbol explode layers
// extern "C" void  WINAPI VCSetSymExplode(short* iError, short iEx);
// iEx =
#define INDIVIDUAL_LAYER  0
#define PLACEMENT_LAYER   1
#define CURRENT_LAYER     2

// AutoCAD Import Unit Types
// extern "C" void WINAPI VCSetAcadImportUnit(short* iError, BYTE b);
// b =
#define ACAD_UNIT_FIRST   0
#define ACAD_UNIT_INCH    ACAD_UNIT_FIRST
#define ACAD_UNIT_FEET    1
#define ACAD_UNIT_MILL    2
#define ACAD_UNIT_CENT    3
#define ACAD_UNIT_METER   4
#define ACAD_UNIT_LAST    ACAD_UNIT_METER // Updated as new unit types are added

// Printer API constants

// PrintStruct.tfPrintMode =
#define PRINTMODE 0
#define PLOTMODE  1

// PrintStruct.ScaleMode =
#define FITTOPAPER  1
#define CURRENTVIEW 2
#define SCALE       3

// PrintStruct.Orientation =
#define PORTRAITMODE  0
#define LANDSCAPEMODE 1

// PrintStruct.PaperUnit =
#define METRICUNITS   0
#define ENGLISHUNITS  1

// Used in PrintStruct
typedef struct DoubleRect {
    double Left;
    double Top;
    double Right;
    double Bottom;
} DoubleRect;

// extern "C" void WINAPI VCSetPrintSettings(short* iError, PrintStruct* pSettings);
// PrintStruct =
typedef struct PrintStructTag {
    vbool       tfPrintMode;
    Point2D     PageSize;
    DoubleRect  Margins;
    double      Scale;
    Point2D     Origin;
    short       ScaleMode;
    short       Orientation;
    double      Rotation;
    vbool       PrintToFile;
    vbool       SelectionOnly;
    vbool       DateStamp;
    vbool       FastPreview;
    vbool       AllColorsToBlack;
    short       PaperUnit;
} PrintStruct;

// Plotter API constants

// PlotStruct.Port =
#define PORTCOM1  0
#define PORTCOM2  1
#define PORTCOM3  2
#define PORTCOM4  3
#define PORTLPT1  4
#define PORTLPT2  5
#define PORTLPT3  6
#define PORTFILE  7 

// PlotStruct.BaudRate =
#define BAUD110   0
#define BAUD300   1
#define BAUD1200  2
#define BAUD2400  3
#define BAUD4800  4
#define BAUD9600  5
#define BAUD19200 6
#define BAUD38400 7
#define BAUD57600 8

// PlotStruct.DataBits =
#define DATABITS7 0
#define DATABITS8 1

// PlotStruct.Parity =
#define PARITYODD   0
#define PARITYEVEN  1
#define PARITYNONE  2

// PlotStruct.StopBits =
#define STOPBITS1   0
#define STOPBITS2   1

// extern "C" void WINAPI VCSetPlotSettings(short* iError, PlotStruct* pSettings);
// pSettings =
typedef struct PlotStructTag {
    short   Port;
    short   BaudRate;
    short   DataBits;
    short   Parity;
    short   StopBits;
    short   NumPens;
    short   NumCarousels;
    short   DPI;
    vbool   UseCarousels;
    vbool   UseLLOrigin;
    vbool   SortColors;
    vbool   Optimize;
    vbool   BufferOutput;
} PlotStruct;

// Tool Bar constants
// extern "C" HWND WINAPI VCGetToolbar(short i);
// i =
#define TBNONE    0 // no toolbar
#define TBTOP     1 // the main speedbar
#define TBLEFT    2 // the tool palette
#define TBRIGHT   3 // not used
#define TBBOTTOM  4 // the status bar

// Font types constants
// extern "C" void  WINAPI VCSetTextFontNameAndType(short* iError, char* sz, BYTE b);
// b = 
#define WINTEXT       0x00  // Windows font
#define VCFTEXT       0x01  // VCF font
#define LIMBOTEXT     0x02  // undetermined font. Added version 5.0.0
#define BASETEXT      (LIMBOTEXT | VCFTEXT) //  base type mask (i.e., 0x03). Added version 5.0.0
#define LOOKUPTEXT    0x04  // lookup font type in font table. Added version 5.0.0

// Added version 4.0.0
// Ortho Advanced type flags
// extern "C" void WINAPI VCSetOrthoAdvancedType(short* iError, short iType);
// iType =
#define ORTHOADV_NONE       0
#define ORTHOADV_STEPANGLE  1
#define ORTHOADV_INCREMENTS 2
#define ORTHOADV_ONEANGLE   3

// Added version 4.0.0
// Running snap type flags
// extern "C" void WINAPI VCSetRunningSnapType(short* iError, DWORD dwFlags, WORD wOperation);
// dwFlags =
#define NOSNAP      0x0000
#define OSNAP_END   0x0001
#define OSNAP_OBJ   0x0002
#define OSNAP_MID   0x0004
#define OSNAP_INT   0x0008
#define OSNAP_PERP  0x0010
#define OSNAP_TAN   0x0020
#define OSNAP_QUAD  0x0040
#define OSNAP_PER   0x0080
#define OSNAP_CEN   0x0100
#define OSNAP_GRID  0x0200
#define OSNAP_ALL   0x03FF // This will be updated if new snaps are added

// Added version 4.0.0
// Running snap types bitwise operators
// extern "C" void WINAPI VCSetRunningSnapType(short* iError, DWORD dwFlags, WORD wOperation);
// wOperation =
#define Op_Assign   1
#define Op_OR       2
#define Op_AND      3
#define Op_Restore  4 // Added version 7.0.0

// Added version 4.0.0
// Font list sorting order flags
// extern "C" void WINAPI VCSetFontListSorting(short* iError, short i);
// i =
#define SORT_ALLFONTS_MIXED     0
#define SORT_VECTORFONT_FIRST   1
#define SORT_TRUETYPEFONT_FIRST 2

// Added version 5.0.0
// status codes on completion of HatchGen
// extern "C" int WINAPI VCGetCurrentHatchStatus(short* iError);
#define GENERATE_NOT_DONE           0
#define GENERATE_NORMAL             1
#define GENERATE_USER_ABORT         2
#define GENERATE_MAX_EXCEEDED       3
#define GENERATE_HATCH_NOT_FOUND    4
#define GENERATE_INVALID_BOUNDARY   5
#define GENERATE_NO_DRAWPATTERN     6

// Added version 5.0.0
// Hatch alignment flags
// extern "C" void WINAPI VCSetHatchAlignment(short* iError, int iAlign);
// iAlign =
#define HATCH_ALIGN_CENTER      0
#define HATCH_ALIGN_ORIGIN      1
#define HATCH_ALIGN_LOWER_LEFT  2
#define HATCH_ALIGN_FIRST_POINT 3

// Added version 5.0.0
// Sound event flags
// extern "C" void WINAPI VCSound(UINT Sound);
// Sound =
#define SND_CRITICAL  0x01000000  // critical error
#define SND_TOOLERROR 0x02000000  // tool error
#define SND_TOOLDONE  0x03000000  // successful tool completion
#define SND_ABORT     0x04000000  // abort
#define SND_ALERT     0x05000000  // user attention is required
#define SND_INPUT     0x06000000  // input error
#define SND_DEBUG     0x07000000  // internal debug sound
#define SND_STARTUP   0x08000000  // start up sound
#define SOUND_COUNT 8 //  updated as needed

// Added version 5.0.0
// EraseEx action flags 
// extern "C" vbool WINAPI VCSetCurrentErasedEx(short* iError, short iErase, short iUserSessionID, DWORD bfFlags);
// iErase =
#define EREX_UNERASE      0
#define EREX_ERASE        1
#define EREX_ERASE_NOREDO 2
#define EREX_PURGE        3

// Added version 5.0.0
// OperationEx and EraseEx behaviour flags
// extern "C" vbool WINAPI VCSetCurrentErasedEx(short* iError, short iErase, short iUserSessionID, DWORD bfFlags);
// extern "C" short WINAPI VCEndOperationEx(short* iError, short iUserSessionID, DWORD bfFlags);
// bfFlags = 
#define OPEX_DEFAULT      0x00000000
#define OPEX_NOTRUNC      0x00000001
#define OPEX_NOPURGE      0x00000002
#define OPEX_NODESELECT   0x00000004
#define OPEX_NODRAW       0x00000008

//--------------------------------------------------------------------------------------------
// The following are not used directly in the API but can be useful in Visual CADD programming
//--------------------------------------------------------------------------------------------

// Visual CADD Fonts

// TrueType font ASCII Character Code values for dimension symbols
#define TT_DIAMETER_SYMBOL    216
#define TT_PLUSMINUS_SYMBOL   177
#define TT_DEGREE_SYMBOL      176

// VCF font ASCII Character Code values for dimension symbols
#define VCF_DIAMETER_SYMBOL   157
#define VCF_PLUSMINUS_SYMBOL  241
#define VCF_DEGREE_SYMBOL     248

// Used in VCFCharRecord
typedef struct fPoint2D {
    float x;
    float y;
} fPoint2D;

// VCF font record
typedef struct VCFCharRecord {
    unsigned char ch;
    short bFillable;
    fPoint2D fpMin;
    fPoint2D fpMax;
} VCFCharRecord;

// VCF font header
typedef struct VCFHeader {
    BYTE bVersion;
    char szFont[33];
    short nChars;
} VCFHeader;

//PDF export settings

typedef struct VCPDFExportSettings
{
    short iSize;            //size of this structure (v5 = 1270, v6 = 1278)
    double dHeight;         //output "paper" height, in inches
    double dWidth;          //output "paper" width, in inches
    Point2D dpMarginUR;     //top and right margins, in inches
    Point2D dpMarginLL;     //bottom and left margins, in inches

    vbool tfUseCompression; //use PDF compression
    vbool tfSelectionOnly;  //only include selected entities in output
    vbool tfLW0HasWidth;    //treat LW0 as LW1
    vbool tfCenterAlways;   //always center output on page
    vbool tfLandscape;      //use landscape mode
    vbool tfShowWatermark;  //display watermark

    short iOutputColor;     //0 for include color, non-zero for all colors black
    short iFontEmbed;       //0 for don't embed, 1 for embed

    short iPermissions;     //desired permissions
    vbool tfUseEncryption;  //encrypt PDF output
    char szUserPwd[36];     //NOTE: passwords are 32 chars + NULL, padded to 36 to maintain structure packing
    char szOwnerPwd[36];
    char szWatermark[64];   //watermark string

    char szTitle[256];      //title string in document properties
    char szSubject[256];    //subject string in document properties
    char szAuthor[256];     //author string in document properties
    char szKeywords[256];   //keyword string in document properties

    double dBaseLineWidth;  //width of a LW1 line

    Point2D dpOrigin;       //location on output of the LL corner of the extents of the output entities
    short iView;            // 1=fit  2=current View  3=Scale
    double dScale;          //output inches/drawing inch
    vbool tfOpenReader;     //open PDF reader when output complete
    int iImageResolution;   //OLE bitmap resolution in DPI
    //v6.0 and later
    int iLayerMode;         //Layer export mode (0 = none, 1 = visible, 2 = printable)
    int iWatermarkGray;     //Watermark gray density (0-100%)  

}VCPDFExportSettings;

// Visual CADD cursor names
// These can be used to load Visual CADD cursors for use in your application.
// Example: hLikeCur = LoadCursor(VCGetVCResourceInstance(), CUR_LIKECURSOR);
#define CUR_LIKECURSOR  "LIKECURSOR"
#define CUR_POINTER     "POINTER"
#define CUR_NOCURSOR    "NOCURSOR"
#define CUR_MOVECURSOR  "MOVECURSOR"
#define CUR_SNAPEND     "SNAPEND"
#define CUR_SNAPCENTER  "SNAPCENTER"
#define CUR_SNAPINT     "SNAPINT"
#define CUR_SNAPOBJ     "SNAPOBJ"
#define CUR_SNAPMID     "SNAPMID"
#define CUR_SNAPPERCENT "SNAPPERCENT"
#define CUR_SNAPPERP    "SNAPPERP"
#define CUR_SNAPQUAD    "SNAPQUAD"
#define CUR_SNAPGRID    "SNAPGRID"
#define CUR_SNAPTAN     "SNAPTAN"
#define CUR_DRAGDOC     "DRAGDOC"
#define CUR_DRAGDATA    "DRAGDATA"
#define CUR_SIZEWE      "SIZEWE"
#define CUR_TOLAYER     "TOLAYER"

// Visual CADD limits

// The following string lengths are the sizes of the maximum string
// sizes and do not include space for the terminal NULL. Buffer to
// receive these values need to be sized accordingly.
// Example: szBuffer[MAX_MACRO + 1]
#define MAX_VC_OBJ_NAME         32
#define MAX_VC_SYM_NAME         MAX_VC_OBJ_NAME
#define MAX_VC_ATB_NAME         MAX_VC_OBJ_NAME
#define MAX_VC_HATCH_NAME       MAX_VC_OBJ_NAME
#define MAX_VC_LAY_NAME         MAX_VC_OBJ_NAME
#define MAX_VC_LAY_GRP_NAME     MAX_VC_LAY_NAME
#define MAX_VC_COLOR_NAME       MAX_VC_OBJ_NAME
#define MAX_VC_LTYPE_NAME       MAX_VC_OBJ_NAME
#define MAX_VC_VIEW_NAME        MAX_VC_OBJ_NAME

#define MAX_NATIVE_NAME         12
#define MAX_SHORTCUT            3
#define MAX_DESCRIPTION         128
#define MAX_MACRO               32000 // Changed from 255 in version 4.0.0

#define MAX_VC_RWLWIDTH_STRING  25
#define MAX_VC_DIM_STRING       347

// Visual CADD Layers
#define MAX_VCADD_LAYERS        1024
#define MAX_VCADD_LAYERS_INDEX  (MAX_VCADD_LAYERS - 1)
#define MIN_VCADD_LAYERS_INDEX  0

// Visual CADD Colors
#define MAX_VCADD_COLORS        256
#define MAX_VCADD_COLOR_INDEX   (MAX_VCADD_COLORS - 1)
#define MIN_VCADD_COLOR_INDEX   0
#define MAX_SYSTEM_COLOR_INDEX  15 // Cursor and other system setting with a limited color pallet

// Visual CADD LineTypes
#define MAX_VCADD_LTYPES        256
#define MAX_VCADD_LTYPES_INDEX  (MAX_VCADD_LTYPES - 1)
#define MIN_VCADD_LTYPES_INDEX  0

// Visual CADD LineWidths
#define MAX_VCADD_LWIDTHS       16
#define MAX_VCADD_LWIDTHS_INDEX (MAX_VCADD_LWIDTHS - 1)
#define MIN_VCADD_LWIDTHS_INDEX 0

//maximum number of points in a continuous entity (CONTINUOUSLINE2D, CONTINUOUSBEZIER2D, MINTERPCURV2D, MULTILINE2D)
#define MAX_CONTINUOUS_POINTS 3748

#define MAX_VC_ATB_FIELD        128
#define MAX_VC_ATB_FIELDNAME    79

// Mathematical constants

// PI defines
#define PI 3.14159265358979323846
#define TWOPI (2.0 * PI)
#define HALFPI 1.57079632679489661923

#define MYRADIAN (180.0 / PI)

// Radian degrees
#define DegreeToRadian(d) (d / 180.0 * PI)
#define RadianToDegree(r) (r / PI * 180.0)

// Standard angles
#define A15  (15.0 / MYRADIAN)
#define A30  (30.0 / MYRADIAN)
#define A45  (45.0 / MYRADIAN)
#define A90  (HALFPI)
#define A135 (135.0 / MYRADIAN)
#define A150 (150.0 / MYRADIAN)
#define A210 (210.0 / MYRADIAN)
#define A270 (3.0 * HALFPI)
#define A315 (315.0 / MYRADIAN)
#define A330 (330.0 / MYRADIAN)

// Unit conversion definitions
#define MM_PER_INCH           25.4
#define INCHES_PER_INCH       1.0
#define INCHES_PER_FOOT       12.0
#define INCHES_PER_MILE       63360.0

#define INCHES_PER_MM         (1.0 / MM_PER_INCH)
#define INCHES_PER_CM         (10.0 / MM_PER_INCH)
#define INCHES_PER_METER      (1000.0 / MM_PER_INCH)
#define INCHES_PER_KILOMETER  (1000000.0 / MM_PER_INCH)

#define FEET_PER_INCH         (INCHES_PER_INCH / INCHES_PER_FOOT)
#define MILES_PER_INCH        (INCHES_PER_INCH / INCHES_PER_MILE)
#define CM_PER_INCH           (MM_PER_INCH / 10.0)
#define METERS_PER_INCH       (MM_PER_INCH / 1000.0)
#define KILOMETERS_PER_INCH   (MM_PER_INCH / 1000000.0)

//Added version 6.0.0
//File Locking
#define MAX_VC_LOC_USERNAME       274 //MAX_COMPUTERNAME_LENGTH + UNLEN + 3

#define VCLF_SAVING     0x01
#define VCLF_SILENT     0x02
#define VCLF_LOCKALWAYS 0x04
#define VCLF_NOLOCK     0x08
#define VCLF_READWRITE  0x10

typedef struct VCImageExportSettings
{
    short iSize;         //size of this structure
    short iImageType;    //type of image exported
    short iImageMode;    //export mode for image type
    short iCompression;  //compression level

    int iWidth;          //image width in pixels
    int iHeight;         //image height in pixels

    int iResolution;     //image resolution
    iPoint2D dpOrigin;   //location on output of the LL corner of the extents of the output entities
    short iView;         // 1=fit  2=current View  3=Scale

    double dScale;       //scale in pixels/drawing inch

    //v8.0.0 and later
    vbool tfOpenImage;   //open image on save

    //v8.0.2 and later
    vbool tfSelectionOnly;   //only include selected entities in image
    vbool tfSaveToClipboard; //save image directly to the Windows clipboard

}VCImageExportSettings;

#define IEX_BMP            0
#define IEX_JPG            1
#define IEX_TIF            2
#define IEX_PNG            3
#define IEX_EMF            4
#define IEX_WMF            5
#define IEX_GIF            6

#define IEX_BMP_MODE_BW    0  //Black on white
#define IEX_BMP_MODE_WB    1  //White on black
#define IEX_BMP_MODE_8     2  //256 Colors (8 bit)
#define IEX_BMP_MODE_16    3  //65k Colors (16 bit)
#define IEX_BMP_MODE_24    4  //16.7M Colors (24 bit)

#define IEX_JPG_MODE_8     0  //8 bit grayscale
#define IEX_JPG_MODE_RGB   1  //24 bit RGB
#define IEX_JPG_MODE_CYMK  2  //32 bit CMYK

#define IEX_TIF_MODE_BW    0  //Black on white
#define IEX_TIF_MODE_WB    1  //White on black
#define IEX_TIF_MODE_8     2  //256 Colors (8 bit)
#define IEX_TIF_MODE_24    3  //16.7M Colors (24 bit RGB)
#define IEX_TIF_MODE_32    4  //16.7M Colors (32 bit RGBA)

#define IEX_PNG_MODE_BW    0  //Black on white
#define IEX_PNG_MODE_WB    1  //White on black
#define IEX_PNG_MODE_GRAY  2  //Grayscale (8 bit)
#define IEX_PNG_MODE_MAP   3  //256 Colors (8 bit)
#define IEX_PNG_MODE_RGB   4  //16.7M Colors(24 bit RGB)
#define IEX_PNG_MODE_RGBA  5  //16.7M (32 bit RGBA)

#define IEX_EMF_MODE_NONE  0  //No background
#define IEX_EMF_MODE_BACK  1  //Include Background

#define IEX_GIF_MODE_8     0  //8 Bit with palette

#define IEX_BMP_COMP_0     0  //None
#define IEX_BMP_COMP_1     1  //RLE

#define IEX_JPG_COMP_0     0  //Low
#define IEX_JPG_COMP_1     1  //Medium
#define IEX_JPG_COMP_2     2  //High

#define IEX_TIF_COMP_0     0  //None
#define IEX_TIF_COMP_1     1  //CCITT
#define IEX_TIF_COMP_2     2  //JPEG
#define IEX_TIF_COMP_3     3  //PackBits
#define IEX_TIF_COMP_4     4  //Deflate

typedef struct VCXMLSettings
{
    UINT uSize;                //size of this structure
    vbool tfEntities;          //include entities in export
    vbool tfPoints;            //include entity points in export
    vbool tfProperties;        //include entity properties in export
    vbool tfSettings;          //include entity settings in export
    vbool tfUserData;          //include entity user data in export
    vbool tfSymbolDefs;        //include symbol definitions in export
    vbool tfHatchDefs;         //include hatch definitions in export
    vbool tfLineDefs;          //include line type definitions in export
    vbool tfUseXSLOut1;        //use the first transform file for export
    vbool tfUseXSLOut2;        //use the second transform file for export
    vbool tfUseXSLIn1;         //use the first transform file for import
    vbool tfUseXSLIn2;         //use the second transform file for import
    char szXSLOut1[260];       //file path for the first export transform file
    char szXSLOut2[260];       //file path for the second export transform file
    char szXSLIn1[260];        //file path for the first import transform file
    char szXSLIn2[260];        //file path for the second import transform file
    vbool tfUseXSLInXML;       //use a transform specified in the imported XML file
    vbool tfKeepTempFiles;     //keep temporary files created for transforms during export and import
    vbool tfPaletteDefs;       //include color palette definitions in export
    vbool tfHdrUserData;       //include header user data in export
    vbool tfHdrExtData;        //include header extended data in export
    vbool tfExtData;           //include entity extended data in export
    vbool tfTraits;            //include entity traits in export
}VCXMLSettings;

//Configuration file translation type constants
#define	CFT_SCRIPT      1 //Script.def
#define	CFT_CMDEXT      2 //Cmdext.def
#define	CFT_MENU	    3 //Menu (.mnu) files
#define	CFT_HATCH	    4 //Hatches.hat
#define	CFT_MULTILINE   5 //Multiline styles
#define	CFT_PRESETS     6 //Print presets
#define	CFT_PDF         7 //PDF presets
#define	CFT_PLOT        8 //Plot settings
#define	CFT_LINETYPE    9 //Linetype.lnt
#define	CFT_VGAPAL     10 //VGA.pal
#define	CFT_TOOLBAR    11 //Toolbars (.mbr, .tbr)
#define	CFT_MOUSEMNU   12 //MouseMenu.def
#define	CFT_POPUP      13 //Popup (.pop) files

//Added version 7.0.2
//  user data constants
#define USER_UNKNOWN    0
#define USER_BYTE       1
#define USER_SHORT      2
#define USER_LONG       3
#define USER_DOUBLE     4
#define USER_FLOAT      5
#define USER_CHUNK      6
#define USER_STRING     7
#define USER_NUMERIC    8 //Added 8.0.0
#define USER_TEXT       9 //Added 8.0.0

#define USER_NAME_SIZE 16
#define USER_MAX_CHUNK_SIZE 1024
#define USER_MAX_STRING_SIZE 255

//Added version 7.0.3
// Floating edit dialog constants
#define FLTDLG_NEVER    0
#define FLTDLG_CREATE   1
#define FLTDLG_EDIT     2
#define FLTDLG_ALWAYS   3

//Added version 8.0.0
//Status bar user pane constants and data structure
#define SBUP_MASK_TEXT  0x01
#define SBUP_MASK_COLOR 0x02
#define SBUP_MASK_BACK  0x04

#define SBUP_ACTION_UPDATE  0
#define SBUP_ACTION_LBUTTON 1
#define SBUP_ACTION_RBUTTON 2

struct UserPaneData
{
    int iPane;
    int iAction;
    UINT uMask;
    char szText[40];
    UINT crText;
    UINT crBack;
    HWND hWnd;
    RECT rPane;
    UINT uData;
};

//Added version 9.0.0
// User tool flags
// extern "C" void WINAPI VCSetUserToolFlags(short* iError, DWORD dw)
// dw =
#define USERTOOL_IS_NESTED              0x00000001
#define USERTOOL_IS_SNAP                0x00000002
#define USERTOOL_USES_RUNNING_SNAPS     0x00000004
#define USERTOOL_PASSTRHU_MOUSEMOVE     0x00000008
#define USERTOOL_PASSTRHU_RUBBERSTATE   0x00000010

#define STATUSCOLOR_NORMAL              0
#define STATUSCOLOR_WARNING             1
#define STATUSCOLOR_LOCKED              2

#if defined _MSC_VER
#pragma pack(pop)
#endif

#endif //VCTYPE32_H_INCLUDED
