/*SDOC*************************************************************

  Module:   VCUtil32.cpp

  Copyright (C) 2022 Gold Run Partners, Inc.  All rights reserved.

  Description: Generic Wrapper Functions

        Function name: 'type'Function means returns a 'type'

        Parameters:
            HMODULE hMod - DLL module handle with function
            const char* szFunction - function name
            remainder of parameters - overloaded for possible combinations

    See VCUtil32.h for Revision Record:

*************************************************************EDOC*/
#include "stdafx.h"

#include "VCType32.h"
#include "VCUtil32.h"

#ifdef VCLINK_STATIC
#else
#endif

BYTE WINAPI BYTEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef BYTE(CALLBACK* GenericProc) (short*);
    BYTE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

BYTE WINAPI BYTEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, BYTE v3)
{
    typedef BYTE(CALLBACK* GenericProc) (short*, char*, BYTE);
    BYTE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

BYTE WINAPI BYTEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef BYTE(CALLBACK* GenericProc) (short*, short);
    BYTE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

BYTE WINAPI BYTEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, char* v4)
{
    typedef BYTE(CALLBACK* GenericProc) (short*, short, short, char*);
    BYTE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

COLORREF WINAPI ColorFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, int v2)
{
    typedef COLORREF(CALLBACK* GenericProc) (short*, int);
    COLORREF vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

COLORREF WINAPI ColorFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef COLORREF(CALLBACK* GenericProc) (short*, short);
    COLORREF vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

COLORREF WINAPI ColorFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, COLORREF v3)
{
    typedef COLORREF(CALLBACK* GenericProc) (short*, short, COLORREF);
    COLORREF vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

COLORREF WINAPI ColorFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, UINT v3)
{
    typedef COLORREF(CALLBACK* GenericProc) (short*, UINT, UINT);
    COLORREF vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef double (CALLBACK* GenericProc) (short*);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2)
{
    typedef double (CALLBACK* GenericProc) (short*, char*);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef double (CALLBACK* GenericProc) (short*, short);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short v3, short v4)
{
    typedef double (CALLBACK* GenericProc) (short*, char*, short, short);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3)
{
    typedef double (CALLBACK* GenericProc) (short*, short, char*);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D v2, Point2D* v3)
{
    typedef double (CALLBACK* GenericProc) (short*, Point2D, Point2D*);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

double WINAPI doubleFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, Point2D* v3)
{
    typedef double (CALLBACK* GenericProc) (short*, Point2D*, Point2D*);
    double vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

float WINAPI floatFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef float (CALLBACK* GenericProc) (short*);
    float vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

float WINAPI floatFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef float (CALLBACK* GenericProc) (short*, short);
    float vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

HANDLE WINAPI HANDLEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, char* v2, DWORD v3)
{
    typedef HANDLE(CALLBACK* GenericProc) (long, char*, DWORD);
    HANDLE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

HINSTANCE WINAPI HINSTANCEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef HINSTANCE(CALLBACK* GenericProc) ();
    HINSTANCE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

HINSTANCE WINAPI HINSTANCEFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1)
{
    typedef HINSTANCE(CALLBACK* GenericProc) (char*);
    HINSTANCE vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

HMENU WINAPI HMENUFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef HMENU(CALLBACK* GenericProc) ();
    HMENU vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

HMENU WINAPI HMENUFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1)
{
    typedef HMENU(CALLBACK* GenericProc) (char*);
    HMENU vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

HMENU WINAPI HMENUFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HMENU v2)
{
    typedef HMENU(CALLBACK* GenericProc) (short*, HMENU);
    HMENU vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

HWND WINAPI HWNDFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef HWND(CALLBACK* GenericProc) ();
    HWND vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

HWND WINAPI HWNDFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1)
{
    typedef HWND(CALLBACK* GenericProc) (short);
    HWND vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

HWND WINAPI HWNDFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WORD v1)
{
    typedef HWND(CALLBACK* GenericProc) (WORD);
    HWND vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef int (CALLBACK* GenericProc) ();
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1)
{
    typedef int (CALLBACK* GenericProc) (char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2, char* v3)
{
    typedef int (CALLBACK* GenericProc) (char*, char*, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2, char* v3, char* v4)
{
    typedef int (CALLBACK* GenericProc) (char*, char*, char*, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2, char* v3, int v4)
{
    typedef int (CALLBACK* GenericProc) (char*, char*, char*, int);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HWND v1, UINT v2, long v3, long v4)
{
    typedef int (CALLBACK* GenericProc) (HWND, UINT, long, long);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HWND v1, UINT v2, short v3, long v4, long v5)
{
    typedef int (CALLBACK* GenericProc) (HWND, UINT, short, long, long);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HWND v1, UINT v2, UINT v3, UINT v4)
{
    typedef int (CALLBACK* GenericProc) (HWND, UINT, UINT, UINT);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1)
{
    typedef int (CALLBACK* GenericProc) (long);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, MSG* v1)
{
    typedef int (CALLBACK* GenericProc) (MSG*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, POINT* v1)
{
    typedef int (CALLBACK* GenericProc) (POINT*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef int (CALLBACK* GenericProc) (short*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2)
{
    typedef int (CALLBACK* GenericProc) (short*, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, BYTE* v3)
{
    typedef int (CALLBACK* GenericProc) (short*, char*, BYTE*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3)
{
    typedef int (CALLBACK* GenericProc) (short*, char*, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, int v4)
{
    typedef int (CALLBACK* GenericProc) (short*, char*, char*, int);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, DWORD v3)
{
    typedef int (CALLBACK* GenericProc) (short*, char*, DWORD);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HWND v2)
{
    typedef int (CALLBACK* GenericProc) (short*, HWND);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, int v2, long v3, long v4)
{
    typedef int (CALLBACK* GenericProc) (short*, int, long, long);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2)
{
    typedef int (CALLBACK* GenericProc) (short*, long);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3)
{
    typedef int (CALLBACK* GenericProc) (short*, long, long);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2)
{
    typedef int (CALLBACK* GenericProc) (short*, Point2D*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef int (CALLBACK* GenericProc) (short*, short);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3)
{
    typedef int (CALLBACK* GenericProc) (short*, short, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3, char* v4)
{
    typedef int (CALLBACK* GenericProc) (short*, short, char*, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, int* v2, int* v3, short v4)
{
    typedef int (CALLBACK* GenericProc) (short*, int*, int*, short);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long* v2, int* v3, short v4)
{
    typedef int (CALLBACK* GenericProc) (short*, long*, int*, short);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, Point2D* v3, Point2D* v4)
{
    typedef int (CALLBACK* GenericProc) (short*, UINT, Point2D*, Point2D*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, WCHAR* v2, WCHAR* v3, int v4)
{
    typedef int (CALLBACK* GenericProc) (short*, WCHAR*, WCHAR*, int);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, WORD* v2, int v3)
{
    typedef int (CALLBACK* GenericProc) (short*, WORD*, int);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, WORD* v2, int v3, short v4)
{
    typedef int (CALLBACK* GenericProc) (short*, WORD*, int, short);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, UINT v1, WPARAM v2, LPARAM v3)
{
    typedef int (CALLBACK* GenericProc) (UINT, WPARAM, LPARAM);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, UINT v1, WPARAM v2, char* v3)
{
    typedef int (CALLBACK* GenericProc) (UINT, WPARAM, char*);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

int WINAPI intFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WPARAM v1, LPARAM v2)
{
    typedef int (CALLBACK* GenericProc) (WPARAM, LPARAM);
    int vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

LPDISPATCH WINAPI LPDISPATCHFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef LPDISPATCH(CALLBACK* GenericProc) ();
    LPDISPATCH vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

LPDISPATCH WINAPI LPDISPATCHFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2)
{
    typedef LPDISPATCH(CALLBACK* GenericProc) (short*, char*);
    LPDISPATCH vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

Point2D WINAPI Point2DFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1)
{
    typedef Point2D(CALLBACK* GenericProc) (long);
    Point2D vReturn;    vReturn.x = vReturn.y = 0.0;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

Point2D WINAPI Point2DFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef Point2D(CALLBACK* GenericProc) (short*);
    Point2D vReturn;    vReturn.x = vReturn.y = 0.0;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

Point2D WINAPI Point2DFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double v2)
{
    typedef Point2D(CALLBACK* GenericProc) (short*, double);
    Point2D vReturn;    vReturn.x = vReturn.y = 0.0;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

Point2D WINAPI Point2DFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef Point2D(CALLBACK* GenericProc) (short*, short);
    Point2D vReturn;    vReturn.x = vReturn.y = 0.0;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef short (CALLBACK* GenericProc) ();
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1)
{
    typedef short (CALLBACK* GenericProc) (char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short* v2)
{
    typedef short (CALLBACK* GenericProc) (char*, short*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2)
{
    typedef short (CALLBACK* GenericProc) (char*, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2, char* v3)
{
    typedef short (CALLBACK* GenericProc) (char*, char*, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short v2)
{
    typedef short (CALLBACK* GenericProc) (char*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short v2, short v3)
{
    typedef short (CALLBACK* GenericProc) (char*, short, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short* v2, short v3)
{
    typedef short (CALLBACK* GenericProc) (char*, short*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, char* v2, short* v3)
{
    typedef short (CALLBACK* GenericProc) (long, char*, short*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, void* v2, char* v3)
{
    typedef short (CALLBACK* GenericProc) (long, void*, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long* v1, short v2)
{
    typedef short (CALLBACK* GenericProc) (long*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1)
{
    typedef short (CALLBACK* GenericProc) (short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1, char* v2)
{
    typedef short (CALLBACK* GenericProc) (short, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1, short v2)
{
    typedef short (CALLBACK* GenericProc) (short, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef short (CALLBACK* GenericProc) (short*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, BYTE* v2)
{
    typedef short (CALLBACK* GenericProc) (short*, BYTE*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2)
{
    typedef short (CALLBACK* GenericProc) (short*, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, BYTE v3)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, BYTE);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, BYTE v3, char* v4)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, BYTE, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, BYTE* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, BYTE*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, short v4)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, char*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, double* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, double*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short v3)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short* v3, DWORD v4)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, short*, DWORD);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short v3, short v4, double* v5)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, short, short, double*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short v3, short v4, short v5)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, short, short, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, WORD v3)
{
    typedef short (CALLBACK* GenericProc) (short*, char*, WORD);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3)
{
    typedef short (CALLBACK* GenericProc) (short*, long, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3, short v4)
{
    typedef short (CALLBACK* GenericProc) (short*, long, short, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HMENU* v2)
{
    typedef short (CALLBACK* GenericProc) (short*, HMENU*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2)
{
    typedef short (CALLBACK* GenericProc) (short*, long);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, long, short*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long* v2)
{
    typedef short (CALLBACK* GenericProc) (short*, long*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, LPDISPATCH v2, char* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, LPDISPATCH, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef short (CALLBACK* GenericProc) (short*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, DWORD v2)
{
    typedef short (CALLBACK* GenericProc) (short*, DWORD);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, DWORD v3)
{
    typedef short (CALLBACK* GenericProc) (short*, short, DWORD);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, short, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3)
{
    typedef short (CALLBACK* GenericProc) (short*, short, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, DWORD v4)
{
    typedef short (CALLBACK* GenericProc) (short*, short, short, DWORD);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, char* v4)
{
    typedef short (CALLBACK* GenericProc) (short*, short, short, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, char* v4, short v5)
{
    typedef short (CALLBACK* GenericProc) (short*, short, short, char*, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, short v4, short v5, float v6)
{
    typedef short (CALLBACK* GenericProc) (short*, short, short, short, short, float);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short* v3, short* v4, short* v5, float* v6)
{
    typedef short (CALLBACK* GenericProc) (short*, short, short*, short*, short*, float*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short* v2)
{
    typedef short (CALLBACK* GenericProc) (short*, short*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3)
{
    typedef short (CALLBACK* GenericProc) (short*, long, long);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WORD v1)
{
    typedef short (CALLBACK* GenericProc) (WORD);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WORD v1, short v2, char* v3)
{
    typedef short (CALLBACK* GenericProc) (WORD, short, char*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WORD v1, short v2)
{
    typedef short (CALLBACK* GenericProc) (WORD, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, UINT v1, WPARAM v2, LPARAM v3)
{
    typedef short (CALLBACK* GenericProc) (UINT, WPARAM, LPARAM);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1)
{
    typedef short (CALLBACK* GenericProc) (long);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, EAttr* v3)
{
    typedef short (CALLBACK* GenericProc) (short*, short, EAttr*);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

short WINAPI shortFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, WORD v2, short v3)
{
    typedef short (CALLBACK* GenericProc) (short*, WORD, short);
    short vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef UINT(CALLBACK* GenericProc) ();
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, UINT v2)
{
    typedef UINT(CALLBACK* GenericProc) (char*, UINT);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, UINT v2, char* v3)
{
    typedef UINT(CALLBACK* GenericProc) (char*, UINT, char*);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, UINT v2, char* v3, char* v4)
{
    typedef UINT(CALLBACK* GenericProc) (char*, UINT, char*, char*);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, UINT v2, char* v3, char* v4, char* v5)
{
    typedef UINT(CALLBACK* GenericProc) (char*, UINT, char*, char*, char*);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}
UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef UINT(CALLBACK* GenericProc) (short*);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3)
{
    typedef UINT(CALLBACK* GenericProc) (short*, char*, char*);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3, long v4)
{
    typedef UINT(CALLBACK* GenericProc) (short*, long, long, long);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3, BYTE* v4, long v5)
{
    typedef UINT(CALLBACK* GenericProc) (short*, long, long, BYTE*, long);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}

UINT WINAPI UINTFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3, BYTE* v4, UINT v5)
{
    typedef UINT(CALLBACK* GenericProc) (short*, long, long, BYTE*, UINT);
    UINT vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return vReturn;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef void (CALLBACK* GenericProc) ();

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)();
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1)
{
    typedef void (CALLBACK* GenericProc) (char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2)
{
    typedef void (CALLBACK* GenericProc) (char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, char* v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (char*, char*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, Point2D* v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (char*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short v2)
{
    typedef void (CALLBACK* GenericProc) (char*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (char*, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, char* v1, short* v2)
{
    typedef void (CALLBACK* GenericProc) (char*, short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, EAttr* v1)
{
    typedef void (CALLBACK* GenericProc) (EAttr*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HMENU v1)
{
    typedef void (CALLBACK* GenericProc) (HMENU);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HWND v1)
{
    typedef void (CALLBACK* GenericProc) (HWND);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HWND v1, int v2, int v3)
{
    typedef void (CALLBACK* GenericProc) (HWND, int, int);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, HWND v1, UINT v2, int v3, int v4)
{
    typedef void (CALLBACK* GenericProc) (HWND, UINT, int, int);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1)
{
    typedef void (CALLBACK* GenericProc) (long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, char v2)
{
    typedef void (CALLBACK* GenericProc) (long, char);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, Point2D* v2)
{
    typedef void (CALLBACK* GenericProc) (long, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, RECT v2)
{
    typedef void (CALLBACK* GenericProc) (long, RECT);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, RECT* v2)
{
    typedef void (CALLBACK* GenericProc) (long, RECT*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, long v1, WORD v2)
{
    typedef void (CALLBACK* GenericProc) (long, WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, LPDISPATCH v1)
{
    typedef void (CALLBACK* GenericProc) (LPDISPATCH);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, lPoint2D v1, short v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (lPoint2D, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, lPoint2D* v1, short v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (lPoint2D*, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, Point2D v1)
{
    typedef void (CALLBACK* GenericProc) (Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, Point2D* v1)
{
    typedef void (CALLBACK* GenericProc) (Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, Point2D* v1, Point2D* v2)
{
    typedef void (CALLBACK* GenericProc) (Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, Point2D* v1, Point2D* v2, Point2D* v3, Point2D* v4, Point2D* v5)
{
    typedef void (CALLBACK* GenericProc) (Point2D*, Point2D*, Point2D*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1)
{
    typedef void (CALLBACK* GenericProc) (short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1, char* v2, char* v3)
{
    typedef void (CALLBACK* GenericProc) (short, char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1, char* v2, char* v3, DWORD v4)
{
    typedef void (CALLBACK* GenericProc) (short, char*, char*, DWORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short v1, short v2)
{
    typedef void (CALLBACK* GenericProc) (short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef void (CALLBACK* GenericProc) (short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, BOOL v2)
{
    typedef void (CALLBACK* GenericProc) (short*, BOOL);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, BYTE v2)
{
    typedef void (CALLBACK* GenericProc) (short*, BYTE);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, BYTE v3, char* v4, BYTE v5)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, BYTE, char*, BYTE);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, char* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, char* v4, char* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, char*, char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, char* v4, short v5)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, char*, char*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, long v4)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, char*, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, char* v3, long v4, long v5)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, char*, long, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, double v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, double v3, double v4)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, double, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, int v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, int);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, LPDISPATCH v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, LPDISPATCH);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, Point2D v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, char* v2, short v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, char*, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double v2)
{
    typedef void (CALLBACK* GenericProc) (short*, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double v2, double v3)
{
    typedef void (CALLBACK* GenericProc) (short*, double, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double v2, double* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, double, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, double, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double v2, Point2D* v3, double* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, double, Point2D*, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double* v2, char* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, double*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double* v2, double* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, double*, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double* v2, double* v3, double* v4, double* v5, double* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, double*, double*, double*, double*, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, double* v2, Point2D* v3, Point2D* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, double*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, DWORD v2, DWORD v3)
{
    typedef void (CALLBACK* GenericProc) (short*, DWORD, DWORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, DWORD* v2, DWORD* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, DWORD*, DWORD*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3, Point2D* v4, Point2D* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, long, long, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, Point2D* v3, Point2D* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, long, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, Point2D* v3, Point2D* v4, double v5)
{
    typedef void (CALLBACK* GenericProc) (short*, long, Point2D*, Point2D*, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, long, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3, short v4, short v5)
{
    typedef void (CALLBACK* GenericProc) (short*, long, short, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3, short v4, short v5, Point2D* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, long, short, short, short, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3)
{
    typedef void (CALLBACK* GenericProc) (short*, long, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, long*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, float v2)
{
    typedef void (CALLBACK* GenericProc) (short*, float);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, float* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, float*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HCURSOR v2)
{
    typedef void (CALLBACK* GenericProc) (short*, HCURSOR);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HMENU v2)
{
    typedef void (CALLBACK* GenericProc) (short*, HMENU);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HWND v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (short*, HWND, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, HWND v2, WORD v3)
{
    typedef void (CALLBACK* GenericProc) (short*, HWND, WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, iPoint2D v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, iPoint2D, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, iPoint2D* v2, iPoint2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, iPoint2D*, iPoint2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, iPoint2D* v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, iPoint2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2)
{
    typedef void (CALLBACK* GenericProc) (short*, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3, long v4)
{
    typedef void (CALLBACK* GenericProc) (short*, long, long, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long v3, long v4, long v5, long v6)
{
    typedef void (CALLBACK* GenericProc) (short*, long, long, long, long, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, long* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, long, long*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (short*, long, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, short v3, Point2D* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, long, short, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, Point2D* v3, double v4, long v5)
{
    typedef void (CALLBACK* GenericProc) (short*, long, Point2D*, double, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, Point2D* v3, Point2D* v4, long v5)
{
    typedef void (CALLBACK* GenericProc) (short*, long, Point2D*, Point2D*, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, long v2, Point2D* v3, long v4)
{
    typedef void (CALLBACK* GenericProc) (short*, long, Point2D*, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, LPDISPATCH v2, char* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, LPDISPATCH, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, LPDISPATCH v2, char* v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, LPDISPATCH, char*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, PlotStruct* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, PlotStruct*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D v2)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, double* v3, double* v4, double* v5, double* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, double*, double*, double*, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, long v3, Point2D* v4, Point2D* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, long, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, Point2D* v3, Point2D* v4, double v5, double v6)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, Point2D*, Point2D*, double, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, Point2D* v3, Point2D* v4, Point2D* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, Point2D*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, short v3, Point2D* v4, short* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, short, Point2D*, short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point2D* v2, short* v3, short v4, double v5)
{
    typedef void (CALLBACK* GenericProc) (short*, Point2D*, short*, short, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point3D* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, Point3D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point3D* v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, Point3D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, Point3D* v2, Point3D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, Point3D*, Point3D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, PrintStruct* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, PrintStruct*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef void (CALLBACK* GenericProc) (short*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, BYTE v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, BYTE);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3, char* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3, char* v4, char* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, short, char*, char*, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3, short* v4, short* v5, double* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, char*, short*, short*, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, double v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, double* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, double*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, EAttr* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, EAttr*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, float v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, float);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, long v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, long v3, long v4, long v5, long v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, long, long, long, long);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D v3, Point2D v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D v3, Point2D v4, Point2D v5)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D, Point2D, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D v3, Point2D v4, Point2D v5, Point2D v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D, Point2D, Point2D, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D v3, Point2D v4, Point2D v5, Point2D v6, Point2D v7, Point2D v8, Point2D v9)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D, Point2D, Point2D, Point2D, Point2D, Point2D, Point2D);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6, v7, v8, v9);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3, Point2D* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3, Point2D* v4, Point2D* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3, Point2D* v4, Point2D* v5, Point2D* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*, Point2D*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3, Point2D* v4, Point2D* v5, Point2D* v6, Point2D* v7)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*, Point2D*, Point2D*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6, v7);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3, Point2D* v4, Point2D* v5, Point2D* v6, Point2D* v7, Point2D* v8, Point2D* v9)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*, Point2D*, Point2D*, Point2D*, Point2D*, Point2D*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6, v7, v8, v9);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point2D* v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point2D*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point3D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point3D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point3D* v3, Point3D* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point3D*, Point3D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, Point3D* v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, Point3D*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, char* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, char* v4, char* v5, short v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, char*, char*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, double v4, short v5)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, double, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, Point2D v4, Point2D v5, BYTE* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, Point2D, Point2D, BYTE*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, Point2D v4, Point2D v5, char* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, Point2D, Point2D, char*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, Point2D* v4, Point2D* v5, BYTE* v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, Point2D*, Point2D*, BYTE*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, short v4, Point2D* v5, short v6)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, short, Point2D*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short v3, short v4, short v5, short v6, double v7, BYTE v8, double v9, short v10)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short, short, short, short, double, BYTE, double, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6, v7, v8, v9, v10);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short* v3, short* v4, short* v5, short* v6, double* v7, BYTE* v8, double* v9, short* v10)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short*, short*, short*, short*, double*, BYTE*, double*, short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6, v7, v8, v9, v10);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, short* v3, double* v4, short* v5)
{
    typedef void (CALLBACK* GenericProc) (short*, short, short*, double*, short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, void* v3, short v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, void*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, WORD v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short, WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short* v2, Point2D* v3)
{
    typedef void (CALLBACK* GenericProc) (short*, short*, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short* v2, short* v3, short* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short*, short*, short*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, char* v3, char* v4, char* v5, UINT v6)
{
    typedef void (CALLBACK* GenericProc) (short*, UINT, char*, char*, char*, UINT);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2, char* v3, double v4)
{
    typedef void (CALLBACK* GenericProc) (short*, short, char*, double);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, char* v3, UINT v4, UINT v5, UINT v6)
{
    typedef void (CALLBACK* GenericProc) (short*, UINT, char*, UINT, UINT, UINT);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4, v5, v6);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, UINT v3, Point2D* v4)
{
    typedef void (CALLBACK* GenericProc) (short*, UINT, UINT, Point2D*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, UINT v3, UINT v4)
{
    typedef void (CALLBACK* GenericProc) (short*, UINT, UINT, UINT);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3, v4);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, UINT v2, WORD v3)
{
    typedef void (CALLBACK* GenericProc) (short*, UINT, WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, ULONG v2)
{
    typedef void (CALLBACK* GenericProc) (short*, UINT);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, void* v2)
{
    typedef void (CALLBACK* GenericProc) (short*, void*);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, void* v2, short v3)
{
    typedef void (CALLBACK* GenericProc) (short*, void*, short);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2, v3);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, WORD v2)
{
    typedef void (CALLBACK* GenericProc) (short*, WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, UINT v1)
{
    typedef void (CALLBACK* GenericProc) (UINT);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WORD v1)
{
    typedef void (CALLBACK* GenericProc) (WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1);
    }

    return;
}

void WINAPI voidFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, WORD v1, WORD v2)
{
    typedef void (CALLBACK* GenericProc) (WORD, WORD);

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        ((GenericProc)*fp)(v1, v2);
    }

    return;
}

WORD WINAPI WORDFunction(FARPROC* fp, HMODULE hMod, const char* szFunction)
{
    typedef WORD(CALLBACK* GenericProc) ();
    WORD vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)();
    }

    return vReturn;
}

WORD WINAPI WORDFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1)
{
    typedef WORD(CALLBACK* GenericProc) (short*);
    WORD vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1);
    }

    return vReturn;
}

WORD WINAPI WORDFunction(FARPROC* fp, HMODULE hMod, const char* szFunction, short* v1, short v2)
{
    typedef WORD(CALLBACK* GenericProc) (short*, short);
    WORD vReturn = NULL;

    if (!*fp && hMod)
    {
        *fp = GetProcAddress(hMod, szFunction);
    }
    if (*fp)
    {
        vReturn = ((GenericProc)*fp)(v1, v2);
    }

    return vReturn;
}
